@@ -23,7 +23,7 @@ import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.netscape.security.pkcs.PKCS10;
 import org.mozilla.jss.netscape.security.util.Cert;
 import org.mozilla.jss.netscape.security.util.Utils;
-import org.mozilla.jss.netscape.security.x509.CertificateExtensions;
+import org.mozilla.jss.netscape.security.x509.Extensions;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
 import com.netscape.cmsutil.password.IPasswordStore;
@@ -43,7 +43,9 @@ public class NSSIssuer extends ACMEIssuer {
 
     NSSExtensionGenerator extGenerator;
     Integer monthsValid;
+    String hash;
 
+    @Override
     public void init() throws Exception {
 
         logger.info("Initializing NSS issuer");
@@ -76,10 +78,13 @@ public class NSSIssuer extends ACMEIssuer {
         issuer = cm.findCertByNickname(nickname);
 
         String monthsValid = config.getParameter("monthsValid");
-        if (monthsValid != null) {
-            logger.info("- months valid: " + monthsValid);
+        this.monthsValid = monthsValid == null ? 3 : Integer.valueOf(monthsValid);
+        logger.info("- months valid: " + monthsValid);
 
-            this.monthsValid = new Integer(monthsValid);
+        String hash = config.getParameter("hash");
+        if (hash != null) {
+            logger.info("- hash: " + hash);
+            this.hash = hash;
         }
 
         String extensions = config.getParameter("extensions");
@@ -91,6 +96,7 @@ public class NSSIssuer extends ACMEIssuer {
         extGenerator.init(extPath.toString());
     }
 
+    @Override
     public String issueCertificate(PKCS10 pkcs10) throws Exception {
 
         logger.info("Issuing certificate");
@@ -99,7 +105,7 @@ public class NSSIssuer extends ACMEIssuer {
         ACMEEngine engine = ACMEEngine.getInstance();
         ACMEDatabase acmeDatabase = engine.getDatabase();
 
-        CertificateExtensions extensions = null;
+        Extensions extensions = null;
         if (extGenerator != null) {
             extensions = extGenerator.createExtensions(issuer, pkcs10);
         }
@@ -108,6 +114,7 @@ public class NSSIssuer extends ACMEIssuer {
                 issuer,
                 pkcs10,
                 monthsValid,
+                hash,
                 extensions);
 
         BigInteger serialNumber = cert.getSerialNumber();
@@ -140,6 +147,7 @@ public class NSSIssuer extends ACMEIssuer {
         return caCertChainImpl;
     }
 
+    @Override
     public String getCertificateChain(String certID) throws Exception {
 
         logger.info("Retrieving certificate");
