@@ -48,16 +48,16 @@ import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IAttrSet;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.common.NameValuePairs;
 import com.netscape.certsrv.pattern.Pattern;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.property.IDescriptor;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.profile.common.EnrollProfile;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.base.ConfigStore;
 import com.netscape.cmscore.cert.PrettyPrintFormat;
+import com.netscape.cmscore.request.Request;
 
 /**
  * This class implements an enrollment default policy.
@@ -79,7 +79,7 @@ public abstract class EnrollDefault extends PolicyDefault {
     public static final String GN_ANY_NAME = "OtherName";
     public static final String GN_OID_NAME = "OIDName";
 
-    protected IConfigStore mConfig = null;
+    protected ConfigStore mConfig;
     protected Vector<String> mConfigNames = new Vector<>();
     protected Vector<String> mValueNames = new Vector<>();
 
@@ -103,9 +103,7 @@ public abstract class EnrollDefault extends PolicyDefault {
     @Override
     public void setConfig(String name, String value)
             throws EPropertyException {
-        if (mConfig.getSubStore("params") == null) {
-            //
-        } else {
+        if (mConfig.getSubStore("params") != null) {
             mConfig.getSubStore("params").putString(name, value);
         }
     }
@@ -129,7 +127,7 @@ public abstract class EnrollDefault extends PolicyDefault {
             return null;
         }
 
-        IConfigStore params = mConfig.getSubStore("params");
+        ConfigStore params = mConfig.getSubStore("params", ConfigStore.class);
         if (params == null) {
             logger.error("Missing constraint parameters");
             return null;
@@ -145,7 +143,7 @@ public abstract class EnrollDefault extends PolicyDefault {
     }
 
     @Override
-    public void init(IConfigStore config) throws EProfileException {
+    public void init(ConfigStore config) throws EProfileException {
         mConfig = config;
     }
 
@@ -159,7 +157,7 @@ public abstract class EnrollDefault extends PolicyDefault {
     public abstract String getText(Locale locale);
 
     @Override
-    public IConfigStore getConfigStore() {
+    public ConfigStore getConfigStore() {
         return mConfig;
     }
 
@@ -180,7 +178,7 @@ public abstract class EnrollDefault extends PolicyDefault {
      * @exception EProfileException failed to populate attributes
      *                into request
      */
-    public abstract void populate(IRequest request, X509CertInfo info)
+    public abstract void populate(Request request, X509CertInfo info)
             throws EProfileException;
 
     /**
@@ -221,7 +219,7 @@ public abstract class EnrollDefault extends PolicyDefault {
      * @exception EProfileException failed to populate
      */
     @Override
-    public void populate(IRequest request)
+    public void populate(Request request)
             throws EProfileException {
         String method = "EnrollDefault: populate: ";
         String name = getClass().getName();
@@ -263,7 +261,7 @@ public abstract class EnrollDefault extends PolicyDefault {
      * @exception EPropertyException failed to set property
      */
     @Override
-    public void setValue(String name, Locale locale, IRequest request,
+    public void setValue(String name, Locale locale, Request request,
             String value)
             throws EPropertyException {
         X509CertInfo info =
@@ -272,7 +270,7 @@ public abstract class EnrollDefault extends PolicyDefault {
         setValue(name, locale, info, value);
 
         boolean ret = request.setExtData(EnrollProfile.REQUEST_CERTINFO, info);
-        if (ret == false) {
+        if (!ret) {
             logger.error("EnrollDefault: setValue(): request.setExtData() returned false");
             throw new EPropertyException("EnrollDefault: setValue(): request.setExtData() failed");
         }
@@ -291,7 +289,7 @@ public abstract class EnrollDefault extends PolicyDefault {
      * @exception EPropertyException failed to get property
      */
     @Override
-    public String getValue(String name, Locale locale, IRequest request)
+    public String getValue(String name, Locale locale, Request request)
             throws EPropertyException {
         X509CertInfo info =
                 request.getExtDataInCertInfo(EnrollProfile.REQUEST_CERTINFO);
@@ -442,11 +440,11 @@ public abstract class EnrollDefault extends PolicyDefault {
     }
 
     protected boolean getBoolean(String value) {
-        return Boolean.valueOf(value).booleanValue();
+        return Boolean.parseBoolean(value);
     }
 
     protected int getInt(String value) {
-        return Integer.valueOf(value).intValue();
+        return Integer.parseInt(value);
     }
 
     protected boolean getConfigBoolean(String value) {
@@ -464,9 +462,7 @@ public abstract class EnrollDefault extends PolicyDefault {
         if (pos == -1)
             return false;
         String nameValue = name.substring(pos + 1).trim();
-        if (nameValue.equals(""))
-            return false;
-        return true;
+        return !nameValue.equals("");
     }
 
     protected GeneralNameInterface parseGeneralName(String name)
@@ -575,9 +571,8 @@ public abstract class EnrollDefault extends PolicyDefault {
                     logger.debug("OtherName about to create OtherName object:");
                     logger.debug("OID: " + on_oid + " Value:" + on_value);
                     return new OtherName(new ObjectIdentifier(on_oid), DerValue.tag_PrintableString, on_value);
-                } else {
-                    return null;
                 }
+                return null;
             } else if (nameValue.startsWith("(KerberosName)")) {
                 // Syntax: (KerberosName)Realm|NameType|NameString(s)
                 int pos0 = nameValue.indexOf(')');
@@ -611,9 +606,8 @@ public abstract class EnrollDefault extends PolicyDefault {
                 String on_value = nameValue.substring(pos1 + 1).trim();
                 if (isValidOID(on_oid)) {
                     return new OtherName(new ObjectIdentifier(on_oid), DerValue.tag_IA5String, on_value);
-                } else {
-                    return null;
                 }
+                return null;
             } else if (nameValue.startsWith("(UTF8String)")) {
                 int pos0 = nameValue.indexOf(')');
                 int pos1 = nameValue.indexOf(',');
@@ -623,9 +617,8 @@ public abstract class EnrollDefault extends PolicyDefault {
                 String on_value = nameValue.substring(pos1 + 1).trim();
                 if (isValidOID(on_oid)) {
                     return new OtherName(new ObjectIdentifier(on_oid), DerValue.tag_UTF8String, on_value);
-                } else {
-                    return null;
                 }
+                return null;
             } else if (nameValue.startsWith("(BMPString)")) {
                 int pos0 = nameValue.indexOf(')');
                 int pos1 = nameValue.indexOf(',');
@@ -635,9 +628,8 @@ public abstract class EnrollDefault extends PolicyDefault {
                 String on_value = nameValue.substring(pos1 + 1).trim();
                 if (isValidOID(on_oid)) {
                     return new OtherName(new ObjectIdentifier(on_oid), DerValue.tag_BMPString, on_value);
-                } else {
-                    return null;
                 }
+                return null;
             } else if (nameValue.startsWith("(Any)")) {
                 int pos0 = nameValue.indexOf(')');
                 int pos1 = nameValue.indexOf(',');
@@ -648,10 +640,9 @@ public abstract class EnrollDefault extends PolicyDefault {
                 if (isValidOID(on_oid)) {
                     logger.debug("OID: " + on_oid + " Value:" + on_value);
                     return new OtherName(new ObjectIdentifier(on_oid), getBytes(on_value));
-                } else {
-                    logger.error("Invalid OID: " + on_oid);
-                    return null;
                 }
+                logger.error("Invalid OID: " + on_oid);
+                return null;
             } else {
                 return null;
             }
@@ -668,9 +659,9 @@ public abstract class EnrollDefault extends PolicyDefault {
         if (string == null)
             return null;
         int stringLength = string.length();
-        if ((stringLength == 0) || ((stringLength % 2) != 0))
+        if (stringLength == 0 || (stringLength % 2) != 0)
             return null;
-        byte[] bytes = new byte[(stringLength / 2)];
+        byte[] bytes = new byte[stringLength / 2];
         for (int i = 0, b = 0; i < stringLength; i += 2, ++b) {
             String nextByte = string.substring(i, (i + 2));
             bytes[b] = (byte) Integer.parseInt(nextByte, 0x10);
@@ -762,12 +753,11 @@ public abstract class EnrollDefault extends PolicyDefault {
             if (pos <= 0) {
                 logger.error("Missing colon");
                 throw new EPropertyException("Missing colon");
+            }
+            if (pos == (token.length() - 1)) {
+                nvps.put(token.substring(0, pos), "");
             } else {
-                if (pos == (token.length() - 1)) {
-                    nvps.put(token.substring(0, pos), "");
-                } else {
-                    nvps.put(token.substring(0, pos), token.substring(pos + 1));
-                }
+                nvps.put(token.substring(0, pos), token.substring(pos + 1));
             }
         }
 
@@ -805,18 +795,14 @@ public abstract class EnrollDefault extends PolicyDefault {
 
         if (type == GeneralNameInterface.NAME_DIRECTORY)
             return s;
-        else {
-            int pos = s.indexOf(":");
+        int pos = s.indexOf(":");
 
-            if (pos <= 0)
-                throw new EPropertyException("Badly formatted general name: " + s);
-            else {
-                return s.substring(pos + 1).trim();
-            }
-        }
+        if (pos <= 0)
+            throw new EPropertyException("Badly formatted general name: " + s);
+        return s.substring(pos + 1).trim();
     }
 
-    public Locale getLocale(IRequest request) {
+    public Locale getLocale(Request request) {
         Locale locale = null;
 
         if (request == null)
@@ -840,7 +826,7 @@ public abstract class EnrollDefault extends PolicyDefault {
         return gn.toString();
     }
 
-    protected String mapPattern(IRequest request, String pattern)
+    protected String mapPattern(Request request, String pattern)
             throws IOException {
         Pattern p = new Pattern(pattern);
         IAttrSet attrSet = null;
