@@ -31,14 +31,14 @@ import org.mozilla.jss.netscape.security.x509.GeneralName;
 import org.mozilla.jss.netscape.security.x509.GeneralNameInterface;
 import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.common.NameValuePairs;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.property.Descriptor;
 import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.property.IDescriptor;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.base.ConfigStore;
+import com.netscape.cmscore.request.Request;
 
 /**
  * This class implements an enrollment default policy
@@ -90,7 +90,7 @@ public class SubjectInfoAccessExtDefault extends EnrollExtDefault {
     }
 
     @Override
-    public void init(IConfigStore config) throws EProfileException {
+    public void init(ConfigStore config) throws EProfileException {
         super.init(config);
         refreshConfigAndValueNames();
     }
@@ -408,7 +408,7 @@ public class SubjectInfoAccessExtDefault extends EnrollExtDefault {
      * Populates the request with this policy default.
      */
     @Override
-    public void populate(IRequest request, X509CertInfo info)
+    public void populate(Request request, X509CertInfo info)
             throws EProfileException {
         SubjectInfoAccessExtension ext = createExtension();
 
