@@ -49,14 +49,10 @@ import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
 import com.netscape.certsrv.authentication.IAuthToken;
-import com.netscape.certsrv.authority.ICertAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IArgBlock;
 import com.netscape.certsrv.base.MetaInfo;
-import com.netscape.certsrv.common.ICMSRequest;
 import com.netscape.certsrv.dbs.EDBRecordNotFoundException;
-import com.netscape.certsrv.dbs.certdb.IRevocationInfo;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.cms.servlet.base.CMSServlet;
 import com.netscape.cms.servlet.common.CMSRequest;
@@ -69,6 +65,8 @@ import com.netscape.cmscore.cert.CertPrettyPrint;
 import com.netscape.cmscore.cert.CertUtils;
 import com.netscape.cmscore.dbs.CertRecord;
 import com.netscape.cmscore.dbs.CertificateRepository;
+import com.netscape.cmscore.dbs.RevocationInfo;
+import com.netscape.cmscore.request.Request;
 
 /**
  * Display detailed information about a certificate
@@ -112,7 +110,7 @@ public class DisplayBySerial extends CMSServlet {
         }
 
         try {
-            mCACerts = ((ICertAuthority) mAuthority).getCACertChain().getChain();
+            mCACerts = ((ICertificateAuthority) mAuthority).getCACertChain().getChain();
         } catch (Exception e) {
             logger.warn(CMS.getLogMessage("CMSGW_CA_CHAIN_NOT_AVAILABLE"), e);
         }
@@ -125,7 +123,7 @@ public class DisplayBySerial extends CMSServlet {
 
         // override success and error templates to null -
         // handle templates locally.
-        mTemplates.remove(ICMSRequest.SUCCESS);
+        mTemplates.remove(CMSRequest.SUCCESS);
     }
 
     /**
@@ -160,7 +158,7 @@ public class DisplayBySerial extends CMSServlet {
             }
 
             if (authzToken == null) {
-                cmsReq.setStatus(ICMSRequest.UNAUTHORIZED);
+                cmsReq.setStatus(CMSRequest.UNAUTHORIZED);
                 return;
             }
 
@@ -190,8 +188,7 @@ public class DisplayBySerial extends CMSServlet {
 
         try {
             if (serialNumber.compareTo(MINUS_ONE) > 0) {
-                process(argSet, header, serialNumber,
-                        req, resp, locale[0]);
+                process(header, serialNumber, req, locale[0]);
             } else {
                 error = new ECMSGWException(
                             CMS.getLogMessage("CMSGW_INVALID_SERIAL_NUMBER"));
@@ -210,10 +207,10 @@ public class DisplayBySerial extends CMSServlet {
                 } else {
                     resp.setContentType("text/html");
                     form.renderOutput(out, argSet);
-                    cmsReq.setStatus(ICMSRequest.SUCCESS);
+                    cmsReq.setStatus(CMSRequest.SUCCESS);
                 }
             } else {
-                cmsReq.setStatus(ICMSRequest.ERROR);
+                cmsReq.setStatus(CMSRequest.ERROR);
                 cmsReq.setError(error);
             }
         } catch (IOException e) {
@@ -226,10 +223,8 @@ public class DisplayBySerial extends CMSServlet {
     /**
      * Display information about a particular certificate
      */
-    private void process(CMSTemplateParams argSet, IArgBlock header,
-            BigInteger seq, HttpServletRequest req,
-            HttpServletResponse resp,
-            Locale locale)
+    private void process(IArgBlock header, BigInteger seq,
+            HttpServletRequest req, Locale locale)
             throws EBaseException {
         String certType[] = new String[1];
 
@@ -237,7 +232,7 @@ public class DisplayBySerial extends CMSServlet {
             getCertRecord(seq, certType); // throw exception on error
 
             if (certType[0].equalsIgnoreCase("x509")) {
-                processX509(argSet, header, seq, req, resp, locale);
+                processX509(header, seq, req, locale);
                 return;
             }
         } catch (EBaseException e) {
@@ -248,10 +243,8 @@ public class DisplayBySerial extends CMSServlet {
         return;
     }
 
-    private void processX509(CMSTemplateParams argSet, IArgBlock header,
-            BigInteger seq, HttpServletRequest req,
-            HttpServletResponse resp,
-            Locale locale)
+    private void processX509(IArgBlock header, BigInteger seq,
+            HttpServletRequest req, Locale locale)
             throws EBaseException {
         boolean b64CertOnly = false; // for request that needs only b64 cert
         String isB64CertOnly = req.getParameter("b64CertOnly");
@@ -321,10 +314,10 @@ public class DisplayBySerial extends CMSServlet {
                     String rid = (String) metaInfo.get(CertRecord.META_REQUEST_ID);
 
                     if (rid != null && mAuthority instanceof ICertificateAuthority) {
-                        IRequest r = requestRepository.readRequest(new RequestId(rid));
-                        String certType = r.getExtDataInString(IRequest.HTTP_PARAMS, IRequest.CERT_TYPE);
+                        Request r = requestRepository.readRequest(new RequestId(rid));
+                        String certType = r.getExtDataInString(Request.HTTP_PARAMS, Request.CERT_TYPE);
 
-                        if (certType != null && certType.equals(IRequest.CLIENT_CERT)) {
+                        if (certType != null && certType.equals(Request.CLIENT_CERT)) {
                             noCertImport = false;
                         }
                         header.addStringValue("reqId", rid);
@@ -340,7 +333,7 @@ public class DisplayBySerial extends CMSServlet {
             // Do base 64 encoding
             header.addStringValue("certChainBase64", Utils.base64encode(ba, true));
 
-            IRevocationInfo revocationInfo = rec.getRevocationInfo();
+            RevocationInfo revocationInfo = rec.getRevocationInfo();
 
             if (revocationInfo != null) {
                 CRLExtensions crlExts = revocationInfo.getCRLEntryExtensions();
