@@ -47,7 +47,6 @@ import com.netscape.certsrv.dbs.certdb.CertId;
 import com.netscape.certsrv.profile.ProfileAttribute;
 import com.netscape.certsrv.profile.ProfileInput;
 import com.netscape.certsrv.registry.IPluginInfo;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.profile.ProfileAuthenticator;
 import com.netscape.cms.profile.common.EnrollProfile;
 import com.netscape.cms.profile.common.Profile;
@@ -59,6 +58,7 @@ import com.netscape.cms.servlet.profile.SSLClientCertProvider;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.dbs.CertRecord;
 import com.netscape.cmscore.registry.PluginRegistry;
+import com.netscape.cmscore.request.Request;
 
 public class RenewalProcessor extends CertProcessor {
 
@@ -204,20 +204,20 @@ public class RenewalProcessor extends CertProcessor {
             Date origNotAfter = origCert.getNotAfter();
             logger.debug("processRenewal: origNotAfter =" + origNotAfter.toString());
 
-            String origSubjectDN = origCert.getSubjectDN().getName();
+            String origSubjectDN = origCert.getSubjectName().getName();
             logger.debug("processRenewal: orig subj dn =" + origSubjectDN);
 
-            IRequest origReq = getOriginalRequest(certSerial, rec);
+            Request origReq = getOriginalRequest(certSerial, rec);
             if (origReq == null) {
                 logger.error("processRenewal: original request not found");
                 throw new EBaseException(CMS.getUserMessage(locale, "CMS_INTERNAL_ERROR"));
             }
 
-            String profileId = origReq.getExtDataInString(IRequest.PROFILE_ID);
+            String profileId = origReq.getExtDataInString(Request.PROFILE_ID);
             logger.debug("RenewalSubmitter: renewal original profileId=" + profileId);
 
             String aidString = origReq.getExtDataInString(
-                    IRequest.AUTHORITY_ID);
+                    Request.AUTHORITY_ID);
 
             Integer origSeqNum = origReq.getExtDataInInteger(EnrollProfile.REQUEST_SEQ_NUM);
             Profile profile = ps.getProfile(profileId);
@@ -344,7 +344,7 @@ public class RenewalProcessor extends CertProcessor {
             // create and populate requests
             ///////////////////////////////////////////////
             startTiming("request_population");
-            IRequest[] reqs = profile.createRequests(ctx, locale);
+            Request[] reqs = profile.createRequests(ctx, locale);
             populateRequests(data, true, locale, origNotAfter, origSubjectDN, origReq, profileId,
                     profile, ctx, authenticator, authToken, reqs);
             endTiming("request_population");
@@ -357,7 +357,7 @@ public class RenewalProcessor extends CertProcessor {
 
             List<String> errors = new ArrayList<>();
             if (errorCode != null) {
-                for (IRequest req: reqs) {
+                for (Request req: reqs) {
                     String error = req.getError(locale);
                     if (error != null) {
                         String code = req.getErrorCode(locale);
@@ -441,7 +441,7 @@ public class RenewalProcessor extends CertProcessor {
      * This is expected to be used by renewal where the request
      * is retrieved from request record
      */
-    private void setInputsIntoContext(IRequest request, Profile profile, Map<String, String> ctx, Locale locale) {
+    private void setInputsIntoContext(Request request, Profile profile, Map<String, String> ctx, Locale locale) {
         // passing inputs into context
         Enumeration<String> inputIds = profile.getProfileInputIds();
 
