@@ -45,15 +45,15 @@ import com.netscape.certsrv.logging.AuditFormat;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestEvent;
 import com.netscape.certsrv.logging.event.CertStatusChangeRequestProcessedEvent;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.certsrv.usrgrp.Certificates;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.dbs.CertRecord;
 import com.netscape.cmscore.dbs.CertificateRepository;
 import com.netscape.cmscore.ldap.CAPublisherProcessor;
-import com.netscape.cmscore.request.ARequestQueue;
 import com.netscape.cmscore.request.CertRequestRepository;
+import com.netscape.cmscore.request.Request;
+import com.netscape.cmscore.request.RequestQueue;
 import com.netscape.cmscore.usrgrp.User;
 
 /**
@@ -71,7 +71,7 @@ public class RevocationProcessor extends CertProcessor {
 
     ICertificateAuthority authority;
     CertificateRepository repo;
-    ARequestQueue requestQueue;
+    RequestQueue requestQueue;
     CAPublisherProcessor publisherProcessor;
 
     String initiative;
@@ -84,7 +84,7 @@ public class RevocationProcessor extends CertProcessor {
     CRLExtensions entryExtn;
     Collection<X509CertImpl> certificates = new ArrayList<>();
     Collection<RevokedCertImpl> revCertImpls = new ArrayList<>();
-    IRequest request;
+    Request request;
     RequestStatus requestStatus;
 
     public RevocationProcessor(String id, Locale locale) throws EPropertyNotFound, EBaseException {
@@ -176,7 +176,7 @@ public class RevocationProcessor extends CertProcessor {
         return certificates;
     }
 
-    public IRequest getRequest() {
+    public Request getRequest() {
         return request;
     }
 
@@ -205,7 +205,7 @@ public class RevocationProcessor extends CertProcessor {
 
         X509CertImpl targetCert = targetRecord.getCertificate();
         BigInteger targetSerialNumber = targetCert.getSerialNumber();
-        Principal targetSubjectDN = targetCert.getSubjectDN();
+        Principal targetSubjectDN = targetCert.getSubjectName();
 
         // Verify the subject DN matches the target cert's subject DN.
         // Agent has null subject DN so he can revoke any certificate.
@@ -291,24 +291,24 @@ public class RevocationProcessor extends CertProcessor {
 
         CAEngine engine = CAEngine.getInstance();
         CertRequestRepository requestRepository = engine.getCertRequestRepository();
-        request = requestRepository.createRequest(IRequest.REVOCATION_REQUEST);
+        request = requestRepository.createRequest(Request.REVOCATION_REQUEST);
 
-        request.setExtData(IRequest.REQ_TYPE, IRequest.REVOCATION_REQUEST);
+        request.setExtData(Request.REQ_TYPE, Request.REVOCATION_REQUEST);
 
-        request.setExtData(IRequest.OLD_CERTS, certificates.toArray(new X509CertImpl[certificates.size()]));
-        request.setExtData(IRequest.CERT_INFO, revCertImpls.toArray(new RevokedCertImpl[revCertImpls.size()]));
+        request.setExtData(Request.OLD_CERTS, certificates.toArray(new X509CertImpl[certificates.size()]));
+        request.setExtData(Request.CERT_INFO, revCertImpls.toArray(new RevokedCertImpl[revCertImpls.size()]));
 
         if (AuditFormat.FROMUSER.equals(initiative)) {
-            request.setExtData(IRequest.REQUESTOR_TYPE, IRequest.REQUESTOR_EE);
+            request.setExtData(Request.REQUESTOR_TYPE, Request.REQUESTOR_EE);
         } else {
-            request.setExtData(IRequest.REQUESTOR_TYPE, IRequest.REQUESTOR_AGENT);
+            request.setExtData(Request.REQUESTOR_TYPE, Request.REQUESTOR_AGENT);
         }
 
         if (comments != null) {
-            request.setExtData(IRequest.REQUESTOR_COMMENTS, comments);
+            request.setExtData(Request.REQUESTOR_COMMENTS, comments);
         }
 
-        request.setExtData(IRequest.REVOKED_REASON, revocationReason.getCode());
+        request.setExtData(Request.REVOKED_REASON, revocationReason.getCode());
     }
 
     public void processRevocationRequest() throws EBaseException {
@@ -320,7 +320,7 @@ public class RevocationProcessor extends CertProcessor {
         logger.debug("RevocationProcessor: - certs:");
         for (X509CertImpl cert : certificates) {
             logger.debug("RevocationProcessor:   - serial number: " + cert.getSerialNumber().toString(16));
-            logger.debug("RevocationProcessor:   - subject: " + cert.getSubjectDN());
+            logger.debug("RevocationProcessor:   - subject: " + cert.getSubjectName());
         }
 
         requestQueue.processRequest(request);
@@ -337,13 +337,13 @@ public class RevocationProcessor extends CertProcessor {
 
         if (requestStatus == RequestStatus.COMPLETE
                 || requestStatus == RequestStatus.SVC_PENDING
-                    && type.equals(IRequest.CLA_CERT4CRL_REQUEST)) {
+                    && type.equals(Request.CLA_CERT4CRL_REQUEST)) {
 
             // audit log the error
-            Integer result = request.getExtDataInInteger(IRequest.RESULT);
+            Integer result = request.getExtDataInInteger(Request.RESULT);
 
-            if (result.equals(IRequest.RES_ERROR)) {
-                String[] svcErrors = request.getExtDataInStringArray(IRequest.SVCERRORS);
+            if (result.equals(Request.RES_ERROR)) {
+                String[] svcErrors = request.getExtDataInStringArray(Request.SVCERRORS);
 
                 if (svcErrors != null) {
                     for (String err : svcErrors) {
@@ -364,16 +364,16 @@ public class RevocationProcessor extends CertProcessor {
 
         CAEngine engine = CAEngine.getInstance();
         CertRequestRepository requestRepository = engine.getCertRequestRepository();
-        request = requestRepository.createRequest(IRequest.UNREVOCATION_REQUEST);
+        request = requestRepository.createRequest(Request.UNREVOCATION_REQUEST);
 
-        request.setExtData(IRequest.REQ_TYPE, IRequest.UNREVOCATION_REQUEST);
+        request.setExtData(Request.REQ_TYPE, Request.UNREVOCATION_REQUEST);
 
         Collection<BigInteger> serialNumbers = new ArrayList<>();
         for (X509CertImpl cert : certificates) {
             serialNumbers.add(cert.getSerialNumber());
         }
-        request.setExtData(IRequest.OLD_SERIALS, serialNumbers.toArray(new BigInteger[serialNumbers.size()]));
-        request.setExtData(IRequest.REQUESTOR_TYPE, IRequest.REQUESTOR_AGENT);
+        request.setExtData(Request.OLD_SERIALS, serialNumbers.toArray(new BigInteger[serialNumbers.size()]));
+        request.setExtData(Request.REQUESTOR_TYPE, Request.REQUESTOR_AGENT);
     }
 
     public void processUnrevocationRequest() throws EBaseException {
@@ -384,7 +384,7 @@ public class RevocationProcessor extends CertProcessor {
         logger.debug("RevocationProcessor: - certs:");
         for (X509CertImpl cert : certificates) {
             logger.debug("RevocationProcessor:   - serial number: " + cert.getSerialNumber().toString(16));
-            logger.debug("RevocationProcessor:   - subject: " + cert.getSubjectDN());
+            logger.debug("RevocationProcessor:   - subject: " + cert.getSubjectName());
         }
 
         requestQueue.processRequest(request);
@@ -396,12 +396,12 @@ public class RevocationProcessor extends CertProcessor {
         logger.debug("RevocationProcessor: - type: " + type);
 
         if (requestStatus == RequestStatus.COMPLETE
-                || requestStatus == RequestStatus.SVC_PENDING && type.equals(IRequest.CLA_UNCERT4CRL_REQUEST)) {
+                || requestStatus == RequestStatus.SVC_PENDING && type.equals(Request.CLA_UNCERT4CRL_REQUEST)) {
 
-            Integer result = request.getExtDataInInteger(IRequest.RESULT);
+            Integer result = request.getExtDataInInteger(Request.RESULT);
 
-            if (result.equals(IRequest.RES_ERROR)) {
-                String error = request.getExtDataInString(IRequest.ERROR);
+            if (result.equals(Request.RES_ERROR)) {
+                String error = request.getExtDataInString(Request.ERROR);
                 logger.debug("RevocationProcessor: - error: " + error);
             }
         }
