@@ -37,7 +37,6 @@ import com.netscape.certsrv.authorization.EAuthzAccessDenied;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.property.IDescriptor;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.template.ArgList;
 import com.netscape.certsrv.template.ArgSet;
@@ -51,6 +50,7 @@ import com.netscape.cms.servlet.common.CMSRequest;
 import com.netscape.cms.servlet.common.CMSTemplate;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.profile.ProfileSubsystem;
+import com.netscape.cmscore.request.Request;
 import com.netscape.cmscore.request.RequestQueue;
 import com.netscape.cmscore.security.JssSubsystem;
 
@@ -190,7 +190,7 @@ public class ProfileReviewServlet extends ProfileServlet {
         }
 
         String requestId = request.getParameter("requestId");
-        IRequest req = null;
+        Request req = null;
 
         logger.debug("ProfileReviewServlet: requestId=" + requestId);
         try {
@@ -207,7 +207,7 @@ public class ProfileReviewServlet extends ProfileServlet {
             return;
         }
 
-        String profileId = req.getExtDataInString(IRequest.PROFILE_ID);
+        String profileId = req.getExtDataInString(Request.PROFILE_ID);
 
         logger.debug("ProfileReviewServlet: requestId=" +
                 requestId + " profileId=" + profileId);
@@ -394,7 +394,7 @@ public class ProfileReviewServlet extends ProfileServlet {
 
     private void handlePolicy(ArgList list, ServletResponse response,
             Locale locale, String id, ProfilePolicy policy,
-            IRequest req) {
+            Request req) {
         ArgSet set = new ArgSet();
 
         set.set(ARG_POLICY_ID, id);
