@@ -19,7 +19,6 @@ package org.dogtagpki.legacy.server.policy.extensions;
 
 import java.io.IOException;
 import java.security.cert.CertificateException;
-import java.util.Locale;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
@@ -41,12 +40,12 @@ import org.mozilla.jss.netscape.security.x509.UserNotice;
 import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.PolicyResult;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.base.ConfigStore;
 import com.netscape.cmscore.cert.CertUtils;
+import com.netscape.cmscore.request.Request;
 
 /**
  * Certificate Policies.
@@ -74,7 +73,7 @@ public class CertificatePoliciesExt extends APolicyRule
     protected static final int DEF_NUM_CERTPOLICIES = 1;
 
     protected boolean mEnabled = false;
-    protected IConfigStore mConfig = null;
+    protected ConfigStore mConfig;
 
     protected boolean mCritical = DEF_CRITICAL;
     protected int mNumCertPolicies = DEF_NUM_CERTPOLICIES;
@@ -100,8 +99,7 @@ public class CertificatePoliciesExt extends APolicyRule
      * @param config The config store reference
      */
     @Override
-    public void init(IPolicyProcessor owner, IConfigStore config)
-            throws EBaseException {
+    public void init(IPolicyProcessor owner, ConfigStore config) throws EBaseException {
         mConfig = config;
 
         mEnabled = mConfig.getBoolean(
@@ -165,11 +163,11 @@ public class CertificatePoliciesExt extends APolicyRule
      * @return The policy result object.
      */
     @Override
-    public PolicyResult apply(IRequest req) {
+    public PolicyResult apply(Request req) {
 
         // get certInfo from request.
         X509CertInfo[] ci =
-                req.getExtDataInCertInfoArray(IRequest.CERT_INFO);
+                req.getExtDataInCertInfoArray(Request.CERT_INFO);
 
         if (ci == null || ci[0] == null) {
             setError(req, CMS.getUserMessage("CMS_POLICY_NO_CERT_INFO"), NAME);
@@ -185,7 +183,7 @@ public class CertificatePoliciesExt extends APolicyRule
         return PolicyResult.ACCEPTED;
     }
 
-    public PolicyResult applyCert(IRequest req, X509CertInfo certInfo) {
+    public PolicyResult applyCert(Request req, X509CertInfo certInfo) {
         CertificateExtensions extensions = null;
 
         try {
@@ -277,7 +275,7 @@ public class CertificatePoliciesExt extends APolicyRule
     }
 
     @Override
-    public String[] getExtendedPluginInfo(Locale locale) {
+    public String[] getExtendedPluginInfo() {
         Vector<String> theparams = new Vector<>();
 
         theparams.addElement(PROP_CRITICAL + ";boolean;RFC 3280 recommendation: MUST be non-critical.");
@@ -324,7 +322,7 @@ class CertPolicy {
 
     protected String mName = null;
     protected String mNameDot = null;
-    protected IConfigStore mConfig = null;
+    protected ConfigStore mConfig;
 
     protected String mPolicyId = null;
     protected String mNoticeRefOrg = null;
@@ -341,10 +339,9 @@ class CertPolicy {
      * @param config parent's config from where we find this configuration.
      * @param enabled whether policy was enabled.
      */
-    protected CertPolicy(String name, IConfigStore config, boolean enabled)
-            throws EBaseException {
+    protected CertPolicy(String name, ConfigStore config, boolean enabled) throws EBaseException {
         mName = name;
-        mConfig = config.getSubStore(mName);
+        mConfig = config.getSubStore(mName, ConfigStore.class);
         mNameDot = mName + ".";
 
         if (mConfig == null) {
@@ -359,7 +356,7 @@ class CertPolicy {
             config.putString(mNameDot + PROP_NOTICE_REF_NUMS, "");
             config.putString(mNameDot + PROP_USER_NOTICE_TEXT, "");
             config.putString(mNameDot + PROP_CPS_URI, "");
-            mConfig = config.getSubStore(mName);
+            mConfig = config.getSubStore(mName, ConfigStore.class);
             if (mConfig == null || mConfig.size() == 0) {
                 logger.error("CertificatePoliciesExt::CertPolicy - mConfig is null or empty!");
                 throw new EBaseException("mConfig is null or empty");
