@@ -19,7 +19,6 @@ package org.dogtagpki.legacy.server.policy.extensions;
 
 import java.io.IOException;
 import java.security.cert.CertificateException;
-import java.util.Locale;
 import java.util.Vector;
 
 import org.dogtagpki.legacy.core.policy.GeneralNameAsConstraintsConfig;
@@ -36,11 +35,11 @@ import org.mozilla.jss.netscape.security.x509.NameConstraintsExtension;
 import org.mozilla.jss.netscape.security.x509.X509CertInfo;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.PolicyResult;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.base.ConfigStore;
+import com.netscape.cmscore.request.Request;
 
 /**
  * Name Constraints Extension Policy
@@ -72,7 +71,7 @@ public class NameConstraintsExt extends APolicyRule
     protected static final int DEF_NUM_EXCLUDEDSUBTREES = 8;
 
     protected boolean mEnabled = false;
-    protected IConfigStore mConfig = null;
+    protected ConfigStore mConfig;
 
     protected boolean mCritical = DEF_CRITICAL;
     protected int mNumPermittedSubtrees = 0;
@@ -100,8 +99,7 @@ public class NameConstraintsExt extends APolicyRule
      * @param config The config store reference
      */
     @Override
-    public void init(IPolicyProcessor owner, IConfigStore config)
-            throws EBaseException {
+    public void init(IPolicyProcessor owner, ConfigStore config) throws EBaseException {
         mConfig = config;
 
         // XXX should do do this ?
@@ -217,7 +215,7 @@ public class NameConstraintsExt extends APolicyRule
 
         for (int i = 0; i < numSubtrees; i++) {
             String subtreeName = subtreesName + i;
-            IConfigStore subtreeConfig = mConfig.getSubStore(subtreeName);
+            ConfigStore subtreeConfig = mConfig.getSubStore(subtreeName, ConfigStore.class);
             Subtree subtree =
                     new Subtree(subtreeName, subtreeConfig, mEnabled);
 
@@ -236,7 +234,7 @@ public class NameConstraintsExt extends APolicyRule
      * @return The policy result object.
      */
     @Override
-    public PolicyResult apply(IRequest req) {
+    public PolicyResult apply(Request req) {
         // if extension hasn't been properly configured reject requests until
         // it has been resolved (or disabled).
         if (mNameConstraintsExtension == null) {
@@ -247,7 +245,7 @@ public class NameConstraintsExt extends APolicyRule
 
         // get certInfo from request.
         X509CertInfo[] ci =
-                req.getExtDataInCertInfoArray(IRequest.CERT_INFO);
+                req.getExtDataInCertInfoArray(Request.CERT_INFO);
 
         if (ci == null || ci[0] == null) {
             setError(req, CMS.getUserMessage("CMS_POLICY_NO_CERT_INFO"), NAME);
@@ -264,7 +262,7 @@ public class NameConstraintsExt extends APolicyRule
 
     }
 
-    public PolicyResult applyCert(IRequest req, X509CertInfo certInfo) {
+    public PolicyResult applyCert(Request req, X509CertInfo certInfo) {
         // check if name constraints extension already exists.
         // if not agent approved, replace name constraints extension with ours.
         // else ignore.
@@ -360,7 +358,7 @@ public class NameConstraintsExt extends APolicyRule
     }
 
     @Override
-    public String[] getExtendedPluginInfo(Locale locale) {
+    public String[] getExtendedPluginInfo() {
         Vector<String> theparams = new Vector<>();
 
         theparams.addElement(PROP_CRITICAL + ";boolean;RFC 2459 recommendation: MUST be critical.");
@@ -403,7 +401,7 @@ class Subtree {
     protected static final String MINMAX_INFO = "number;See RFC 2459 section 4.2.1.11";
 
     String mName = null;
-    IConfigStore mConfig = null;
+    ConfigStore mConfig;
     int mMin = DEF_MIN, mMax = DEF_MAX;
     IGeneralNameAsConstraintsConfig mBase = null;
     GeneralSubtree mGeneralSubtree = null;
@@ -413,7 +411,9 @@ class Subtree {
     String mNameDotMax = null;
 
     public Subtree(
-            String subtreeName, IConfigStore config, boolean policyEnabled)
+            String subtreeName,
+            ConfigStore config,
+            boolean policyEnabled)
             throws EBaseException {
         mName = subtreeName;
         mConfig = config;
@@ -441,8 +441,10 @@ class Subtree {
         if (mMax < -1)
             mMax = -1;
         mBase = new GeneralNameAsConstraintsConfig(
-                    mNameDot + PROP_BASE, mConfig.getSubStore(PROP_BASE),
-                    true, policyEnabled);
+                    mNameDot + PROP_BASE,
+                    mConfig.getSubStore(PROP_BASE, ConfigStore.class),
+                    true,
+                    policyEnabled);
 
         if (policyEnabled) {
             mGeneralSubtree =
