@@ -55,7 +55,6 @@ import com.netscape.ca.KeyRetriever;
 import com.netscape.ca.KeyRetrieverRunner;
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.ca.AuthorityID;
 import com.netscape.certsrv.ca.CANotFoundException;
@@ -71,6 +70,7 @@ import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.authentication.VerifiedCert;
 import com.netscape.cmscore.base.ConfigStorage;
+import com.netscape.cmscore.base.ConfigStore;
 import com.netscape.cmscore.cert.CertUtils;
 import com.netscape.cmscore.cert.CrossCertPairSubsystem;
 import com.netscape.cmscore.dbs.CRLRepository;
@@ -314,7 +314,7 @@ public class CAEngine extends CMSEngine {
     }
 
     public ICRLIssuingPoint getMasterCRLIssuingPoint() {
-        return crlIssuingPoints.get(CertificateAuthority.PROP_MASTER_CRL);
+        return crlIssuingPoints.get(ICertificateAuthority.PROP_MASTER_CRL);
     }
 
     /**
@@ -392,17 +392,17 @@ public class CAEngine extends CMSEngine {
         CAEngineConfig engineConfig = getConfig();
         CAConfig caConfig = engineConfig.getCAConfig();
 
-        IConfigStore listenersConfig = caConfig.getSubStore(CertificateAuthority.PROP_LISTENER_SUBSTORE);
+        ConfigStore listenersConfig = caConfig.getSubStore(ICertificateAuthority.PROP_LISTENER_SUBSTORE, ConfigStore.class);
         if (listenersConfig == null) return;
 
         logger.info("CAEngine: Loading listener plugins");
 
-        IConfigStore pluginsConfig = listenersConfig.getSubStore(CertificateAuthority.PROP_IMPL);
+        ConfigStore pluginsConfig = listenersConfig.getSubStore(ICertificateAuthority.PROP_IMPL, ConfigStore.class);
         Enumeration<String> pluginNames = pluginsConfig.getSubStoreNames();
 
         while (pluginNames.hasMoreElements()) {
             String id = pluginNames.nextElement();
-            String listenerClassName = pluginsConfig.getString(id + "." + CertificateAuthority.PROP_CLASS);
+            String listenerClassName = pluginsConfig.getString(id + "." + ICertificateAuthority.PROP_CLASS);
             logger.info("CAEngine: - " + id + ": " + listenerClassName);
 
             ListenerPlugin plugin = new ListenerPlugin(id, listenerClassName);
@@ -411,14 +411,14 @@ public class CAEngine extends CMSEngine {
 
         logger.info("CAEngine: Creating listener instances");
 
-        IConfigStore instancesConfig = listenersConfig.getSubStore(CertificateAuthority.PROP_INSTANCE);
+        ConfigStore instancesConfig = listenersConfig.getSubStore(ICertificateAuthority.PROP_INSTANCE, ConfigStore.class);
         Enumeration<String> instanceNames = instancesConfig.getSubStoreNames();
 
         while (instanceNames.hasMoreElements()) {
             String id = instanceNames.nextElement();
 
-            IConfigStore instanceConfig = instancesConfig.getSubStore(id);
-            String pluginName = instancesConfig.getString(id + "." + CertificateAuthority.PROP_PLUGIN);
+            ConfigStore instanceConfig = instancesConfig.getSubStore(id, ConfigStore.class);
+            String pluginName = instancesConfig.getString(id + "." + ICertificateAuthority.PROP_PLUGIN);
             logger.info("CAEngine: - " + id + ": " + pluginName);
 
             ListenerPlugin plugin = listenerPlugins.get(pluginName);
@@ -446,7 +446,7 @@ public class CAEngine extends CMSEngine {
         CAEngineConfig engineConfig = getConfig();
         CAConfig caConfig = engineConfig.getCAConfig();
 
-        IConfigStore crlPublisherConfig = caConfig.getSubStore("crlPublisher");
+        ConfigStore crlPublisherConfig = caConfig.getSubStore("crlPublisher", ConfigStore.class);
         if (crlPublisherConfig == null || crlPublisherConfig.size() == 0) {
             return;
         }
@@ -478,7 +478,7 @@ public class CAEngine extends CMSEngine {
 
         CertificateAuthority hostCA = getCA();
 
-        publisherProcessor = new CAPublisherProcessor(CertificateAuthority.ID + "pp");
+        publisherProcessor = new CAPublisherProcessor(ICertificateAuthority.ID + "pp");
 
         if (publishingConfig.getBoolean(PublisherProcessor.PROP_ENABLE, false)) {
             LdapRequestListener listener = new LdapRequestListener();
@@ -498,7 +498,7 @@ public class CAEngine extends CMSEngine {
         CAEngineConfig engineConfig = getConfig();
         CAConfig caConfig = engineConfig.getCAConfig();
 
-        IConfigStore crlConfig = caConfig.getSubStore(CertificateAuthority.PROP_CRL_SUBSTORE);
+        ConfigStore crlConfig = caConfig.getSubStore(ICertificateAuthority.PROP_CRL_SUBSTORE, ConfigStore.class);
 
         if (crlConfig == null || crlConfig.size() <= 0) {
             logger.error(CMS.getLogMessage("CMSCORE_CA_CA_NO_MASTER_CRL"));
@@ -600,7 +600,7 @@ public class CAEngine extends CMSEngine {
         CAEngineConfig engineConfig = getConfig();
         CAConfig caConfig = engineConfig.getCAConfig();
 
-        IConfigStore listenerConfig = caConfig.getSubStore(CertificateAuthority.PROP_NOTIFY_SUBSTORE);
+        ConfigStore listenerConfig = caConfig.getSubStore(ICertificateAuthority.PROP_NOTIFY_SUBSTORE, ConfigStore.class);
         if (listenerConfig == null || listenerConfig.size() == 0) {
             return;
         }
@@ -622,7 +622,7 @@ public class CAEngine extends CMSEngine {
         CAEngineConfig engineConfig = getConfig();
         CAConfig caConfig = engineConfig.getCAConfig();
 
-        IConfigStore listenerConfig = caConfig.getSubStore(CertificateAuthority.PROP_NOTIFY_SUBSTORE);
+        ConfigStore listenerConfig = caConfig.getSubStore(ICertificateAuthority.PROP_NOTIFY_SUBSTORE, ConfigStore.class);
         if (listenerConfig == null || listenerConfig.size() == 0) {
             return;
         }
@@ -644,7 +644,7 @@ public class CAEngine extends CMSEngine {
         CAEngineConfig engineConfig = getConfig();
         CAConfig caConfig = engineConfig.getCAConfig();
 
-        IConfigStore listenerConfig = caConfig.getSubStore(CertificateAuthority.PROP_NOTIFY_SUBSTORE);
+        ConfigStore listenerConfig = caConfig.getSubStore(ICertificateAuthority.PROP_NOTIFY_SUBSTORE, ConfigStore.class);
         if (listenerConfig == null || listenerConfig.size() == 0) {
             return;
         }
@@ -742,7 +742,7 @@ public class CAEngine extends CMSEngine {
 
         logger.info("CAEngine: Loading CA configuration");
 
-        int certVersion = caConfig.getInteger(CertificateAuthority.PROP_X509CERT_VERSION, CertificateVersion.V3);
+        int certVersion = caConfig.getInteger(ICertificateAuthority.PROP_X509CERT_VERSION, CertificateVersion.V3);
         if (certVersion != CertificateVersion.V1 && certVersion != CertificateVersion.V3) {
             throw new ECAException(CMS.getUserMessage("CMS_CA_X509CERT_VERSION_NOT_SUPPORTED"));
         }
@@ -750,19 +750,19 @@ public class CAEngine extends CMSEngine {
         defaultCertVersion = new CertificateVersion(certVersion - 1);
         logger.info("CAEngine: - default cert version: " + defaultCertVersion);
 
-        int certValidity = caConfig.getInteger(CertificateAuthority.PROP_DEF_VALIDITY, 2 * 365);
+        int certValidity = caConfig.getInteger(ICertificateAuthority.PROP_DEF_VALIDITY, 2 * 365);
         defaultCertValidity = certValidity * CertificateAuthority.DAY; // in milliseconds
         logger.info("CAEngine: - default cert validity (days): " + certValidity);
 
-        enablePastCATime = caConfig.getBoolean(CertificateAuthority.PROP_ENABLE_PAST_CATIME, false);
+        enablePastCATime = caConfig.getBoolean(ICertificateAuthority.PROP_ENABLE_PAST_CATIME, false);
         logger.info("CAEngine: - enable past CA time: " + enablePastCATime);
 
-        enablePastCATime_caCert = caConfig.getBoolean(CertificateAuthority.PROP_ENABLE_PAST_CATIME_CACERT, false);
+        enablePastCATime_caCert = caConfig.getBoolean(ICertificateAuthority.PROP_ENABLE_PAST_CATIME_CACERT, false);
         logger.info("CAEngine: - enable past CA time for CA certs: " + enablePastCATime_caCert);
 
-        enableOCSP = caConfig.getBoolean(CertificateAuthority.PROP_ENABLE_OCSP, true);
+        enableOCSP = caConfig.getBoolean(ICertificateAuthority.PROP_ENABLE_OCSP, true);
 
-        String fastSigning = caConfig.getString(CertificateAuthority.PROP_FAST_SIGNING, "");
+        String fastSigning = caConfig.getString(ICertificateAuthority.PROP_FAST_SIGNING, "");
         logger.info("CAEngine: - fast signing: " + fastSigning);
 
         if (fastSigning.equals("enabled") || fastSigning.equals("enable")) {
@@ -781,7 +781,7 @@ public class CAEngine extends CMSEngine {
         logger.info("CAEngine: - max nonces: " + maxNonces);
 
         logger.info("CAEngine: Initializing CA policy");
-        IConfigStore caPolicyConfig = caConfig.getSubStore(CertificateAuthority.PROP_POLICY);
+        ConfigStore caPolicyConfig = caConfig.getSubStore(ICertificateAuthority.PROP_POLICY, ConfigStore.class);
         caPolicy = new CAPolicy();
         caPolicy.init(hostCA, caPolicyConfig);
 
@@ -803,6 +803,7 @@ public class CAEngine extends CMSEngine {
         logger.info("CAEngine: - scheduler: " + schedulerClass);
 
         requestRepository = new CertRequestRepository(dbSubsystem);
+        requestRepository.init();
 
         requestQueue = new RequestQueue(
                 dbSubsystem,
@@ -829,7 +830,7 @@ public class CAEngine extends CMSEngine {
 
             startSerialNumberUpdateTask();
 
-            caService.init(caConfig.getSubStore("connector"));
+            caService.init(caConfig.getSubStore("connector", ConfigStore.class));
 
             initListeners();
 
@@ -846,13 +847,9 @@ public class CAEngine extends CMSEngine {
     }
 
     @Override
-    public void initSubsystem(ISubsystem subsystem, IConfigStore subsystemConfig) throws Exception {
+    public void initSubsystem(ISubsystem subsystem, ConfigStore subsystemConfig) throws Exception {
 
-        if (subsystem instanceof CertificateAuthority) {
-            // skip initialization during installation
-            if (isPreOpMode()) return;
-
-        } else if (subsystem instanceof CrossCertPairSubsystem) {
+        if (subsystem instanceof CertificateAuthority || subsystem instanceof CrossCertPairSubsystem) {
             // skip initialization during installation
             if (isPreOpMode()) return;
         }
@@ -950,7 +947,7 @@ public class CAEngine extends CMSEngine {
      * Returns the main/host CA.
      */
     public CertificateAuthority getCA() {
-        return (CertificateAuthority) getSubsystem(CertificateAuthority.ID);
+        return (CertificateAuthority) getSubsystem(ICertificateAuthority.ID);
     }
 
     /**
@@ -1148,18 +1145,18 @@ public class CAEngine extends CMSEngine {
             return;
         }
 
-        IConfigStore keyRetrieverConfig = engineConfig.getSubStore("features.authority.keyRetrieverConfig");
+        ConfigStore keyRetrieverConfig = engineConfig.getSubStore("features.authority.keyRetrieverConfig", ConfigStore.class);
 
         KeyRetriever keyRetriever;
         try {
             Class<? extends KeyRetriever> clazz = Class.forName(className).asSubclass(KeyRetriever.class);
 
             // If there is an accessible constructor that takes
-            // an IConfigStore, invoke that; otherwise invoke
+            // a ConfigStore, invoke that; otherwise invoke
             // the nullary constructor.
 
             try {
-                keyRetriever = clazz.getDeclaredConstructor(IConfigStore.class).newInstance(keyRetrieverConfig);
+                keyRetriever = clazz.getDeclaredConstructor(ConfigStore.class).newInstance(keyRetrieverConfig);
 
             } catch (NoSuchMethodException | SecurityException | IllegalAccessException e) {
                 keyRetriever = clazz.getDeclaredConstructor().newInstance();
@@ -1372,12 +1369,11 @@ public class CAEngine extends CMSEngine {
                         + " skipping.  Enable dirsrv USN plugin.");
                 return;
 
-            } else {
-                logger.debug("CAEngine: dirsrv USN plugin is enabled; continuing");
-                // entryUSN plugin is enabled, but no entryUSN attribute. We
-                // can proceed because future modifications will result in the
-                // entryUSN attribute being added.
             }
+            logger.debug("CAEngine: dirsrv USN plugin is enabled; continuing");
+            // entryUSN plugin is enabled, but no entryUSN attribute. We
+            // can proceed because future modifications will result in the
+            // entryUSN attribute being added.
 
         } else {
             newEntryUSN = new BigInteger(entryUSNAttr.getStringValueArray()[0]);
@@ -1444,7 +1440,7 @@ public class CAEngine extends CMSEngine {
             entryUSNs.put(aid, newEntryUSN);
             nsUniqueIds.put(aid, nsUniqueId);
 
-        } catch (EBaseException e) {
+        } catch (Exception e) {
             logger.warn("CAEngine: Error initializing lightweight CA: " + e.getMessage(), e);
         }
     }
@@ -1604,21 +1600,20 @@ public class CAEngine extends CMSEngine {
 
         logger.info("CAEngine: Initializing cert repository");
 
-        IConfigStore caConfig = mConfig.getSubStore(CertificateAuthority.ID);
+        ConfigStore caConfig = mConfig.getSubStore(ICertificateAuthority.ID, ConfigStore.class);
         int increment = caConfig.getInteger(CertificateRepository.PROP_INCREMENT, 5);
         logger.info("CAEngine: - increment: " + increment);
 
         certificateRepository = new CertificateRepository(dbSubsystem);
+        certificateRepository.init();
     }
 
     public void initCrlDatabase() throws Exception {
 
         logger.info("CAEngine: Initializing CRL repository");
 
-        IConfigStore caConfig = mConfig.getSubStore(CertificateAuthority.ID);
-        int increment = caConfig.getInteger(CRLRepository.PROP_INCREMENT, 5);
-
         crlRepository = new CRLRepository(dbSubsystem);
+        crlRepository.init();
     }
 
     public void initReplicaIDRepository() throws Exception {
@@ -1626,6 +1621,7 @@ public class CAEngine extends CMSEngine {
         logger.info("CAEngine: Initializing replica ID repository");
 
         replicaIDRepository = new ReplicaIDRepository(dbSubsystem);
+        replicaIDRepository.init();
     }
 
     @Override
