@@ -337,7 +337,13 @@ class SystemCertData(object):
     """
 
     def __init__(self):
-        pass
+        self.token = None
+        self.keyID = None
+        self.keyType = None
+        self.keySize = None
+        self.keyWrap = False
+        self.keyCurveName = None
+        self.sslECDH = False
 
 
 class SystemConfigClient(object):
@@ -353,41 +359,24 @@ class SystemConfigClient(object):
 
         self.connection = connection
 
-        self.load_cert_url = '/rest/installer/loadCert'
-        self.setup_cert_url = '/rest/installer/setupCert'
-        self.setup_admin_url = '/rest/installer/setupAdmin'
-        self.backup_keys_url = '/rest/installer/backupKeys'
-        self.setup_security_domain_url = '/rest/installer/setupSecurityDomain'
+        self.create_request_id_url = '/rest/installer/createRequestID'
+        self.create_cert_id_url = '/rest/installer/createCertID'
+        self.create_cert_url = '/rest/installer/createCert'
+        self.init_subsystem_url = '/rest/installer/initSubsystem'
 
         if connection.subsystem is None:
 
             if subsystem is None:
                 raise Exception('Missing subsystem for SystemConfigClient')
 
-            self.load_cert_url = '/' + subsystem + self.load_cert_url
-            self.setup_cert_url = '/' + subsystem + self.setup_cert_url
-            self.setup_admin_url = '/' + subsystem + self.setup_admin_url
-            self.backup_keys_url = '/' + subsystem + self.backup_keys_url
-            self.setup_security_domain_url = '/' + subsystem + self.setup_security_domain_url
+            self.create_request_id_url = '/' + subsystem + self.create_request_id_url
+            self.create_cert_id_url = '/' + subsystem + self.create_cert_id_url
+            self.create_cert_url = '/' + subsystem + self.create_cert_url
+            self.init_subsystem_url = '/' + subsystem + self.init_subsystem_url
 
-    def loadCert(self, request):
+    def createRequestID(self, request):
         """
-        Load existing certificate.
-
-        :param request: Certificate setup request
-        :type request: CertificateSetupRequest
-        """
-        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
-        headers = {'Content-type': 'application/json'}
-
-        self.connection.post(
-            self.load_cert_url,
-            data,
-            headers)
-
-    def setupCert(self, request):
-        """
-        Set up certificate.
+        Create certificate request ID.
 
         :param request: Certificate setup request
         :type request: CertificateSetupRequest
@@ -398,32 +387,65 @@ class SystemConfigClient(object):
                    'Accept': 'application/json'}
 
         response = self.connection.post(
-            self.setup_cert_url,
+            self.create_request_id_url,
             data,
             headers)
 
-        if not response.content:
-            return None
-
         return response.json()
 
-    def setupAdmin(self, request):
+    def createCertID(self, request):
         """
-        Set up admin.
+        Create certificate ID.
 
-        :param request: Admin setup request
-        :type request: AdminSetupRequest
-        :return: AdminSetupResponse
+        :param request: Certificate setup request
+        :type request: CertificateSetupRequest
+        :return: SystemCertData
         """
         data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
         headers = {'Content-type': 'application/json',
                    'Accept': 'application/json'}
+
         response = self.connection.post(
-            self.setup_admin_url,
+            self.create_cert_id_url,
             data,
             headers)
+
         return response.json()
 
+    def createCert(self, request):
+        """
+        Create certificate.
+
+        :param request: Certificate setup request
+        :type request: CertificateSetupRequest
+        :return: SystemCertData
+        """
+        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
+        headers = {'Content-type': 'application/json',
+                   'Accept': 'application/json'}
+
+        response = self.connection.post(
+            self.create_cert_url,
+            data,
+            headers)
+
+        return response.json()
+
+    def initSubsystem(self, request):
+        """
+        Initialize subsystem.
+
+        :param request: Certificate setup request
+        :type request: CertificateSetupRequest
+        """
+        data = json.dumps(request, cls=pki.encoder.CustomTypeEncoder)
+        headers = {'Content-type': 'application/json'}
+
+        self.connection.post(
+            self.init_subsystem_url,
+            data,
+            headers)
+
 
 class SystemStatusClient(object):
     """
