@@ -26,7 +26,10 @@ Module containing utility functions and classes for the Dogtag python code
 from __future__ import absolute_import
 import fileinput
 import functools
+import getpass
+import io
 import logging
+import operator
 import os
 import re
 import shutil
@@ -93,15 +96,26 @@ def replace_params(line, params=None):
     return line
 
 
-def makedirs(path, uid=-1, gid=-1, force=False):
+def makedirs(
+        path,
+        mode=0o777,
+        exist_ok=False,
+        uid=-1,
+        gid=-1,
+        force=False):
 
-    logger.debug('Command: mkdir -p %s', path)
+    parent = os.path.dirname(path)
+
+    if not os.path.exists(parent):
+        makedirs(parent, mode=mode, exist_ok=exist_ok, uid=uid, gid=gid, force=force)
 
     if force and os.path.exists(path):
         logger.warning('Directory already exists: %s', path)
         return
 
-    os.makedirs(path)
+    logger.debug('Command: mkdir %s', path)
+
+    os.makedirs(path, mode=mode, exist_ok=exist_ok)
     os.chown(path, uid, gid)
 
 
@@ -117,7 +131,14 @@ def symlink(source, dest, uid=-1, gid=-1, force=False):
     os.lchown(dest, uid, gid)
 
 
-def copy(source, dest, uid=-1, gid=-1, force=False):
+def copy(
+        source,
+        dest,
+        uid=-1,
+        gid=-1,
+        dir_mode=None,
+        file_mode=None,
+        force=False):
     """
     Copy a file or a folder and its contents.
     """
@@ -132,28 +153,33 @@ def copy(source, dest, uid=-1, gid=-1, force=False):
     destparent = os.path.dirname(dest)
 
     if not os.path.exists(destparent):
-        copydirs(sourceparent, destparent, uid=uid, gid=gid, force=force)
+        # if parent directory doesn't exist, create it first
+        copydirs(sourceparent, destparent, uid=uid, gid=gid, mode=dir_mode, force=force)
 
     if os.path.isfile(source):
-        copyfile(source, dest, uid=uid, gid=gid, force=force)
+        # if it's a file, copy the file
+        copyfile(source, dest, uid=uid, gid=gid, mode=file_mode, force=force)
+        return
 
-    else:
-        for sourcepath, _, filenames in os.walk(source):
+    # it's a directory tree, go through each directory in the tree
+    for sourcepath, _, filenames in os.walk(source):
 
-            relpath = sourcepath[len(source):]
-            destpath = dest + relpath
-            if destpath == '':
-                destpath = '/'
+        relpath = sourcepath[len(source):]
+        destpath = dest + relpath
+        if destpath == '':
+            destpath = '/'
 
-            copydirs(sourcepath, destpath, uid=uid, gid=gid, force=force)
+        # copy the directory itself
+        copydirs(sourcepath, destpath, uid=uid, gid=gid, mode=dir_mode, force=force)
 
-            for filename in filenames:
-                sourcefile = os.path.join(sourcepath, filename)
-                targetfile = os.path.join(destpath, filename)
-                copyfile(sourcefile, targetfile, uid=uid, gid=gid, force=force)
+        # copy the contents
+        for filename in filenames:
+            sourcefile = os.path.join(sourcepath, filename)
+            targetfile = os.path.join(destpath, filename)
+            copyfile(sourcefile, targetfile, uid=uid, gid=gid, mode=file_mode, force=force)
 
 
-def copyfile(source, dest, slots=None, params=None, uid=None, gid=None, perms=None, force=False):
+def copyfile(source, dest, slots=None, params=None, uid=None, gid=None, mode=None, force=False):
     """
     Copy a file or link while preserving its attributes.
     """
@@ -194,7 +220,7 @@ def copyfile(source, dest, slots=None, params=None, uid=None, gid=None, perms=No
         if params is None:
             params = {}
 
-        with open(dest, 'w') as f:
+        with open(dest, 'w', encoding='utf-8') as f:
             for line in fileinput.FileInput(source):
                 for slot in slots:
                     if slot != '__name__' and slots[slot] in line:
@@ -209,22 +235,23 @@ def copyfile(source, dest, slots=None, params=None, uid=None, gid=None, perms=No
 
     os.chown(dest, uid, gid)
 
-    if perms is None:
-        perms = stat.st_mode
+    if mode is None:
+        mode = stat.st_mode
 
-    os.chmod(dest, perms)
+    os.chmod(dest, mode)
 
 
-def copydirs(source, dest, uid=-1, gid=-1, force=False):
+def copydirs(source, dest, uid=-1, gid=-1, mode=None, force=False):
     """
-    Copy a folder and its parents while preserving their attributes.
+    Copy a folder and its parents (without the contents) while
+    preserving their attributes.
     """
 
     destparent = os.path.dirname(dest)
 
     if not os.path.exists(destparent):
         sourceparent = os.path.dirname(source)
-        copydirs(sourceparent, destparent, uid=uid, gid=gid, force=force)
+        copydirs(sourceparent, destparent, uid=uid, gid=gid, mode=mode, force=force)
 
     logger.debug('Command: mkdir %s', dest)
 
@@ -241,9 +268,13 @@ def copydirs(source, dest, uid=-1, gid=-1, force=False):
         gid = stat.st_gid
 
     os.utime(dest, (stat.st_atime, stat.st_mtime))
-    os.chmod(dest, stat.st_mode)
     os.chown(dest, uid, gid)
 
+    if mode is None:
+        mode = stat.st_mode
+
+    os.chmod(dest, mode)
+
 
 def chown(path, uid, gid):
     """
@@ -263,19 +294,19 @@ def chown(path, uid, gid):
         chown(itempath, uid, gid)
 
 
-def chmod(path, perms):
+def chmod(path, mode):
     """
     Change permissions of a file, link, or folder recursively.
     """
 
-    os.chmod(path, perms)
+    os.chmod(path, mode)
 
     if not os.path.isdir(path):
         return
 
     for item in os.listdir(path):
         itempath = os.path.join(path, item)
-        chmod(itempath, perms)
+        chmod(itempath, mode)
 
 
 def remove(path, force=False):
@@ -316,7 +347,9 @@ def customize_file(input_file, output_file, params):
     Customize a file with specified parameters.
     """
 
-    with open(input_file) as infile, open(output_file, 'w') as outfile:
+    with open(input_file, encoding='utf-8') as infile, \
+            open(output_file, 'w', encoding='utf-8') as outfile:
+
         for line in infile:
             for src, target in params.items():
                 line = line.replace(src, target)
@@ -325,7 +358,7 @@ def customize_file(input_file, output_file, params):
 
 def load_properties(filename, properties):
 
-    with open(filename) as f:
+    with open(filename, encoding='utf-8') as f:
 
         lines = f.read().splitlines()
         name = None
@@ -369,11 +402,36 @@ def load_properties(filename, properties):
 
 def store_properties(filename, properties):
 
-    with open(filename, 'w') as f:
+    sorted_props = sorted(properties.items(), key=operator.itemgetter(0))
 
-        for name, value in properties.items():
-            line = '%s=%s\n' % (name, value)
-            f.write(line)
+    with io.open(filename, 'w', encoding='utf-8') as f:
+
+        for name, value in sorted_props:
+
+            if value is None:
+                # write None as empty value
+                f.write('{0}=\n'.format(name))
+
+            elif isinstance(value, six.string_types):
+                f.write('{0}={1}\n'.format(name, value))
+
+            elif isinstance(value, six.integer_types):
+                f.write('{0}={1:d}\n'.format(name, value))
+
+            else:
+                raise TypeError((name, value, type(value)))
+
+
+def set_property(properties, name, value):
+
+    if value is None:  # no change
+        return
+
+    if value:  # non-empty value updates the property
+        properties[name] = value
+
+    else:  # empty value removes the property
+        properties.pop(name, None)
 
 
 def copytree(src, dst, symlinks=False, ignore=None):
@@ -465,14 +523,18 @@ def read_environment_files(env_file_list=None):
 
     for env_val in env_vals:
         (key, _, value) = env_val.partition("=")
-        if not key.strip() or key == u'_':
+        if not key.strip() or key == '_':
             continue
         os.environ[key] = value
 
 
 def read_text(message,
-              options=None, default=None, delimiter=':',
-              allow_empty=True, case_sensitive=True):
+              options=None,
+              default=None,
+              delimiter=':',
+              case_sensitive=True,
+              password=False,
+              required=False):
     """
     Get an input from the user. This is used, for example, in
     pkispawn and pkidestroy to obtain user input.
@@ -485,42 +547,58 @@ def read_text(message,
     :type default: str
     :param delimiter: delimiter to be used at the end of the prompt.
     :type delimiter: str
-    :param allow_empty: Allow input to be empty.
-    :type allow_empty: boolean -- True/False
     :param case_sensitive: Allow input to be case sensitive.
     :type case_sensitive: boolean -- True/False
+    :param password: Input is a password. Don't show the value.
+    :type password: boolean -- True/False
+    :param required: Input must be non-empty.
+    :type required: boolean -- True/False
     :returns: str -- value obtained from user input.
     """
-    if default:
-        message = message + ' [' + default + ']'
+
+    if default is not None:
+        if len(default) == 0:
+            message = message + ' []'
+        elif password:
+            message = message + ' [********]'
+        else:
+            message = message + ' [' + default + ']'
+
     message = message + delimiter + ' '
 
-    done = False
-    value = None
-    while not done:
-        value = input(message)
+    if options and not case_sensitive:
+        options = list(options)
+        for i in range(len(options)):
+            options[i] = options[i].lower()  # normalize options
+
+    while True:
+        if password:
+            value = getpass.getpass(message)
+        else:
+            value = input(message)
+
+        if not value:  # empty value
+            if not required:
+                return default
+            if default:
+                return default
+            continue
+
         value = value.strip()
 
-        if len(value) == 0:  # empty value
-            if allow_empty:
-                value = default
-                break
+        if not value:  # blank value
+            if not required:
+                return value
+            continue
 
-        else:  # non-empty value
-            if options is not None:
-                for val in options:
-                    if case_sensitive:
-                        if val == value:
-                            done = True
-                            break
-                    else:
-                        if val.lower() == value.lower():
-                            done = True
-                            break
-            else:
-                break
+        if options:  # non-empty options
+            if case_sensitive and value in options:
+                return value
+            if not case_sensitive and value.lower() in options:
+                return value
+            continue
 
-    return value
+        return value
 
 
 @functools.total_ordering
