@@ -24,6 +24,7 @@ import java.io.StringReader;
 import java.io.StringWriter;
 import java.util.Date;
 
+import javax.xml.XMLConstants;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.transform.OutputKeys;
@@ -42,7 +43,6 @@ import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
 import com.fasterxml.jackson.annotation.JsonInclude;
 import com.fasterxml.jackson.annotation.JsonInclude.Include;
 import com.fasterxml.jackson.annotation.JsonProperty;
-import com.netscape.certsrv.base.Link;
 import com.netscape.certsrv.dbs.certdb.CertId;
 import com.netscape.certsrv.util.JSONSerializer;
 
@@ -69,8 +69,6 @@ public class CertDataInfo implements JSONSerializer {
     Date revokedOn;
     String revokedBy;
 
-    Link link;
-
     public CertId getID() {
         return id;
     }
@@ -196,15 +194,6 @@ public class CertDataInfo implements JSONSerializer {
         this.revokedBy = revokedBy;
     }
 
-    @JsonProperty("Link")
-    public Link getLink() {
-        return link;
-    }
-
-    public void setLink(Link link) {
-        this.link = link;
-    }
-
     @Override
     public int hashCode() {
         final int prime = 31;
@@ -214,7 +203,6 @@ public class CertDataInfo implements JSONSerializer {
         result = prime * result + ((issuedOn == null) ? 0 : issuedOn.hashCode());
         result = prime * result + ((keyAlgorithmOID == null) ? 0 : keyAlgorithmOID.hashCode());
         result = prime * result + ((keyLength == null) ? 0 : keyLength.hashCode());
-        result = prime * result + ((link == null) ? 0 : link.hashCode());
         result = prime * result + ((notValidAfter == null) ? 0 : notValidAfter.hashCode());
         result = prime * result + ((notValidBefore == null) ? 0 : notValidBefore.hashCode());
         result = prime * result + ((status == null) ? 0 : status.hashCode());
@@ -261,11 +249,6 @@ public class CertDataInfo implements JSONSerializer {
                 return false;
         } else if (!keyLength.equals(other.keyLength))
             return false;
-        if (link == null) {
-            if (other.link != null)
-                return false;
-        } else if (!link.equals(other.link))
-            return false;
         if (notValidAfter == null) {
             if (other.notValidAfter != null)
                 return false;
@@ -400,11 +383,6 @@ public class CertDataInfo implements JSONSerializer {
             infoElement.appendChild(revokedByElement);
         }
 
-        if (link != null) {
-            Element linkElement = link.toDOM(document);
-            infoElement.appendChild(linkElement);
-        }
-
         return infoElement;
     }
 
@@ -492,14 +470,6 @@ public class CertDataInfo implements JSONSerializer {
             String value = revokedByList.item(0).getTextContent();
             info.setRevokedBy(value);
         }
-
-        NodeList linkList = infoElement.getElementsByTagName("Link");
-        if (linkList.getLength() > 0) {
-            Element linkElement = (Element) linkList.item(0);
-            Link link = Link.fromDOM(linkElement);
-            info.setLink(link);
-        }
-
         return info;
     }
 
@@ -513,6 +483,8 @@ public class CertDataInfo implements JSONSerializer {
         document.appendChild(infoElement);
 
         TransformerFactory transformerFactory = TransformerFactory.newInstance();
+        transformerFactory.setAttribute(XMLConstants.ACCESS_EXTERNAL_DTD, "");
+        transformerFactory.setAttribute(XMLConstants.ACCESS_EXTERNAL_STYLESHEET, "");
         Transformer transformer = transformerFactory.newTransformer();
         transformer.setOutputProperty(OutputKeys.INDENT, "yes");
         transformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", "4");
@@ -528,6 +500,7 @@ public class CertDataInfo implements JSONSerializer {
     public static CertDataInfo fromXML(String xml) throws Exception {
 
         DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+        factory.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
         DocumentBuilder builder = factory.newDocumentBuilder();
         Document document = builder.parse(new InputSource(new StringReader(xml)));
 
