@@ -20,6 +20,7 @@ package com.netscape.certsrv.request;
 import java.io.StringReader;
 import java.io.StringWriter;
 
+import javax.xml.XMLConstants;
 import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.transform.OutputKeys;
@@ -42,11 +43,20 @@ import com.netscape.certsrv.util.JSONSerializer;
 @JsonIgnoreProperties(ignoreUnknown=true)
 public class CMSRequestInfo implements JSONSerializer {
 
+    protected RequestId requestID;
     protected String requestType;
     protected RequestStatus requestStatus;
     protected String requestURL;
     protected String realm;
 
+    public RequestId getRequestID() {
+        return requestID;
+    }
+
+    public void setRequestID(RequestId requestID) {
+        this.requestID = requestID;
+    }
+
     /**
      * @return the requestType
      */
@@ -84,7 +94,9 @@ public class CMSRequestInfo implements JSONSerializer {
 
     /**
      * @return the request ID in the requestURL
+     * @deprecated Use getRequestID() instead.
      */
+    @Deprecated(since = "11.2.0", forRemoval = true)
     public RequestId getRequestId() {
 
         if (requestURL == null) {
@@ -115,6 +127,7 @@ public class CMSRequestInfo implements JSONSerializer {
         final int prime = 31;
         int result = 1;
         result = prime * result + ((realm == null) ? 0 : realm.hashCode());
+        result = prime * result + ((requestID == null) ? 0 : requestID.hashCode());
         result = prime * result + ((requestStatus == null) ? 0 : requestStatus.hashCode());
         result = prime * result + ((requestType == null) ? 0 : requestType.hashCode());
         result = prime * result + ((requestURL == null) ? 0 : requestURL.hashCode());
@@ -135,6 +148,11 @@ public class CMSRequestInfo implements JSONSerializer {
                 return false;
         } else if (!realm.equals(other.realm))
             return false;
+        if (requestID == null) {
+            if (other.requestID != null)
+                return false;
+        } else if (!requestID.equals(other.requestID))
+            return false;
         if (requestStatus == null) {
             if (other.requestStatus != null)
                 return false;
@@ -155,6 +173,12 @@ public class CMSRequestInfo implements JSONSerializer {
 
     public void toDOM(Document document, Element infoElement) {
 
+        if (requestID != null) {
+            Element requestTypeElement = document.createElement("requestID");
+            requestTypeElement.appendChild(document.createTextNode(requestID.toHexString()));
+            infoElement.appendChild(requestTypeElement);
+        }
+
         if (requestType != null) {
             Element requestTypeElement = document.createElement("requestType");
             requestTypeElement.appendChild(document.createTextNode(requestType));
@@ -188,6 +212,12 @@ public class CMSRequestInfo implements JSONSerializer {
 
     public static void fromDOM(Element infoElement, CMSRequestInfo info) {
 
+        NodeList requestIDList = infoElement.getElementsByTagName("requestID");
+        if (requestIDList.getLength() > 0) {
+            String value = requestIDList.item(0).getTextContent();
+            info.setRequestID(new RequestId(value));
+        }
+
         NodeList requestTypeList = infoElement.getElementsByTagName("requestType");
         if (requestTypeList.getLength() > 0) {
             String value = requestTypeList.item(0).getTextContent();
@@ -229,6 +259,8 @@ public class CMSRequestInfo implements JSONSerializer {
         document.appendChild(element);
 
         TransformerFactory transformerFactory = TransformerFactory.newInstance();
+        transformerFactory.setAttribute(XMLConstants.ACCESS_EXTERNAL_DTD, "");
+        transformerFactory.setAttribute(XMLConstants.ACCESS_EXTERNAL_STYLESHEET, "");
         Transformer transformer = transformerFactory.newTransformer();
         transformer.setOutputProperty(OutputKeys.INDENT, "yes");
         transformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", "4");
@@ -244,6 +276,7 @@ public class CMSRequestInfo implements JSONSerializer {
     public static CMSRequestInfo fromXML(String xml) throws Exception {
 
         DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
+        factory.setFeature("http://apache.org/xml/features/disallow-doctype-decl", true);
         DocumentBuilder builder = factory.newDocumentBuilder();
         Document document = builder.parse(new InputSource(new StringReader(xml)));
 
