@@ -10,17 +10,22 @@ import java.io.FileInputStream;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.HashSet;
+import java.util.HexFormat;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
+import java.util.Set;
 import java.util.Vector;
 import java.util.stream.Collectors;
 
+import org.dogtag.util.cert.CertUtil;
 import org.mozilla.jss.netscape.security.extensions.AuthInfoAccessExtension;
 import org.mozilla.jss.netscape.security.extensions.ExtendedKeyUsageExtension;
 import org.mozilla.jss.netscape.security.extensions.OCSPNoCheckExtension;
 import org.mozilla.jss.netscape.security.pkcs.PKCS10;
+import org.mozilla.jss.netscape.security.util.DerOutputStream;
 import org.mozilla.jss.netscape.security.util.ObjectIdentifier;
 import org.mozilla.jss.netscape.security.util.Utils;
 import org.mozilla.jss.netscape.security.x509.AuthorityKeyIdentifierExtension;
@@ -29,14 +34,19 @@ import org.mozilla.jss.netscape.security.x509.CPSuri;
 import org.mozilla.jss.netscape.security.x509.CertificatePoliciesExtension;
 import org.mozilla.jss.netscape.security.x509.CertificatePolicyId;
 import org.mozilla.jss.netscape.security.x509.CertificatePolicyInfo;
+import org.mozilla.jss.netscape.security.x509.DNSName;
+import org.mozilla.jss.netscape.security.x509.Extension;
 import org.mozilla.jss.netscape.security.x509.Extensions;
 import org.mozilla.jss.netscape.security.x509.GeneralName;
+import org.mozilla.jss.netscape.security.x509.GeneralNames;
 import org.mozilla.jss.netscape.security.x509.KeyIdentifier;
 import org.mozilla.jss.netscape.security.x509.KeyUsageExtension;
 import org.mozilla.jss.netscape.security.x509.PolicyQualifierInfo;
 import org.mozilla.jss.netscape.security.x509.PolicyQualifiers;
+import org.mozilla.jss.netscape.security.x509.SubjectAlternativeNameExtension;
 import org.mozilla.jss.netscape.security.x509.SubjectKeyIdentifierExtension;
 import org.mozilla.jss.netscape.security.x509.URIName;
+import org.mozilla.jss.netscape.security.x509.X500Name;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 import org.mozilla.jss.netscape.security.x509.X509Key;
 
@@ -49,6 +59,8 @@ public class NSSExtensionGenerator {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(NSSExtensionGenerator.class);
 
+    public static final HexFormat HEX_FORMAT = HexFormat.ofDelimiter(":");
+
     private Map<String, String> parameters = new LinkedHashMap<>();
 
     public NSSExtensionGenerator() {
@@ -155,15 +167,12 @@ public class NSSExtensionGenerator {
 
         logger.info("Creating AKID extension:");
 
-        boolean keyid = false;
-
         List<String> options = Arrays.asList(authorityKeyIdentifier.split("\\s*,\\s*"));
         for (String option : options) {
             option = option.trim();
             logger.info("- " + option);
 
             if (option.equals("keyid") || option.equals("keyid:always")) {
-                keyid = true;
                 continue;
             }
 
@@ -182,31 +191,42 @@ public class NSSExtensionGenerator {
         return new AuthorityKeyIdentifierExtension(keyID, null, null);
     }
 
-    public SubjectKeyIdentifierExtension createSKIDExtension(PKCS10 pkcs10) throws Exception {
+    public SubjectKeyIdentifierExtension createSKIDExtension(X509Key subjectKey) throws Exception {
 
-        if (pkcs10 == null) return null;
+        if (subjectKey == null) return null;
 
         String subjectKeyIdentifier = getParameter("subjectKeyIdentifier");
         if (subjectKeyIdentifier == null) return null;
 
         logger.info("Creating SKID extension:");
 
-        byte[] bytes;
+        boolean critical = false;
+        byte[] bytes = null;
 
-        if (subjectKeyIdentifier.equals("hash")) {
-            logger.info("- hash");
+        List<String> values = Arrays.asList(subjectKeyIdentifier.split(","));
+        for (String value : values) {
+            value = value.trim();
+            logger.info("- " + value);
 
-            X509Key subjectKey = pkcs10.getSubjectPublicKeyInfo();
-            bytes = CryptoUtil.generateKeyIdentifier(subjectKey.getKey());
+            if (value.equals("critical")) {
+                critical = true;
 
-        } else {
-            throw new Exception("Unsupported subjectKeyIdentifier: " + subjectKeyIdentifier);
+            } else if (value.equals("hash")) {
+                bytes = CryptoUtil.generateKeyIdentifier(subjectKey.getKey());
+
+            } else {
+                try {
+                    bytes = HEX_FORMAT.parseHex(value);
+                } catch (IllegalArgumentException e) {
+                    throw new IllegalArgumentException("Unsupported subject key identifier: " + value + ": " + e.getMessage(), e);
+                }
+            }
         }
 
         String skid = "0x" + Utils.HexEncode(bytes);
         logger.info("- SKID: " + skid);
 
-        return new SubjectKeyIdentifierExtension(bytes);
+        return new SubjectKeyIdentifierExtension(critical, bytes);
     }
 
     public AuthInfoAccessExtension createAIAExtension() throws Exception {
@@ -430,14 +450,148 @@ public class NSSExtensionGenerator {
         return new OCSPNoCheckExtension();
     }
 
-    public Extensions createExtensions() throws Exception {
-        return createExtensions(null, null);
+    public SubjectAlternativeNameExtension createSANExtension(PKCS10 pkcs10) throws Exception {
+
+        if (pkcs10 == null) return null;
+
+        String subjectAltName = getParameter("subjectAltName");
+        if (subjectAltName == null) return null;
+
+        List<String> options = Arrays.asList(subjectAltName.split("\\s*,\\s*"));
+        Set<String> dnsNames = new HashSet<>();
+
+        for (String option : options) {
+
+            if (option.equals("DNS:request_subject_cn")) {
+                X500Name subjectName = pkcs10.getSubjectName();
+                logger.info("Getting CN from subject name: " + subjectName);
+
+                String cn = CertUtil.getCommonName(subjectName);
+                if (cn != null) {
+                    cn = cn.toLowerCase();
+                    logger.info("- DNS:" + cn);
+                    dnsNames.add(cn);
+                }
+            }
+
+            if (option.equals("DNS:request_san_ext")) {
+                logger.info("Getting SAN extension from CSR");
+                SubjectAlternativeNameExtension sanExtension = CertUtil.getSANExtension(pkcs10);
+
+                if (sanExtension != null) {
+                    logger.info("Getting DNS names from SAN extension");
+                    Set<String> names = CertUtil.getDNSNames(sanExtension);
+
+                    for (String name : names) {
+                        logger.info("- DNS:" + name);
+                        dnsNames.add(name);
+                    }
+                }
+            }
+        }
+
+        logger.info("Converting DNS names to general names");
+        GeneralNames generalNames = new GeneralNames();
+        for (String name : dnsNames) {
+            generalNames.add(new DNSName(name));
+        }
+
+        logger.info("Creating SAN extension");
+        return new SubjectAlternativeNameExtension(generalNames);
     }
 
+    public Collection<Extension> createGenericExtensions() throws Exception {
+
+        String genericExtensions = getParameter("genericExtensions");
+        if (genericExtensions == null) return null;
+
+        List<String> oids = Arrays.asList(genericExtensions.split("\\s*,\\s*"));
+        List<Extension> extensions = new ArrayList<>();
+
+        for (String oid : oids) {
+            Extension extension = createGenericExtension(oid);
+            extensions.add(extension);
+        }
+
+        return extensions;
+    }
+
+    public Extension createGenericExtension(String oid) throws Exception {
+
+        logger.info("Creating " + oid + " extension:");
+
+        String value = getParameter(oid);
+        List<String> options = Arrays.asList(value.split("\\s*,\\s*"));
+        byte[] extValue = null;
+
+        boolean critical = false;
+
+        for (String option : options) {
+
+            if (option.equals("critical")) {
+                logger.info("- critical");
+                critical = true;
+                continue;
+            }
+
+            if (option.startsWith("DER:")) {
+                String hexValues = option.substring(4);
+                logger.info("- DER: " + hexValues);
+
+                String[] bytes = hexValues.split(":");
+                byte[] data = new byte[bytes.length];
+
+                for (int i=0; i<bytes.length; i++) {
+                    data[i] = (byte) Integer.parseInt(bytes[i], 16);
+                }
+
+                try (DerOutputStream os = new DerOutputStream()) {
+                    os.putOctetString(data);
+                    extValue = os.toByteArray();
+                }
+
+                continue;
+            }
+
+            throw new Exception("Unsupported option: " + option);
+        }
+
+        return new Extension(new ObjectIdentifier(oid), critical, extValue);
+    }
+
+    /**
+     * Create extensions.
+     */
+    public Extensions createExtensions() throws Exception {
+        return createExtensions(null, null, null);
+    }
+
+    /**
+     * Create extensions with the specified subject key.
+     */
+    public Extensions createExtensions(X509Key subjectKey) throws Exception {
+        return createExtensions(subjectKey, null, null);
+    }
+
+    /**
+     * Create extensions with the specified issuer and request.
+     */
     public Extensions createExtensions(
             org.mozilla.jss.crypto.X509Certificate issuer,
             PKCS10 pkcs10) throws Exception {
 
+        X509Key subjectKey = pkcs10.getSubjectPublicKeyInfo();
+        return createExtensions(subjectKey, issuer, pkcs10);
+    }
+
+    /**
+     * Create extensions with the specified subject key, issuer, and request.
+     */
+    public Extensions createExtensions(
+            X509Key subjectKey,
+            org.mozilla.jss.crypto.X509Certificate issuer,
+            PKCS10 pkcs10) throws Exception {
+
         Extensions extensions = new Extensions();
 
         BasicConstraintsExtension basicConstraintsExtension = createBasicConstraintsExtension();
@@ -450,7 +604,7 @@ public class NSSExtensionGenerator {
             extensions.parseExtension(akidExtension);
         }
 
-        SubjectKeyIdentifierExtension skidExtension = createSKIDExtension(pkcs10);
+        SubjectKeyIdentifierExtension skidExtension = createSKIDExtension(subjectKey);
         if (skidExtension != null) {
             extensions.parseExtension(skidExtension);
         }
@@ -480,6 +634,18 @@ public class NSSExtensionGenerator {
             extensions.parseExtension(ocspNoCheckExtension);
         }
 
+        SubjectAlternativeNameExtension sanExtension = createSANExtension(pkcs10);
+        if (sanExtension != null) {
+            extensions.parseExtension(sanExtension);
+        }
+
+        Collection<Extension> genericExtensions = createGenericExtensions();
+        if (genericExtensions != null) {
+            for (Extension extension : genericExtensions) {
+                extensions.parseExtension(extension);
+            }
+        }
+
         return extensions;
     }
 }
