@@ -1,10 +1,12 @@
 package com.netscape.certsrv.cert;
 
-import org.junit.Assert;
+import static org.junit.Assert.assertEquals;
+
 import org.junit.Before;
 import org.junit.Test;
 
 import com.netscape.certsrv.dbs.certdb.CertId;
+import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.certsrv.util.JSONSerializer;
 
@@ -14,6 +16,7 @@ public class CertRequestInfoTest {
 
     @Before
     public void setUpBefore() {
+        before.setRequestID(new RequestId("0x1"));
         before.setRequestType("enrollment");
         before.setRequestStatus(RequestStatus.COMPLETE);
         before.setCertRequestType("pkcs10");
@@ -30,7 +33,7 @@ public class CertRequestInfoTest {
         System.out.println("JSON (after): " + afterJSON.toJSON());
 
         // Assert
-        Assert.assertEquals(before, afterJSON);
+        assertEquals(before, afterJSON);
     }
 
 }
