@@ -1,6 +1,7 @@
 package com.netscape.certsrv.cert;
 
-import org.junit.Assert;
+import static org.junit.Assert.assertEquals;
+
 import org.junit.Test;
 
 import com.netscape.certsrv.util.JSONSerializer;
@@ -19,7 +20,7 @@ public class CertSearchRequestTest {
         System.out.println("XML (after): " + afterXML.toXML());
 
         // Assert
-        Assert.assertEquals(before, afterXML);
+        assertEquals(before, afterXML);
     }
 
     @Test
@@ -32,7 +33,7 @@ public class CertSearchRequestTest {
         System.out.println("JSON (after): " + afterJSON.toJSON());
 
         // Assert
-        Assert.assertEquals(before, afterJSON);
+        assertEquals(before, afterJSON);
     }
 
 
