@@ -25,7 +25,9 @@ package com.netscape.admin.certsrv;
  * @author Jack Pan-Chen
  * @version $Revision$, $Date$
  * @see com.netscape.admin.certsrv
+ * @deprecated The PKI console will be removed once there are CLI equivalents of desired console features.
  */
+@Deprecated(since="10.14.0", forRemoval=true)
 public class CellEditorData {
     public Object mData;
     public String mType;
