@@ -22,7 +22,9 @@ package com.netscape.admin.certsrv.config;
  *
  * @author Christine Ho
  * @version $Revision$, $Date$
+ * @deprecated The PKI console will be removed once there are CLI equivalents of desired console features.
  */
+@Deprecated(since="10.14.0", forRemoval=true)
 public class CMSRALDAPPanel extends CMSBaseLDAPPanel {
 
     private static String PANEL_NAME = "RALDAPSETTING";
