@@ -62,12 +62,12 @@ import com.netscape.certsrv.key.SymKeyGenerationRequest;
 import com.netscape.certsrv.kra.IKeyService;
 import com.netscape.certsrv.request.CMSRequestInfo;
 import com.netscape.certsrv.request.CMSRequestInfos;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.cms.servlet.request.CMSRequestDAO;
 import com.netscape.cmscore.dbs.KeyRepository;
 import com.netscape.cmscore.request.KeyRequestRepository;
+import com.netscape.cmscore.request.Request;
 import com.netscape.kra.KeyRecoveryAuthority;
 
 /**
@@ -93,11 +93,11 @@ public class KeyRequestDAO extends CMSRequestDAO {
         ASYMKEY_GEN_ALGORITHMS.put(KeyRequestResource.DSA_ALGORITHM, KeyPairAlgorithm.DSA);
     }
 
-    private static String REQUEST_ARCHIVE_OPTIONS = IRequest.REQUEST_ARCHIVE_OPTIONS;
-    private static String REQUEST_SECURITY_DATA = IRequest.REQUEST_SECURITY_DATA;
-    private static String REQUEST_SESSION_KEY = IRequest.REQUEST_SESSION_KEY;
-    private static String REQUEST_ALGORITHM_OID = IRequest.REQUEST_ALGORITHM_OID;
-    private static String REQUEST_ALGORITHM_PARAMS = IRequest.REQUEST_ALGORITHM_PARAMS;
+    private static String REQUEST_ARCHIVE_OPTIONS = Request.REQUEST_ARCHIVE_OPTIONS;
+    private static String REQUEST_SECURITY_DATA = Request.REQUEST_SECURITY_DATA;
+    private static String REQUEST_SESSION_KEY = Request.REQUEST_SESSION_KEY;
+    private static String REQUEST_ALGORITHM_OID = Request.REQUEST_ALGORITHM_OID;
+    private static String REQUEST_ALGORITHM_PARAMS = Request.REQUEST_ALGORITHM_PARAMS;
 
     public static final String ATTR_SERIALNO = "serialNumber";
 
@@ -149,8 +149,6 @@ public class KeyRequestDAO extends CMSRequestDAO {
         List<KeyRequestInfo> list = (List<KeyRequestInfo>) cmsList;
         ret.setEntries(list);
 
-        ret.setLinks(cmsInfos.getLinks());
-
         return ret;
     }
 
@@ -164,12 +162,12 @@ public class KeyRequestDAO extends CMSRequestDAO {
      * @throws EBaseException
      */
     public KeyRequestInfo getRequest(RequestId id, UriInfo uriInfo, IAuthToken authToken) throws EBaseException {
-        IRequest request = requestRepository.readRequest(id);
+        Request request = requestRepository.readRequest(id);
         if (request == null) {
             return null;
         }
 
-        authz.checkRealm(request.getRealm(), authToken, request.getExtDataInString(IRequest.ATTR_REQUEST_OWNER),
+        authz.checkRealm(request.getRealm(), authToken, request.getExtDataInString(Request.ATTR_REQUEST_OWNER),
                 "certServer.kra.request", "read");
 
         KeyRequestInfo info = createKeyRequestInfo(request, uriInfo);
@@ -208,7 +206,7 @@ public class KeyRequestDAO extends CMSRequestDAO {
 
         boolean ephemeral = kra.isEphemeral(realm);
         RequestId requestID = requestRepository.createRequestID(ephemeral);
-        IRequest request = requestRepository.createRequest(requestID, IRequest.SECURITY_DATA_ENROLLMENT_REQUEST);
+        Request request = requestRepository.createRequest(requestID, Request.SECURITY_DATA_ENROLLMENT_REQUEST);
 
         if (pkiArchiveOptions != null) {
             request.setExtData(REQUEST_ARCHIVE_OPTIONS, pkiArchiveOptions);
@@ -218,16 +216,16 @@ public class KeyRequestDAO extends CMSRequestDAO {
             request.setExtData(REQUEST_ALGORITHM_PARAMS, symkeyParams);
             request.setExtData(REQUEST_ALGORITHM_OID, algorithmOID);
         }
-        request.setExtData(IRequest.SECURITY_DATA_CLIENT_KEY_ID, clientKeyId);
-        request.setExtData(IRequest.SECURITY_DATA_TYPE, dataType);
-        request.setExtData(IRequest.SECURITY_DATA_STRENGTH,
+        request.setExtData(Request.SECURITY_DATA_CLIENT_KEY_ID, clientKeyId);
+        request.setExtData(Request.SECURITY_DATA_TYPE, dataType);
+        request.setExtData(Request.SECURITY_DATA_STRENGTH,
                 (keyStrength > 0) ? Integer.toString(keyStrength) : Integer.toString(0));
 
         if (keyAlgorithm != null) {
-            request.setExtData(IRequest.SECURITY_DATA_ALGORITHM, keyAlgorithm);
+            request.setExtData(Request.SECURITY_DATA_ALGORITHM, keyAlgorithm);
         }
 
-        request.setExtData(IRequest.ATTR_REQUEST_OWNER, owner);
+        request.setExtData(Request.ATTR_REQUEST_OWNER, owner);
 
         if (realm != null) {
             request.setRealm(realm);
@@ -243,7 +241,7 @@ public class KeyRequestDAO extends CMSRequestDAO {
         return createKeyRequestResponse(request, uriInfo);
     }
 
-    public IRequest createRecoveryRequest(KeyRecoveryRequest data, UriInfo uriInfo, String requestor,
+    public Request createRecoveryRequest(KeyRecoveryRequest data, UriInfo uriInfo, String requestor,
             IAuthToken authToken, boolean ephemeral) throws EBaseException{
         if (data == null) {
             throw new BadRequestException("Invalid request.");
@@ -279,28 +277,28 @@ public class KeyRequestDAO extends CMSRequestDAO {
         KeyRequestRepository requestRepository = engine.getKeyRequestRepository();
 
         RequestId requestID = requestRepository.createRequestID(ephemeral);
-        IRequest request = requestRepository.createRequest(requestID, IRequest.SECURITY_DATA_RECOVERY_REQUEST);
+        Request request = requestRepository.createRequest(requestID, Request.SECURITY_DATA_RECOVERY_REQUEST);
 
         if (rec.getRealm() != null) {
             request.setRealm(rec.getRealm());
         }
 
         request.setExtData(ATTR_SERIALNO, keyId.toString());
-        request.setExtData(IRequest.ATTR_REQUEST_OWNER, requestor);
-        request.setExtData(IRequest.ATTR_APPROVE_AGENTS, requestor);
+        request.setExtData(Request.ATTR_REQUEST_OWNER, requestor);
+        request.setExtData(Request.ATTR_APPROVE_AGENTS, requestor);
 
         String encryptOID = data.getPaylodEncryptionOID();
         if (encryptOID != null)
-            request.setExtData(IRequest.SECURITY_DATA_PL_ENCRYPTION_OID, encryptOID);
+            request.setExtData(Request.SECURITY_DATA_PL_ENCRYPTION_OID, encryptOID);
 
         String wrapName = data.getPayloadWrappingName();
         if (wrapName != null)
-            request.setExtData(IRequest.SECURITY_DATA_PL_WRAPPING_NAME, wrapName);
+            request.setExtData(Request.SECURITY_DATA_PL_WRAPPING_NAME, wrapName);
 
         return request;
     }
 
-    public void setTransientData(KeyRecoveryRequest data, IRequest request) throws EBaseException {
+    public void setTransientData(KeyRecoveryRequest data, Request request) throws EBaseException {
 
         Hashtable<String, Object> requestParams = getTransientData(request);
 
@@ -311,27 +309,27 @@ public class KeyRequestDAO extends CMSRequestDAO {
         String wrapName = data.getPayloadWrappingName();
 
         if (wrappedPassPhraseStr != null) {
-            requestParams.put(IRequest.SECURITY_DATA_SESS_PASS_PHRASE, wrappedPassPhraseStr);
+            requestParams.put(Request.SECURITY_DATA_SESS_PASS_PHRASE, wrappedPassPhraseStr);
         }
 
         if (wrappedSessionKeyStr != null) {
-            requestParams.put(IRequest.SECURITY_DATA_TRANS_SESS_KEY, wrappedSessionKeyStr);
+            requestParams.put(Request.SECURITY_DATA_TRANS_SESS_KEY, wrappedSessionKeyStr);
         }
 
         if (nonceDataStr != null) {
-            requestParams.put(IRequest.SECURITY_DATA_IV_STRING_IN, nonceDataStr);
+            requestParams.put(Request.SECURITY_DATA_IV_STRING_IN, nonceDataStr);
         }
 
         if (encryptOID != null) {
-            requestParams.put(IRequest.SECURITY_DATA_PL_ENCRYPTION_OID, encryptOID);
+            requestParams.put(Request.SECURITY_DATA_PL_ENCRYPTION_OID, encryptOID);
         }
 
         if (wrapName != null) {
-            requestParams.put(IRequest.SECURITY_DATA_PL_WRAPPING_NAME, wrapName);
+            requestParams.put(Request.SECURITY_DATA_PL_WRAPPING_NAME, wrapName);
         }
     }
 
-    public Hashtable<String, Object> getTransientData(IRequest request) throws EBaseException {
+    public Hashtable<String, Object> getTransientData(Request request) throws EBaseException {
 
         KRAEngine engine = KRAEngine.getInstance();
         KeyRecoveryAuthority kra = (KeyRecoveryAuthority) engine.getSubsystem(KeyRecoveryAuthority.ID);
@@ -359,7 +357,7 @@ public class KeyRequestDAO extends CMSRequestDAO {
     public KeyRequestResponse submitRequest(KeyRecoveryRequest data, UriInfo uriInfo, String requestor,
             IAuthToken authToken)
             throws EBaseException {
-        IRequest request = createRecoveryRequest(data, uriInfo, requestor, authToken, false);
+        Request request = createRecoveryRequest(data, uriInfo, requestor, authToken, false);
         setTransientData(data, request);
         queue.processRequest(request);
 
@@ -399,7 +397,7 @@ public class KeyRequestDAO extends CMSRequestDAO {
             e.printStackTrace();
             throw new PKIException(e.toString(), e);
         }
-        IRequest request = null;
+        Request request = null;
         try {
             request = requestRepository.readRequest(new RequestId(requestId));
         } catch (EBaseException e) {
@@ -449,19 +447,19 @@ public class KeyRequestDAO extends CMSRequestDAO {
 
         KRAEngine engine = KRAEngine.getInstance();
         KeyRequestRepository requestRepository = engine.getKeyRequestRepository();
-        IRequest request = requestRepository.createRequest(IRequest.SYMKEY_GENERATION_REQUEST);
+        Request request = requestRepository.createRequest(Request.SYMKEY_GENERATION_REQUEST);
 
-        request.setExtData(IRequest.KEY_GEN_ALGORITHM, algName);
-        request.setExtData(IRequest.KEY_GEN_SIZE, keySize);
-        request.setExtData(IRequest.SECURITY_DATA_STRENGTH, keySize);
-        request.setExtData(IRequest.SECURITY_DATA_ALGORITHM, algName);
+        request.setExtData(Request.KEY_GEN_ALGORITHM, algName);
+        request.setExtData(Request.KEY_GEN_SIZE, keySize);
+        request.setExtData(Request.SECURITY_DATA_STRENGTH, keySize);
+        request.setExtData(Request.SECURITY_DATA_ALGORITHM, algName);
 
-        request.setExtData(IRequest.KEY_GEN_USAGES, StringUtils.join(usages, ","));
-        request.setExtData(IRequest.SECURITY_DATA_CLIENT_KEY_ID, clientKeyId);
-        request.setExtData(IRequest.ATTR_REQUEST_OWNER, owner);
+        request.setExtData(Request.KEY_GEN_USAGES, StringUtils.join(usages, ","));
+        request.setExtData(Request.SECURITY_DATA_CLIENT_KEY_ID, clientKeyId);
+        request.setExtData(Request.ATTR_REQUEST_OWNER, owner);
 
         if (transWrappedSessionKey != null) {
-            request.setExtData(IRequest.KEY_GEN_TRANS_WRAPPED_SESSION_KEY,
+            request.setExtData(Request.KEY_GEN_TRANS_WRAPPED_SESSION_KEY,
                     transWrappedSessionKey);
         }
 
@@ -539,23 +537,23 @@ public class KeyRequestDAO extends CMSRequestDAO {
         }
 
         KeyRequestRepository requestRepository = engine.getKeyRequestRepository();
-        IRequest request = requestRepository.createRequest(IRequest.ASYMKEY_GENERATION_REQUEST);
+        Request request = requestRepository.createRequest(Request.ASYMKEY_GENERATION_REQUEST);
 
-        request.setExtData(IRequest.KEY_GEN_ALGORITHM, algName);
-        request.setExtData(IRequest.KEY_GEN_SIZE, keySize);
-        request.setExtData(IRequest.SECURITY_DATA_STRENGTH, keySize);
-        request.setExtData(IRequest.SECURITY_DATA_ALGORITHM, algName);
+        request.setExtData(Request.KEY_GEN_ALGORITHM, algName);
+        request.setExtData(Request.KEY_GEN_SIZE, keySize);
+        request.setExtData(Request.SECURITY_DATA_STRENGTH, keySize);
+        request.setExtData(Request.SECURITY_DATA_ALGORITHM, algName);
 
-        request.setExtData(IRequest.KEY_GEN_USAGES, StringUtils.join(usages, ","));
-        request.setExtData(IRequest.SECURITY_DATA_CLIENT_KEY_ID, clientKeyId);
-        request.setExtData(IRequest.ATTR_REQUEST_OWNER, owner);
+        request.setExtData(Request.KEY_GEN_USAGES, StringUtils.join(usages, ","));
+        request.setExtData(Request.SECURITY_DATA_CLIENT_KEY_ID, clientKeyId);
+        request.setExtData(Request.ATTR_REQUEST_OWNER, owner);
 
         if (realm != null) {
             request.setRealm(realm);
         }
 
         if (transWrappedSessionKey != null) {
-            request.setExtData(IRequest.KEY_GEN_TRANS_WRAPPED_SESSION_KEY,
+            request.setExtData(Request.KEY_GEN_TRANS_WRAPPED_SESSION_KEY,
                     transWrappedSessionKey);
         }
 
@@ -567,45 +565,47 @@ public class KeyRequestDAO extends CMSRequestDAO {
 
     public void approveRequest(RequestId id, String requestor, IAuthToken authToken)
             throws EBaseException {
-        IRequest request = requestRepository.readRequest(id);
+        Request request = requestRepository.readRequest(id);
         authz.checkRealm(request.getRealm(), authToken,
-                request.getExtDataInString(IRequest.ATTR_REQUEST_OWNER),
+                request.getExtDataInString(Request.ATTR_REQUEST_OWNER),
                 "certServer.kra.requests", "execute");
 
         service.addAgentAsyncKeyRecovery(id.toString(), requestor);
     }
 
     public void rejectRequest(RequestId id, IAuthToken authToken) throws EBaseException {
-        IRequest request = requestRepository.readRequest(id);
+        Request request = requestRepository.readRequest(id);
         String realm = request.getRealm();
         authz.checkRealm(realm, authToken,
-                request.getExtDataInString(IRequest.ATTR_REQUEST_OWNER),
+                request.getExtDataInString(Request.ATTR_REQUEST_OWNER),
                 "certServer.kra.requests", "execute");
         request.setRequestStatus(RequestStatus.REJECTED);
-        queue.updateRequest(request);
+        requestRepository.updateRequest(request);
     }
 
     public void cancelRequest(RequestId id, IAuthToken authToken) throws EBaseException {
-        IRequest request = requestRepository.readRequest(id);
+        Request request = requestRepository.readRequest(id);
         String realm = request.getRealm();
         authz.checkRealm(realm, authToken,
-                request.getExtDataInString(IRequest.ATTR_REQUEST_OWNER),
+                request.getExtDataInString(Request.ATTR_REQUEST_OWNER),
                 "certServer.kra.requests", "execute");
         request.setRequestStatus(RequestStatus.CANCELED);
-        queue.updateRequest(request);
+        requestRepository.updateRequest(request);
     }
 
-    private KeyRequestInfo createKeyRequestInfo(IRequest request, UriInfo uriInfo) {
+    private KeyRequestInfo createKeyRequestInfo(Request request, UriInfo uriInfo) {
         KeyRequestInfo ret = new KeyRequestInfo();
 
+        RequestId requestID = request.getRequestId();
+        ret.setRequestID(requestID);
+
         ret.setRequestType(request.getRequestType());
         ret.setRequestStatus(request.getRequestStatus());
 
         Path keyRequestPath = KeyRequestResource.class.getAnnotation(Path.class);
-        RequestId rid = request.getRequestId();
 
         UriBuilder reqBuilder = uriInfo.getBaseUriBuilder();
-        reqBuilder.path(keyRequestPath.value() + "/" + rid);
+        reqBuilder.path(keyRequestPath.value() + "/" + requestID);
         ret.setRequestURL(reqBuilder.build().toString());
 
         Path keyPath = KeyResource.class.getAnnotation(Path.class);
@@ -625,13 +625,13 @@ public class KeyRequestDAO extends CMSRequestDAO {
         return ret;
     }
 
-    private KeyData createKeyData(IRequest request, UriInfo uriInfo) {
+    private KeyData createKeyData(Request request, UriInfo uriInfo) {
         // TODO - to be implemented when we enable one-shot generation and recovery
         // with retrieval
         return null;
     }
 
-    private KeyRequestResponse createKeyRequestResponse(IRequest request, UriInfo uriInfo) {
+    private KeyRequestResponse createKeyRequestResponse(Request request, UriInfo uriInfo) {
         KeyRequestResponse response = new KeyRequestResponse();
         response.setRequestInfo(createKeyRequestInfo(request, uriInfo));
         response.setKeyData(createKeyData(request, uriInfo));
@@ -639,11 +639,11 @@ public class KeyRequestDAO extends CMSRequestDAO {
     }
 
     @Override
-    public KeyRequestInfo createCMSRequestInfo(IRequest request, UriInfo uriInfo) {
+    public KeyRequestInfo createCMSRequestInfo(Request request, UriInfo uriInfo) {
         return createKeyRequestInfo(request, uriInfo);
     }
 
-    public KeyRequestResponse createCMSRequestResponse(IRequest request, UriInfo uriInfo) {
+    public KeyRequestResponse createCMSRequestResponse(Request request, UriInfo uriInfo) {
         return createKeyRequestResponse(request, uriInfo);
     }
 
