@@ -36,7 +36,6 @@ import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 import org.mozilla.jss.netscape.security.x509.X509Key;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.common.Constants;
 import com.netscape.certsrv.common.NameValuePairs;
@@ -44,6 +43,7 @@ import com.netscape.certsrv.dbs.crldb.ICRLIssuingPointRecord;
 import com.netscape.certsrv.dbs.repository.IRepositoryRecord;
 import com.netscape.certsrv.ocsp.IDefStore;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.base.ConfigStore;
 import com.netscape.cmscore.dbs.DBSubsystem;
 import com.netscape.cmsutil.ocsp.CertID;
 import com.netscape.cmsutil.ocsp.CertStatus;
@@ -58,7 +58,7 @@ import netscape.ldap.LDAPConnection;
 import netscape.ldap.LDAPEntry;
 import netscape.ldap.LDAPException;
 import netscape.ldap.LDAPSearchResults;
-import netscape.ldap.LDAPv2;
+import netscape.ldap.LDAPv3;
 
 /**
  * This is the LDAP OCSP store. It reads CA certificate and
@@ -86,7 +86,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
     private final static String PROP_INCLUDE_NEXT_UPDATE =
             "includeNextUpdate";
 
-    private IConfigStore mConfig = null;
+    private ConfigStore mConfig;
     private String mId = null;
     private String mCRLAttr = null;
     private boolean mByName = true;
@@ -106,6 +106,10 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
     }
 
     @Override
+    public String[] getExtendedPluginInfo() {
+        return getExtendedPluginInfo(Locale.getDefault());
+    }
+
     public String[] getExtendedPluginInfo(Locale locale) {
         Vector<String> v = new Vector<>();
 
@@ -127,7 +131,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
      * Fetch CA certificate and CRL from LDAP server.
      */
     @Override
-    public void init(IConfigStore config, DBSubsystem dbSubsystem) throws EBaseException {
+    public void init(ConfigStore config, DBSubsystem dbSubsystem) throws EBaseException {
 
         mConfig = config;
 
@@ -145,7 +149,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
             throws EBaseException {
         try {
             LDAPSearchResults results = conn.search(baseDN,
-                    LDAPv2.SCOPE_SUB, mCACertAttr + "=*",
+                    LDAPv3.SCOPE_SUB, mCACertAttr + "=*",
                     null, false);
 
             if (!results.hasMoreElements()) {
@@ -176,7 +180,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
             throws EBaseException {
         try {
             LDAPSearchResults results = conn.search(baseDN,
-                    LDAPv2.SCOPE_SUB, mCRLAttr + "=*",
+                    LDAPv3.SCOPE_SUB, mCRLAttr + "=*",
                     null, false);
 
             if (!results.hasMoreElements()) {
@@ -210,7 +214,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
                 return; // no update
             }
         }
-        logger.debug("Added '" + caCert.getSubjectDN() + "' into CRL hash");
+        logger.debug("Added '" + caCert.getSubjectName() + "' into CRL hash");
         mCRLs.put(caCert, crl);
     }
 
@@ -242,7 +246,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
     public void shutdown() {
     }
 
-    public IConfigStore getConfigStore() {
+    public ConfigStore getConfigStore() {
         return mConfig;
     }
 
@@ -393,7 +397,7 @@ public class LDAPStore implements IDefStore, IExtendedPluginInfo {
             }
 
             theCert = caCert;
-            incReqCount(caCert.getSubjectDN().toString());
+            incReqCount(caCert.getSubjectName().toString());
             theCRL = mCRLs.get(caCert);
             break;
         }
@@ -537,7 +541,7 @@ class TempCRLIssuingPointRecord implements ICRLIssuingPointRecord {
 
     @Override
     public String getId() {
-        return mCACert.getSubjectDN().toString();
+        return mCACert.getSubjectName().toString();
     }
 
     /**
