@@ -38,8 +38,7 @@ logger = logging.getLogger(__name__)
 class AuditCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditCLI, self).__init__(
-            'audit', 'Audit management commands')
+        super().__init__('audit', 'Audit management commands')
 
         self.parent = parent
         self.add_module(AuditConfigShowCLI(self))
@@ -93,8 +92,7 @@ class AuditCLI(pki.cli.CLI):
 class AuditConfigShowCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditConfigShowCLI, self).__init__(
-            'config-show', 'Display audit configuration')
+        super().__init__('config-show', 'Display audit configuration')
         self.parent = parent
 
     def print_help(self):
@@ -138,7 +136,7 @@ class AuditConfigShowCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -159,8 +157,7 @@ class AuditConfigShowCLI(pki.cli.CLI):
 class AuditConfigModifyCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditConfigModifyCLI, self).__init__(
-            'config-mod', 'Modify audit configuration')
+        super().__init__('config-mod', 'Modify audit configuration')
         self.parent = parent
 
     def print_help(self):
@@ -267,7 +264,7 @@ class AuditConfigModifyCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -327,8 +324,7 @@ class AuditConfigModifyCLI(pki.cli.CLI):
 class AuditEventFindCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditEventFindCLI, self).__init__(
-            'event-find', 'Find audit event configurations')
+        super().__init__('event-find', 'Find audit event configurations')
 
         self.parent = parent
 
@@ -391,7 +387,7 @@ class AuditEventFindCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -424,8 +420,7 @@ class AuditEventFindCLI(pki.cli.CLI):
 class AuditEventShowCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditEventShowCLI, self).__init__(
-            'event-show', 'Show audit event configuration')
+        super().__init__('event-show', 'Show audit event configuration')
 
         self.parent = parent
 
@@ -480,7 +475,7 @@ class AuditEventShowCLI(pki.cli.CLI):
 
         event_name = args[0]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -502,8 +497,7 @@ class AuditEventShowCLI(pki.cli.CLI):
 class AuditEventEnableCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditEventEnableCLI, self).__init__(
-            'event-enable', 'Enable audit event configurations')
+        super().__init__('event-enable', 'Enable audit event configurations')
 
         self.parent = parent
 
@@ -556,7 +550,7 @@ class AuditEventEnableCLI(pki.cli.CLI):
             raise getopt.GetoptError("Too many arguments specified.")
         event_name = args[0]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -591,8 +585,7 @@ class AuditEventEnableCLI(pki.cli.CLI):
 class AuditEventUpdateCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditEventUpdateCLI, self).__init__(
-            'event-update', 'Update audit event configurations')
+        super().__init__('event-update', 'Update audit event configurations')
 
         self.parent = parent
 
@@ -651,7 +644,7 @@ class AuditEventUpdateCLI(pki.cli.CLI):
 
         event_name = args[0]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -675,8 +668,7 @@ class AuditEventUpdateCLI(pki.cli.CLI):
 class AuditEventDisableCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditEventDisableCLI, self).__init__(
-            'event-disable', 'Disable audit event configurations')
+        super().__init__('event-disable', 'Disable audit event configurations')
 
         self.parent = parent
 
@@ -730,7 +722,7 @@ class AuditEventDisableCLI(pki.cli.CLI):
 
         event_name = args[0]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -765,8 +757,7 @@ class AuditEventDisableCLI(pki.cli.CLI):
 class AuditFileFindCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditFileFindCLI, self).__init__(
-            'file-find', 'Find audit log files')
+        super().__init__('file-find', 'Find audit log files')
 
         self.parent = parent
 
@@ -812,7 +803,7 @@ class AuditFileFindCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -843,8 +834,7 @@ class AuditFileFindCLI(pki.cli.CLI):
 class AuditFileVerifyCLI(pki.cli.CLI):
 
     def __init__(self, parent):
-        super(AuditFileVerifyCLI, self).__init__(
-            'file-verify', 'Verify audit log files')
+        super().__init__('file-verify', 'Verify audit log files')
 
         self.parent = parent
 
@@ -890,7 +880,7 @@ class AuditFileVerifyCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
@@ -913,7 +903,7 @@ class AuditFileVerifyCLI(pki.cli.CLI):
         try:
             file_list = os.path.join(tmpdir, 'audit.txt')
 
-            with open(file_list, 'w') as f:
+            with open(file_list, 'w', encoding='utf-8') as f:
                 for filename in log_files:
                     f.write(os.path.join(log_dir, filename) + '\n')
 
