@@ -32,8 +32,7 @@ import pki.server.instance
 class NSSCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(NSSCLI, self).__init__(
-            'nss', 'NSS management commands')
+        super().__init__('nss', 'NSS management commands')
 
         self.add_module(NSSCreateCLI())
         self.add_module(NSSRemoveCLI())
@@ -42,8 +41,7 @@ class NSSCLI(pki.cli.CLI):
 class NSSCreateCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(NSSCreateCLI, self).__init__(
-            'create', 'Create NSS database in PKI server')
+        super().__init__('create', 'Create NSS database in PKI server')
 
     def print_help(self):
         print('Usage: pki-server nss-create [OPTIONS]')
@@ -110,7 +108,7 @@ class NSSCreateCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             raise Exception('Invalid instance: %s' % instance_name)
 
         instance.load()
@@ -122,7 +120,7 @@ class NSSCreateCLI(pki.cli.CLI):
             pass
 
         elif password_file is not None:
-            with open(password_file) as f:
+            with open(password_file, encoding='utf-8') as f:
                 password = f.read().splitlines()[0]
 
         else:
@@ -137,8 +135,7 @@ class NSSCreateCLI(pki.cli.CLI):
 class NSSRemoveCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(NSSRemoveCLI, self).__init__(
-            'remove', 'Remove NSS database in PKI server')
+        super().__init__('remove', 'Remove NSS database in PKI server')
 
     def print_help(self):
         print('Usage: pki-server nss-remove [OPTIONS]')
@@ -190,7 +187,7 @@ class NSSRemoveCLI(pki.cli.CLI):
 
         instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
-        if not instance.is_valid():
+        if not instance.exists():
             raise Exception('Invalid instance: %s' % instance_name)
 
         if not force:
