@@ -42,8 +42,7 @@ logger = logging.getLogger(__name__)
 class SubsystemCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCLI, self).__init__('subsystem',
-                                           'Subsystem management commands')
+        super().__init__('subsystem', 'Subsystem management commands')
 
         self.add_module(SubsystemDisableCLI())
         self.add_module(SubsystemEnableCLI())
@@ -62,7 +61,7 @@ class SubsystemCLI(pki.cli.CLI):
 class SubsystemFindCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemFindCLI, self).__init__('find', 'Find subsystems')
+        super().__init__('find', 'Find subsystems')
 
     def usage(self):
         print('Usage: pki-server subsystem-find [OPTIONS]')
@@ -106,7 +105,7 @@ class SubsystemFindCLI(pki.cli.CLI):
                 self.usage()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -129,7 +128,7 @@ class SubsystemFindCLI(pki.cli.CLI):
 class SubsystemShowCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemShowCLI, self).__init__('show', 'Show subsystem')
+        super().__init__('show', 'Show subsystem')
 
     def usage(self):
         print('Usage: pki-server subsystem-show [OPTIONS] <subsystem ID>')
@@ -180,7 +179,7 @@ class SubsystemShowCLI(pki.cli.CLI):
 
         subsystem_name = args[0]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -197,10 +196,183 @@ class SubsystemShowCLI(pki.cli.CLI):
         SubsystemCLI.print_subsystem(subsystem)
 
 
+class SubsystemDeployCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super().__init__('deploy', 'Deploy %s subsystem' % parent.name.upper())
+        self.parent = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-deploy [OPTIONS] [name]' % self.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --wait                         Wait until started.')
+        print('      --max-wait <seconds>           Maximum wait time (default: 60).')
+        print('      --timeout <seconds>            Connection timeout.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+
+        try:
+            opts, args = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'wait', 'max-wait=', 'timeout=',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logger.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        name = self.parent.name
+        instance_name = 'pki-tomcat'
+        wait = False
+        max_wait = 60
+        timeout = None
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--wait':
+                wait = True
+
+            elif o == '--max-wait':
+                max_wait = int(a)
+
+            elif o == '--timeout':
+                timeout = int(a)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logger.error('Unknown option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        if len(args) > 0:
+            name = args[0]
+
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
+
+        if not instance.exists():
+            raise Exception('Invalid instance: %s' % instance_name)
+
+        instance.load()
+
+        descriptor = os.path.join(pki.server.PKIServer.SHARE_DIR,
+                                  '%s/conf/Catalina/localhost/%s.xml' % (name, name))
+        doc_base = os.path.join(pki.server.PKIServer.SHARE_DIR,
+                                '%s/webapps/%s' % (name, name))
+
+        logger.info('Deploying %s webapp', name)
+        instance.deploy_webapp(
+            name,
+            descriptor,
+            doc_base,
+            wait=wait,
+            max_wait=max_wait,
+            timeout=timeout)
+
+
+class SubsystemUndeployCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super().__init__('undeploy', 'Undeploy %s subsystem' % parent.name.upper())
+        self.parenet = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-undeploy [OPTIONS] [name]' % self.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --wait                         Wait until stopped.')
+        print('      --max-wait <seconds>           Maximum wait time (default: 60).')
+        print('      --timeout <seconds>            Connection timeout.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+
+        try:
+            opts, args = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'wait', 'max-wait=', 'timeout=',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logger.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        name = self.parent.name
+        instance_name = 'pki-tomcat'
+        wait = False
+        max_wait = 60
+        timeout = None
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--wait':
+                wait = True
+
+            elif o == '--max-wait':
+                max_wait = int(a)
+
+            elif o == '--timeout':
+                timeout = int(a)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logger.error('Unknown option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        if len(args) > 0:
+            name = args[0]
+
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
+
+        if not instance.exists():
+            raise Exception('Invalid instance: %s' % instance_name)
+
+        instance.load()
+
+        logger.info('Undeploying %s webapp', name)
+        instance.undeploy_webapp(
+            name,
+            wait=wait,
+            max_wait=max_wait,
+            timeout=timeout)
+
+
 class SubsystemEnableCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemEnableCLI, self).__init__('enable', 'Enable subsystem')
+        super().__init__('enable', 'Enable subsystem')
 
     def usage(self):
         print('Usage: pki-server subsystem-enable [OPTIONS] <subsystem ID>')
@@ -254,7 +426,7 @@ class SubsystemEnableCLI(pki.cli.CLI):
                 self.usage()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -301,9 +473,7 @@ class SubsystemEnableCLI(pki.cli.CLI):
 class SubsystemDisableCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemDisableCLI, self).__init__(
-            'disable',
-            'Disable subsystem')
+        super().__init__('disable', 'Disable subsystem')
 
     def usage(self):
         print('Usage: pki-server subsystem-disable [OPTIONS] <subsystem ID>')
@@ -352,7 +522,7 @@ class SubsystemDisableCLI(pki.cli.CLI):
                 self.usage()
                 sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -395,8 +565,7 @@ class SubsystemDisableCLI(pki.cli.CLI):
 class SubsystemCertCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCertCLI, self).__init__(
-            'cert', 'Subsystem certificate management commands')
+        super().__init__('cert', 'Subsystem certificate management commands')
 
         self.add_module(SubsystemCertFindCLI())
         self.add_module(SubsystemCertShowCLI())
@@ -424,8 +593,7 @@ class SubsystemCertCLI(pki.cli.CLI):
 class SubsystemCertFindCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCertFindCLI, self).__init__(
-            'find', 'Find subsystem certificates')
+        super().__init__('find', 'Find subsystem certificates')
 
     def print_help(self):
         print('Usage: pki-server subsystem-cert-find [OPTIONS] <subsystem ID>')
@@ -481,7 +649,7 @@ class SubsystemCertFindCLI(pki.cli.CLI):
 
         subsystem_name = args[0]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -517,8 +685,7 @@ class SubsystemCertFindCLI(pki.cli.CLI):
 class SubsystemCertShowCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCertShowCLI, self).__init__(
-            'show', 'Show subsystem certificate')
+        super().__init__('show', 'Show subsystem certificate')
 
     def usage(self):
         print('Usage: pki-server subsystem-cert-show [OPTIONS] <subsystem ID> <cert ID>')
@@ -580,7 +747,7 @@ class SubsystemCertShowCLI(pki.cli.CLI):
         subsystem_name = args[0]
         cert_id = args[1]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -601,8 +768,7 @@ class SubsystemCertShowCLI(pki.cli.CLI):
 class SubsystemCertExportCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCertExportCLI, self).__init__(
-            'export', 'Export subsystem certificate')
+        super().__init__('export', 'Export subsystem certificate')
 
     def print_help(self):
         print('Usage: pki-server subsystem-cert-export [OPTIONS] <subsystem ID> [cert ID]')
@@ -709,7 +875,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -740,7 +906,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
                 sys.exit(1)
 
             cert_data = pki.nssdb.convert_cert(cert_data, 'base64', 'pem')
-            with open(cert_file, 'w') as f:
+            with open(cert_file, 'w', encoding='utf-8') as f:
                 f.write(cert_data)
 
         if csr_file:
@@ -750,7 +916,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
                 sys.exit(1)
 
             csr_data = pki.nssdb.convert_csr(cert_request, 'base64', 'pem')
-            with open(csr_file, 'w') as f:
+            with open(csr_file, 'w', encoding='utf-8') as f:
                 f.write(csr_data)
 
         if pkcs12_file:
@@ -787,8 +953,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
 class SubsystemCertUpdateCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCertUpdateCLI, self).__init__(
-            'update', 'Update subsystem certificate')
+        super().__init__('update', 'Update subsystem certificate')
 
     def usage(self):
         print('Usage: pki-server subsystem-cert-update [OPTIONS] <subsystem ID> <cert ID>')
@@ -851,7 +1016,7 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
         subsystem_name = args[0]
         cert_id = args[1]
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
@@ -864,12 +1029,12 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
             logger.error('No %s subsystem in instance %s.',
                          subsystem_name, instance_name)
             sys.exit(1)
-        subsystem_cert = subsystem.get_subsystem_cert(cert_id)
+        system_cert = subsystem.get_subsystem_cert(cert_id)
 
         logger.info('Retrieving certificate %s from %s',
-                    subsystem_cert['nickname'], subsystem_cert['token'])
+                    system_cert['nickname'], system_cert['token'])
 
-        token = subsystem_cert['token']
+        token = system_cert['token']
         nssdb = instance.open_nssdb(token)
 
         if cert_file:
@@ -879,25 +1044,25 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
                 sys.exit(1)
 
             data = nssdb.get_cert(
-                nickname=subsystem_cert['nickname'],
+                nickname=system_cert['nickname'],
                 output_format='base64')
 
             if data:
                 logger.info('Removing old %s certificate from database.',
-                            subsystem_cert['nickname'])
-                nssdb.remove_cert(nickname=subsystem_cert['nickname'])
+                            system_cert['nickname'])
+                nssdb.remove_cert(nickname=system_cert['nickname'])
 
-            logger.info('Adding new %s certificate into database.', subsystem_cert['nickname'])
+            logger.info('Adding new %s certificate into database.', system_cert['nickname'])
             nssdb.add_cert(
-                nickname=subsystem_cert['nickname'],
+                nickname=system_cert['nickname'],
                 cert_file=cert_file)
 
         # Retrieve the cert info from NSSDB
         # Note: This reloads `data` object if --cert option is provided
         data = nssdb.get_cert(
-            nickname=subsystem_cert['nickname'],
+            nickname=system_cert['nickname'],
             output_format='base64')
-        subsystem_cert['data'] = data
+        system_cert['data'] = data
 
         # format cert data for LDAP database
         lines = [data[i:i + 64] for i in range(0, len(data), 64)]
@@ -924,13 +1089,13 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
             if lines[-1] == '-----END CERTIFICATE REQUEST-----':
                 lines = lines[:-1]
             request = ''.join(lines)
-            subsystem_cert['request'] = request
+            system_cert['request'] = request
 
         else:
             logger.warning('Certificate request not found')
 
         # store cert data and request in CS.cfg
-        subsystem.update_subsystem_cert(subsystem_cert)
+        subsystem.update_system_cert(system_cert)
         subsystem.save()
 
         self.print_message('Updated "%s" subsystem certificate' % cert_id)
@@ -939,8 +1104,7 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
 class SubsystemCertValidateCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(SubsystemCertValidateCLI, self).__init__(
-            'validate', 'Validate subsystem certificates')
+        super().__init__('validate', 'Validate subsystem certificates')
 
     def usage(self):
         print('Usage: pki-server subsystem-cert-validate [OPTIONS] <subsystem ID> [<cert_id>]')
@@ -996,7 +1160,7 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
         else:
             cert_id = None
 
-        instance = pki.server.instance.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.exists():
             logger.error('Invalid instance %s.', instance_name)
