@@ -34,7 +34,7 @@ logger = logging.getLogger(__name__)
 class UpgradeCLI(pki.cli.CLI):
 
     def __init__(self):
-        super(UpgradeCLI, self).__init__('upgrade', 'Upgrade PKI server')
+        super().__init__('upgrade', 'Upgrade PKI server')
 
     def usage(self):
         print('Usage: pki-server upgrade [OPTIONS] [<instance ID>]')
@@ -129,7 +129,7 @@ class UpgradeCLI(pki.cli.CLI):
             instance_name = args[0]
 
         if instance_name:
-            instance = pki.server.instance.PKIInstance(instance_name)
+            instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
             if not instance.exists():
                 raise Exception('Invalid instance: %s' % instance_name)
