@@ -42,17 +42,6 @@ PKI_DICTIONARY_WEB_SERVER = '''
 # NEVER print out 'sensitive' data dictionary!!!
 
 
-# PKI Deployment Log Messages
-PKI_VERBOSITY = '''
-VERBOSITY FLAGS    CONSOLE MESSAGE LEVEL       LOG MESSAGE LEVEL
-=======================================================================
-  NONE             error|warning               error|warning|info|debug
-  -v               error|warning|info          error|warning|info|debug
-  -vv              error|warning|info|debug    error|warning|info|debug
-
-'''
-
-
 # PKI Deployment Error Messages
 PKI_BADZIPFILE_ERROR_1 = "zipfile.BadZipFile:  %s!"
 PKI_RUN_INSTALLATION_STEP_TWO = '''
@@ -124,7 +113,7 @@ REMINDER:
     Finally, if an optional '-p <prefix>' is defined, this value WILL be
     prepended to the default PKI instance path which is placed in front
     of the specified '-i <instance>' parameter.
-''' + PKI_VERBOSITY
+'''
 PKISPAWN_BEGIN_MESSAGE_2 = \
     "BEGIN spawning %s subsystem in %s instance"
 PKISPAWN_END_MESSAGE_2 = \
@@ -141,7 +130,7 @@ REMINDER:
 
     Finally, if an optional '-p <prefix>' is defined, this value WILL NOT
     be prepended in front of the mandatory '-f <configuration_file>'.
-""" + PKI_VERBOSITY
+"""
 PKISPAWN_INTERACTIVE_INSTALLATION = '''
 IMPORTANT:
 
@@ -236,8 +225,6 @@ PKIHELPER_JAR_XF_C_2 = "jar -xf %s -C %s"
 PKIHELPER_KRACONNECTOR_UPDATE_FAILURE = "Failed to update KRA connector on CA"
 PKIHELPER_KRACONNECTOR_UPDATE_FAILURE_2 = \
     "Failed to update KRA connector for %s:%s"
-PKIHELPER_KRACONNECTOR_DEREGISTER_FAILURE_4 = \
-    "Failed to deregister KRA connector %s:%s from CA %s:%s"
 PKIHELPER_LINK_S_2 = "ln -s %s %s"
 PKIHELPER_MKDIR_1 = "mkdir -p %s"
 PKIHELPER_MODUTIL_MISSING_LIBFILE = \
@@ -294,8 +281,6 @@ PKIHELPER_SECURITY_DOMAIN_UNDEFINED = \
     "Otherwise, manually delete the entry from the security domain master."
 PKIHELPER_SECURITY_DOMAIN_UNREACHABLE_1 = \
     "security domain '%s' may be offline or unreachable!"
-PKIHELPER_SECURITY_DOMAIN_UNREGISTERED_2 = \
-    "this '%s' entry may not be registered with security domain '%s'!"
 PKIHELPER_SECURITY_DOMAIN_UPDATE_FAILURE_2 = \
     "this '%s' entry will NOT be deleted from security domain '%s'!"
 PKIHELPER_SECURITY_DOMAIN_UPDATE_FAILURE_3 = \
@@ -303,17 +288,9 @@ PKIHELPER_SECURITY_DOMAIN_UPDATE_FAILURE_3 = \
     "security domain '%s': '%s'"
 PKIHELPER_SELINUX_DISABLED = "Selinux is disabled.  Not checking port contexts"
 PKIHELPER_SET_MODE_1 = "Setting up ownerships, permissions, and ACLs on %s"
-PKIHELPER_SSLGET_OUTPUT_1 = '''
-    Dump of 'sslget' output:
-    =====================================================
-    %s
-    =====================================================
-'''
 PKIHELPER_SYSTEMD_COMMAND_1 = "executing '%s'"
 PKIHELPER_TOMCAT_INSTANCE_SUBSYSTEMS_2 = \
     "instance '%s' contains '%d' Tomcat PKI subsystems"
-PKIHELPER_TOMCAT_INSTANCES_2 = \
-    "PKI Tomcat registry '%s' contains '%d' Tomcat PKI instances"
 PKIHELPER_TOUCH_1 = "touch %s"
 PKIHELPER_TPSCONNECTOR_UPDATE_FAILURE = "Failed to update TPS connector on TKS"
 PKIHELPER_TPSCONNECTOR_UPDATE_FAILURE_2 = \
@@ -336,7 +313,6 @@ PKIHELPER_USER_ADD_DEFAULT_2 = "Adding default UID '%s' for user '%s'"
 PKIHELPER_USER_ADD_KEYERROR_1 = "KeyError:  pki_user %s"
 PKIHELPER_USER_ADD_UID_KEYERROR_1 = "KeyError:  pki_uid %s"
 
-PKI_CONFIG_ADMIN_CERT_SAVE_2 = "saving %s Admin Certificate to file: %s"
 PKI_CONFIG_ADMIN_CERT_ATOB_1 = "converting %s Admin Certificate to binary:"
 PKI_CONFIG_CONSTRUCTING_PKI_DATA = "constructing PKI configuration data."
 PKI_CONFIG_PKCS10_SUPPORT_ONLY = \
@@ -364,7 +340,6 @@ PKI_CONFIG_EXTERNAL_CSR_SAVE_KRA_TRANSPORT_1 = (
     "saving KRA Transport CSR to file: %s")
 PKI_CONFIG_EXTERNAL_CSR_SAVE_OCSP_SIGNING_1 = (
     "saving OCSP Signing CSR to file: %s")
-PKI_CONFIG_EXTERNAL_CSR_SAVE_PKI_ADMIN_2 = "saving %s Admin CSR to file: '%s'"
 PKI_CONFIG_EXTERNAL_CSR_SAVE_PKI_AUDIT_SIGNING_2 = \
     "saving %s Audit Signing CSR to file: %s"
 PKI_CONFIG_EXTERNAL_CSR_SAVE_PKI_SSLSERVER_2 = (
