@@ -40,7 +40,7 @@ from pki.server.deployment.pkiparser import PKIConfigParser
 from pki.server.deployment import pkilogging
 from pki.server.deployment import pkimessages as log
 
-logger = logging.getLogger('pkispawn')
+logger = logging.getLogger(__name__)
 
 deployer = pki.server.deployment.PKIDeployer()
 
@@ -106,6 +106,12 @@ def main(argv):
         help='configuration filename '
         '(MUST specify complete path)')
 
+    parser.optional.add_argument(
+        '-D',
+        dest='params', action='append',
+        metavar='<name>=<value>',
+        help='configuration parameter name and value')
+
     parser.optional.add_argument(
         '--precheck',
         dest='precheck', action='store_true',
@@ -135,6 +141,12 @@ def main(argv):
         action='store_true',
         help='Install Maven dependencies')
 
+    parser.optional.add_argument(
+        '--log-file',
+        dest='log_file',
+        action='store',
+        help='Log file')
+
     args = parser.process_command_line_arguments()
 
     config.default_deployment_cfg = \
@@ -526,6 +538,13 @@ def main(argv):
     if args.skip_installation:
         deployer.set_property('pki_skip_installation', 'True')
 
+    if args.params:
+        for param in args.params:
+            i = param.index('=')
+            name = param[0:i]
+            value = param[i + 1:]
+            deployer.set_property(name, value)
+
     create_master_dictionary(parser)
     deployer.init()
 
@@ -534,15 +553,10 @@ def main(argv):
         user=deployer.mdict['pki_user'],
         group=deployer.mdict['pki_group'])
 
-    log_dir = config.PKI_DEPLOYMENT_LOG_ROOT
-    log_name = "pki" + "-" + \
-               deployer.subsystem_name.lower() + \
-               "-" + "spawn" + "." + \
-               deployer.log_timestamp + "." + "log"
-    log_file = os.path.join(log_dir, log_name)
-    print('Installation log: %s' % log_file)
+    if args.log_file:
+        print('Installation log: %s' % args.log_file)
 
-    pkilogging.enable_pki_logger(log_file, 'pkispawn')
+    pkilogging.enable_pki_logger(args.log_file)
 
     if not interactive and \
             not config.str2bool(parser.mdict['pki_skip_configuration']):
@@ -580,8 +594,11 @@ def main(argv):
         print("Installation failed: Command failed: %s" % ' '.join(e.cmd))
         if e.output:
             print(e.output)
-        print()
-        print('Please check pkispawn logs in %s' % log_file)
+
+        if args.log_file:
+            print()
+            print('Please check pkispawn logs in %s' % args.log_file)
+
         sys.exit(1)
 
     except requests.HTTPError as e:
@@ -654,9 +671,15 @@ def main(argv):
         elif deployer.subsystem_name == 'KRA':
             print_kra_step_one_information(parser.mdict)
 
-        else:  # OCSP
+        elif deployer.subsystem_name == 'OCSP':
             print_ocsp_step_one_information(parser.mdict)
 
+        elif deployer.subsystem_name == 'TKS':
+            print_tks_step_one_information(parser.mdict)
+
+        elif deployer.subsystem_name == 'TPS':
+            print_tps_step_one_information(parser.mdict)
+
     else:
         print_final_install_information(parser.mdict)
 
@@ -853,6 +876,70 @@ def print_ocsp_step_one_information(mdict):
     print(log.PKI_SPAWN_INFORMATION_FOOTER)
 
 
+def print_tks_step_one_information(mdict):
+
+    print(log.PKI_SPAWN_INFORMATION_HEADER)
+    print("      The %s subsystem of the '%s' instance is still incomplete." %
+          (deployer.subsystem_name, mdict['pki_instance_name']))
+    print()
+    print("      NSS database: %s" % mdict['pki_server_database_path'])
+    print()
+
+    subsystem_csr = mdict['pki_subsystem_csr_path']
+    sslserver_csr = mdict['pki_sslserver_csr_path']
+    audit_csr = mdict['pki_audit_signing_csr_path']
+    admin_csr = mdict['pki_admin_csr_path']
+
+    if subsystem_csr or sslserver_csr or audit_csr or admin_csr:
+        print("      The CSRs for TKS certificates have been generated in:")
+    else:
+        print("      No CSRs have been generated for TKS certificates.")
+
+    if subsystem_csr:
+        print("          subsystem:     %s" % subsystem_csr)
+    if sslserver_csr:
+        print("          SSL server:    %s" % sslserver_csr)
+    if audit_csr:
+        print("          audit signing: %s" % audit_csr)
+    if admin_csr:
+        print("          admin:         %s" % admin_csr)
+
+    print(log.PKI_RUN_INSTALLATION_STEP_TWO)
+    print(log.PKI_SPAWN_INFORMATION_FOOTER)
+
+
+def print_tps_step_one_information(mdict):
+
+    print(log.PKI_SPAWN_INFORMATION_HEADER)
+    print("      The %s subsystem of the '%s' instance is still incomplete." %
+          (deployer.subsystem_name, mdict['pki_instance_name']))
+    print()
+    print("      NSS database: %s" % mdict['pki_server_database_path'])
+    print()
+
+    subsystem_csr = mdict['pki_subsystem_csr_path']
+    sslserver_csr = mdict['pki_sslserver_csr_path']
+    audit_csr = mdict['pki_audit_signing_csr_path']
+    admin_csr = mdict['pki_admin_csr_path']
+
+    if subsystem_csr or sslserver_csr or audit_csr or admin_csr:
+        print("      The CSRs for TPS certificates have been generated in:")
+    else:
+        print("      No CSRs have been generated for TpS certificates.")
+
+    if subsystem_csr:
+        print("          subsystem:     %s" % subsystem_csr)
+    if sslserver_csr:
+        print("          SSL server:    %s" % sslserver_csr)
+    if audit_csr:
+        print("          audit signing: %s" % audit_csr)
+    if admin_csr:
+        print("          admin:         %s" % admin_csr)
+
+    print(log.PKI_RUN_INSTALLATION_STEP_TWO)
+    print(log.PKI_SPAWN_INFORMATION_FOOTER)
+
+
 def print_skip_configuration_information(mdict):
 
     print(log.PKI_SPAWN_INFORMATION_HEADER)
