@@ -23,7 +23,6 @@ import java.io.FilenameFilter;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.util.Hashtable;
-import java.util.Locale;
 import java.util.Vector;
 
 import javax.servlet.ServletException;
@@ -31,7 +30,6 @@ import javax.servlet.ServletException;
 import org.mozilla.jss.netscape.security.util.Utils;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.common.Constants;
 import com.netscape.certsrv.common.NameValuePairs;
@@ -40,6 +38,7 @@ import com.netscape.certsrv.logging.ELogException;
 import com.netscape.certsrv.logging.ILogEvent;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.base.ConfigStore;
 
 /**
  * A rotating log file for Certificate log events. This class loosely follows
@@ -110,8 +109,7 @@ public class RollingLogFile extends LogFile {
      * @param config The property config store to find values in
      */
     @Override
-    public void init(IConfigStore config) throws IOException,
-            EBaseException {
+    public void init(ConfigStore config) throws IOException, EBaseException {
         super.init(config);
 
         rl_init(config.getInteger(Constants.PR_LOG_MAXFILESIZE, MAX_FILE_SIZE),
@@ -613,8 +611,8 @@ public class RollingLogFile extends LogFile {
     }
 
     @Override
-    public String[] getExtendedPluginInfo(Locale locale) {
-        String[] p = super.getExtendedPluginInfo(locale);
+    public String[] getExtendedPluginInfo() {
+        String[] p = super.getExtendedPluginInfo();
         Vector<String> info = new Vector<>();
 
         for (int i = 0; i < p.length; i++) {
