@@ -31,7 +31,6 @@ import java.security.cert.X509CRL;
 import java.security.cert.X509Certificate;
 import java.text.ParseException;
 import java.util.Arrays;
-import java.util.Locale;
 import java.util.TimeZone;
 import java.util.Vector;
 import java.util.regex.Matcher;
@@ -44,13 +43,13 @@ import org.mozilla.jss.netscape.security.util.Utils;
 import org.mozilla.jss.util.Base64OutputStream;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.IExtendedPluginInfo;
 import com.netscape.certsrv.ldap.ELdapException;
 import com.netscape.certsrv.publish.ILdapPublisher;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.base.ConfigStore;
 
 import netscape.ldap.LDAPConnection;
 
@@ -74,7 +73,7 @@ public class FileBasedPublisher implements ILdapPublisher, IExtendedPluginInfo {
     private static final String PROP_LEV = "zipLevel";
     private static final String PROP_MAX_AGE = "maxAge";
     private static final String PROP_MAX_FULL_CRLS = "maxFullCRLs";
-    private IConfigStore mConfig = null;
+    private ConfigStore mConfig;
     private String mDir = null;
     private String mCrlIssuingPointId;
     protected boolean mDerAttr = true;
@@ -109,7 +108,7 @@ public class FileBasedPublisher implements ILdapPublisher, IExtendedPluginInfo {
     }
 
     @Override
-    public String[] getExtendedPluginInfo(Locale locale) {
+    public String[] getExtendedPluginInfo() {
         String[] params = {
                 PROP_DIR
                         + ";string;Directory in which to put the files (absolute path or relative path to cert-* instance directory).",
@@ -213,7 +212,7 @@ public class FileBasedPublisher implements ILdapPublisher, IExtendedPluginInfo {
      * Initializes this plugin.
      */
     @Override
-    public void init(IConfigStore config) {
+    public void init(ConfigStore config) {
 
         CMSEngine engine = CMS.getCMSEngine();
         EngineConfig cs = engine.getConfig();
@@ -266,7 +265,7 @@ public class FileBasedPublisher implements ILdapPublisher, IExtendedPluginInfo {
     }
 
     @Override
-    public IConfigStore getConfigStore() {
+    public ConfigStore getConfigStore() {
         return mConfig;
     }
 
