@@ -63,12 +63,9 @@ import org.w3c.dom.Node;
 
 import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.authority.IAuthority;
-import com.netscape.certsrv.authority.ICertAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IArgBlock;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.SessionContext;
-import com.netscape.certsrv.common.ICMSRequest;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.LogEvent;
@@ -76,8 +73,6 @@ import com.netscape.certsrv.logging.LogSource;
 import com.netscape.certsrv.logging.event.AuthEvent;
 import com.netscape.certsrv.logging.event.AuthzEvent;
 import com.netscape.certsrv.logging.event.RoleAssumeEvent;
-import com.netscape.certsrv.ra.IRegistrationAuthority;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.common.AuthCredentials;
@@ -102,9 +97,11 @@ import com.netscape.cmscore.apps.CommandQueue;
 import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.authorization.AuthzSubsystem;
 import com.netscape.cmscore.base.ArgBlock;
+import com.netscape.cmscore.base.ConfigStore;
 import com.netscape.cmscore.dbs.CertRecord;
 import com.netscape.cmscore.dbs.CertificateRepository;
-import com.netscape.cmscore.request.ARequestQueue;
+import com.netscape.cmscore.request.Request;
+import com.netscape.cmscore.request.RequestQueue;
 import com.netscape.cmscore.request.RequestRepository;
 import com.netscape.cmscore.security.JssSubsystem;
 import com.netscape.cmscore.usrgrp.Group;
@@ -232,13 +229,13 @@ public abstract class CMSServlet extends HttpServlet {
     protected Vector<String> mSaveHttpHeaders = new Vector<>();
 
     protected String mId = null;
-    protected IConfigStore mConfig = null;
+    protected ConfigStore mConfig;
 
     // the authority, RA, CA, KRA this servlet is serving.
     protected IAuthority mAuthority = null;
     protected ICertificateAuthority certAuthority;
     protected RequestRepository requestRepository;
-    protected ARequestQueue mRequestQueue = null;
+    protected RequestQueue mRequestQueue;
 
     // system logger.
     protected LogSource mLogCategory = ILogger.S_OTHER;
@@ -289,7 +286,7 @@ public abstract class CMSServlet extends HttpServlet {
             throw e;
         }
 
-        mConfig = cs.getSubStore(CMSGateway.PROP_CMSGATEWAY);
+        mConfig = cs.getSubStore(CMSGateway.PROP_CMSGATEWAY, ConfigStore.class);
         mServletConfig = sc;
         mServletContext = sc.getServletContext();
         mFileLoader = new CMSFileLoader();
@@ -324,8 +321,6 @@ public abstract class CMSServlet extends HttpServlet {
         } else {
             if (mAuthority instanceof ICertificateAuthority)
                 mLogCategory = ILogger.S_CA;
-            else if (mAuthority instanceof IRegistrationAuthority)
-                mLogCategory = ILogger.S_RA;
             else if (mAuthority instanceof IKeyRecoveryAuthority)
                 mLogCategory = ILogger.S_KRA;
             else
@@ -366,8 +361,8 @@ public abstract class CMSServlet extends HttpServlet {
                 }
             }
 
-            // get http params NOT to store in a IRequest and
-            // get http headers TO store in a IRequest.
+            // get http params NOT to store in a Request and
+            // get http headers TO store in a Request.
             getDontSaveHttpParams(sc);
             getSaveHttpHeaders(sc);
         } catch (Exception e) {
@@ -376,7 +371,7 @@ public abstract class CMSServlet extends HttpServlet {
         }
 
         try {
-            mSHADigest = MessageDigest.getInstance("SHA1");
+            mSHADigest = MessageDigest.getInstance("SHA-256");
         } catch (NoSuchAlgorithmException e) {
             logger.error(CMS.getLogMessage("CMSGW_ERR_CONF_TEMP_PARAMS", e.toString()), e);
             throw new ServletException(e);
@@ -392,10 +387,7 @@ public abstract class CMSServlet extends HttpServlet {
     }
 
     public boolean isClientCertRequired() {
-        if (mGetClientCert != null && mGetClientCert.equals("true"))
-            return true;
-        else
-            return false;
+        return mGetClientCert != null && mGetClientCert.equals("true");
     }
 
     public void outputHttpParameters(HttpServletRequest httpReq) {
@@ -408,13 +400,8 @@ public abstract class CMSServlet extends HttpServlet {
             // __ (double underscores); however, in the event that
             // a security parameter slips through, we perform multiple
             // additional checks to insure that it is NOT displayed
-            if (CMS.isSensitive(pn)) {
-                logger.debug("CMSServlet::service() param name='" + pn +
-                        "' value='(sensitive)'");
-            } else {
-                logger.debug("CMSServlet::service() param name='" + pn +
-                        "' value='" + httpReq.getParameter(pn) + "'");
-            }
+            String value = CMS.isSensitive(pn) ? "(sensitive)" : httpReq.getParameter(pn);
+            logger.debug("CMSServlet::service() param name='{}' value='{}'", pn, value);
         }
     }
 
@@ -492,7 +479,7 @@ public abstract class CMSServlet extends HttpServlet {
 
         try {
             if (iCommandQueue.registerProcess(cmsRequest, this) == false) {
-                cmsRequest.setStatus(ICMSRequest.ERROR);
+                cmsRequest.setStatus(CMSRequest.ERROR);
                 renderResult(cmsRequest);
                 SessionContext.releaseContext();
                 return;
@@ -683,7 +670,6 @@ public abstract class CMSServlet extends HttpServlet {
         } catch (Exception e) {
             logger.error(CMS.getLogMessage("CMSGW_ERR_OUT_TEMPLATE", templateName, e.toString()), e);
             renderException(cmsReq, new ECMSGWException(CMS.getLogMessage("CMSGW_ERROR_DISPLAY_TEMPLATE"), e));
-            return;
         }
     }
 
@@ -704,7 +690,7 @@ public abstract class CMSServlet extends HttpServlet {
         try {
             Locale[] locale = new Locale[1];
             CMSLoadTemplate loadTempl =
-                    mTemplates.get(ICMSRequest.EXCEPTION);
+                    mTemplates.get(CMSRequest.EXCEPTION);
             CMSTemplate template = getTemplate(loadTempl.mTemplateName,
                     cmsReq.getHttpReq(), locale);
             ICMSTemplateFiller filler = loadTempl.mFiller;
@@ -714,7 +700,7 @@ public abstract class CMSServlet extends HttpServlet {
             // will leave the requestStatus value set to something other
             // than CMSRequest.EXCEPTION, so force the requestStatus to
             // EXCEPTION since it must be that if we're here.
-            cmsReq.setStatus(ICMSRequest.EXCEPTION);
+            cmsReq.setStatus(CMSRequest.EXCEPTION);
 
             if (filler != null) {
                 templateParams = filler.getTemplateParams(
@@ -770,7 +756,6 @@ public abstract class CMSServlet extends HttpServlet {
                                     tokenIdx + ERROR_MSG_TOKEN.length());
         }
         out.println(finalErrMsg);
-        return;
     }
 
     /**
@@ -792,7 +777,6 @@ public abstract class CMSServlet extends HttpServlet {
          }catch (SocketException se) {
          }
          */
-        return;
     }
 
     /**
@@ -844,11 +828,10 @@ public abstract class CMSServlet extends HttpServlet {
         X509Certificate[] allCerts = (X509Certificate[]) httpReq.getAttribute(CERT_ATTR);
 
         if (allCerts == null || allCerts.length == 0) {
-            if (!clientCertRequired) {
-                return null;
-            } else {
+            if (clientCertRequired) {
                 throw new EBaseException("You did not provide a valid certificate for this operation");
             }
+            return null;
         }
 
         cert = allCerts[0];
@@ -885,10 +868,6 @@ public abstract class CMSServlet extends HttpServlet {
             logger.error("CMSServlet:getTemplate() - mServletConfig is null!");
             return null;
         }
-        if (mServletConfig.getServletContext() == null) {
-        }
-        if (templateName == null) {
-        }
         String realpath =
                 mServletConfig.getServletContext().getRealPath("/" + templateName);
 
@@ -905,10 +884,7 @@ public abstract class CMSServlet extends HttpServlet {
         if (charSet == null) {
             charSet = "UTF8";
         }
-        CMSTemplate template =
-                (CMSTemplate) mFileLoader.getCMSFile(templateFile, charSet);
-
-        return template;
+        return (CMSTemplate) mFileLoader.getCMSFile(templateFile, charSet);
     }
 
     /**
@@ -939,7 +915,6 @@ public abstract class CMSServlet extends HttpServlet {
             for (int i = 0; i < DONT_SAVE_HTTP_PARAMS.length; i++) {
                 mDontSaveHttpParams.addElement(DONT_SAVE_HTTP_PARAMS[i]);
             }
-            return;
         }
     }
 
@@ -969,15 +944,14 @@ public abstract class CMSServlet extends HttpServlet {
             }
         } catch (Exception e) {
             logger.warn(CMS.getLogMessage("CMSGW_NO_CONFIG_VALUE", PROP_SAVE_HTTP_HEADERS, e.toString()), e);
-            return;
         }
     }
 
     /**
-     * save http headers in a IRequest.
+     * save http headers in a Request.
      */
     protected void saveHttpHeaders(
-            HttpServletRequest httpReq, IRequest req)
+            HttpServletRequest httpReq, Request req)
             throws EBaseException {
         Hashtable<String, String> headers = new Hashtable<>();
         Enumeration<String> hdrs = mSaveHttpHeaders.elements();
@@ -990,14 +964,14 @@ public abstract class CMSServlet extends HttpServlet {
                 headers.put(hdr, val);
             }
         }
-        req.setExtData(IRequest.HTTP_HEADERS, headers);
+        req.setExtData(Request.HTTP_HEADERS, headers);
     }
 
     /**
-     * save http headers in a IRequest.
+     * save http headers in a Request.
      */
     protected void saveHttpParams(
-            IArgBlock httpParams, IRequest req) {
+            IArgBlock httpParams, Request req) {
         Hashtable<String, String> saveParams = new Hashtable<>();
 
         Enumeration<String> names = httpParams.elements();
@@ -1024,15 +998,14 @@ public abstract class CMSServlet extends HttpServlet {
                 saveParams.put(name, (String) httpParams.get(name));
             }
         }
-        req.setExtData(IRequest.HTTP_PARAMS, saveParams);
+        req.setExtData(Request.HTTP_PARAMS, saveParams);
     }
 
     /**
      * handy routine for getting a cert record given a serial number.
      */
     protected CertRecord getCertRecord(BigInteger serialNo) {
-        if (mAuthority == null ||
-                !(mAuthority instanceof ICertificateAuthority)) {
+        if (!(mAuthority instanceof ICertificateAuthority)) {
             logger.error(CMS.getLogMessage("CMSGW_NON_CERT_AUTH"));
             return null;
         }
@@ -1061,9 +1034,7 @@ public abstract class CMSServlet extends HttpServlet {
         BigInteger serialno = cert.getSerialNumber();
         X509CertImpl certInDB = (X509CertImpl) getX509Certificate(serialno);
 
-        if (certInDB == null || !certInDB.equals(cert))
-            return false;
-        return true;
+        return certInDB != null && certInDB.equals(cert);
     }
 
     /**
@@ -1083,8 +1054,7 @@ public abstract class CMSServlet extends HttpServlet {
      * repository. mAuthority must be a CA.
      */
     protected X509Certificate getX509Certificate(BigInteger serialNo) {
-        if (mAuthority == null ||
-                !(mAuthority instanceof ICertificateAuthority)) {
+        if (!(mAuthority instanceof ICertificateAuthority)) {
             logger.error(CMS.getLogMessage("CMSGW_NOT_CERT_AUTH"));
             return null;
         }
@@ -1118,10 +1088,9 @@ public abstract class CMSServlet extends HttpServlet {
         } catch (Exception e) {
             if ((e instanceof RuntimeException)) {
                 throw (RuntimeException) e;
-            } else {
-                logger.error(CMS.getLogMessage("CMSGW_CANT_LOAD_FILLER", fillerClass, e.toString()), e);
-                return null;
             }
+            logger.error(CMS.getLogMessage("CMSGW_CANT_LOAD_FILLER", fillerClass, e.toString()), e);
+            return null;
         }
         return filler;
     }
@@ -1221,37 +1190,37 @@ public abstract class CMSServlet extends HttpServlet {
         }
 
         mTemplates.put(
-                ICMSRequest.UNAUTHORIZED,
+                CMSRequest.UNAUTHORIZED,
                 new CMSLoadTemplate(
                         PROP_UNAUTHORIZED_TEMPLATE, PROP_UNAUTHOR_TEMPLATE_FILLER,
                         unauthorizedTemplate, null));
         mTemplates.put(
-                ICMSRequest.SUCCESS,
+                CMSRequest.SUCCESS,
                 new CMSLoadTemplate(
                         PROP_SUCCESS_TEMPLATE, PROP_SUCCESS_TEMPLATE_FILLER,
                         successTemplate, new GenSuccessTemplateFiller()));
         mTemplates.put(
-                ICMSRequest.PENDING,
+                CMSRequest.PENDING,
                 new CMSLoadTemplate(
                         PROP_PENDING_TEMPLATE, PROP_PENDING_TEMPLATE_FILLER,
                         pendingTemplate, new GenPendingTemplateFiller()));
         mTemplates.put(
-                ICMSRequest.SVC_PENDING,
+                CMSRequest.SVC_PENDING,
                 new CMSLoadTemplate(
                         PROP_SVC_PENDING_TEMPLATE, PROP_SVC_PENDING_TEMPLATE_FILLER,
                         svcpendingTemplate, new GenSvcPendingTemplateFiller()));
         mTemplates.put(
-                ICMSRequest.REJECTED,
+                CMSRequest.REJECTED,
                 new CMSLoadTemplate(
                         PROP_REJECTED_TEMPLATE, PROP_REJECTED_TEMPLATE_FILLER,
                         rejectedTemplate, new GenRejectedTemplateFiller()));
         mTemplates.put(
-                ICMSRequest.ERROR,
+                CMSRequest.ERROR,
                 new CMSLoadTemplate(
                         PROP_ERROR_TEMPLATE, PROP_ERROR_TEMPLATE_FILLER,
                         errorTemplate, new GenErrorTemplateFiller()));
         mTemplates.put(
-                ICMSRequest.EXCEPTION,
+                CMSRequest.EXCEPTION,
                 new CMSLoadTemplate(
                         PROP_EXCEPTION_TEMPLATE, PROP_EXCEPTION_TEMPLATE_FILLER,
                         unexpectedErrorTemplate, new GenUnexpectedErrorTemplateFiller()));
@@ -1263,10 +1232,7 @@ public abstract class CMSServlet extends HttpServlet {
     public static boolean clientIsNav(HttpServletRequest httpReq) {
         String useragent = httpReq.getHeader("user-agent");
 
-        if (useragent.startsWith("Mozilla") &&
-                useragent.indexOf("MSIE") == -1)
-            return true;
-        return false;
+        return useragent.startsWith("Mozilla") && useragent.indexOf("MSIE") == -1;
     }
 
     /**
@@ -1275,9 +1241,7 @@ public abstract class CMSServlet extends HttpServlet {
     public static boolean clientIsMSIE(HttpServletRequest httpReq) {
         String useragent = httpReq.getHeader("user-agent");
 
-        if (useragent != null && useragent.indexOf("MSIE") != -1)
-            return true;
-        return false;
+        return useragent != null && useragent.indexOf("MSIE") != -1;
     }
 
     /**
@@ -1287,10 +1251,7 @@ public abstract class CMSServlet extends HttpServlet {
     private static String CMMF_RESPONSE = "cmmfResponse";
 
     public static boolean doCMMFResponse(IArgBlock httpParams) {
-        if (httpParams.getValueAsBoolean(CMMF_RESPONSE, false))
-            return true;
-        else
-            return false;
+        return httpParams.getValueAsBoolean(CMMF_RESPONSE, false);
     }
 
     private static final String IMPORT_CERT = "importCert";
@@ -1312,10 +1273,7 @@ public abstract class CMSServlet extends HttpServlet {
     public static String FULL_RESPONSE = "fullResponse";
 
     public static boolean doFullResponse(IArgBlock httpParams) {
-        if (httpParams.getValueAsBoolean(FULL_RESPONSE, false))
-            return true;
-        else
-            return false;
+        return httpParams.getValueAsBoolean(FULL_RESPONSE, false);
     }
 
     /**
@@ -1365,7 +1323,7 @@ public abstract class CMSServlet extends HttpServlet {
                 X509Certificate[] caCerts = null;
                 PKCS7 p7 = null;
 
-                caChain = ((ICertAuthority) mAuthority).getCACertChain();
+                caChain = ((ICertificateAuthority) mAuthority).getCACertChain();
                 caCerts = caChain.getChain();
 
                 // set user + CA cert chain in pkcs7
@@ -1407,9 +1365,9 @@ public abstract class CMSServlet extends HttpServlet {
         }
     }
 
-    protected static void saveAuthToken(IAuthToken token, IRequest req) {
+    protected static void saveAuthToken(IAuthToken token, Request req) {
         if (token != null && req != null)
-            req.setExtData(IRequest.AUTH_TOKEN, token);
+            req.setExtData(Request.AUTH_TOKEN, token);
 
         // # 56230 - expose auth token parameters to the policy predicate
         if (token != null && req != null) {
@@ -1419,24 +1377,24 @@ public abstract class CMSServlet extends HttpServlet {
                 String[] x1 = token.getInStringArray(n);
                 if (x1 != null) {
                     for (int i = 0; i < x1.length; i++) {
-                        logger.debug("Setting " + IRequest.AUTH_TOKEN + "-" + n +
+                        logger.debug("Setting " + Request.AUTH_TOKEN + "-" + n +
                                 "(" + i + ")=" + x1[i]);
-                        req.setExtData(IRequest.AUTH_TOKEN + "-" + n + "(" + i + ")",
+                        req.setExtData(Request.AUTH_TOKEN + "-" + n + "(" + i + ")",
                                 x1[i]);
                     }
                 } else {
                     String x = token.getInString(n);
                     if (x != null) {
-                        logger.debug("Setting " + IRequest.AUTH_TOKEN + "-" + n + "=" + x);
-                        req.setExtData(IRequest.AUTH_TOKEN + "-" + n, x);
+                        logger.debug("Setting " + Request.AUTH_TOKEN + "-" + n + "=" + x);
+                        req.setExtData(Request.AUTH_TOKEN + "-" + n, x);
                     }
                 }
             } // while
         } // if
     }
 
-    protected IAuthToken getAuthToken(IRequest req) {
-        return req.getExtDataInAuthToken(IRequest.AUTH_TOKEN);
+    protected IAuthToken getAuthToken(Request req) {
+        return req.getExtDataInAuthToken(Request.AUTH_TOKEN);
     }
 
     protected static boolean connectionIsSSL(HttpServletRequest httpReq) {
@@ -1449,8 +1407,6 @@ public abstract class CMSServlet extends HttpServlet {
     protected String getRelPath(IAuthority authority) {
         if (authority instanceof ICertificateAuthority)
             return "ca/";
-        else if (authority instanceof IRegistrationAuthority)
-            return "ra/";
         else if (authority instanceof IKeyRecoveryAuthority)
             return "kra/";
         else
@@ -1497,10 +1453,7 @@ public abstract class CMSServlet extends HttpServlet {
             logger.error(CMS.getLogMessage("CMSGW_ERR_CRL_REASON", reason.toString(), e.toString()), e);
             throw new ECMSGWException(CMS.getLogMessage("CMSGW_ERROR_SETTING_CRLREASON"), e);
         }
-        RevokedCertImpl crlentry =
-                new RevokedCertImpl(serialNo, new Date(), crlentryexts);
-
-        return crlentry;
+        return new RevokedCertImpl(serialNo, new Date(), crlentryexts);
     }
 
     /**
@@ -1517,17 +1470,14 @@ public abstract class CMSServlet extends HttpServlet {
             logger.error(CMS.getLogMessage("CMSGW_BAD_CERT_SER_NUM", String.valueOf(serialNum)));
             throw new ECMSGWException(CMS.getLogMessage("CMSGW_INVALID_CERT"));
         }
-        if (certRecord.getStatus().equals(CertRecord.STATUS_REVOKED))
-            return true;
-        return false;
+        return certRecord.getStatus().equals(CertRecord.STATUS_REVOKED);
     }
 
     public static String generateSalt() {
         CMSEngine engine = CMS.getCMSEngine();
         JssSubsystem jssSubsystem = engine.getJSSSubsystem();
         SecureRandom rnd = jssSubsystem.getRandomNumberGenerator();
-        String salt = Integer.valueOf(rnd.nextInt()).toString();
-        return salt;
+        return Integer.toString(rnd.nextInt());
     }
 
     protected String hashPassword(String pwd) {
@@ -1535,7 +1485,7 @@ public abstract class CMSServlet extends HttpServlet {
         byte[] pwdDigest = mSHADigest.digest((salt + pwd).getBytes());
         String b64E = Utils.base64encode(pwdDigest, true);
 
-        return "{SHA}" + salt + ";" + b64E;
+        return "{SHA-256}" + salt + ";" + b64E;
     }
 
     /**
@@ -1617,10 +1567,10 @@ public abstract class CMSServlet extends HttpServlet {
     public static Locale getLocale(String lang) {
         int dash = lang.indexOf('-');
 
-        if (dash == -1)
+        if (dash == -1) {
             return new Locale(lang, "");
-        else
-            return new Locale(lang.substring(0, dash), lang.substring(dash + 1));
+        }
+        return new Locale(lang.substring(0, dash), lang.substring(dash + 1));
     }
 
     public IAuthToken authenticate(CMSRequest req)
@@ -1638,7 +1588,7 @@ public abstract class CMSServlet extends HttpServlet {
         IAuthToken authToken = authenticate(req.getHttpReq(),
                 authMgrName);
 
-        saveAuthToken(authToken, req.getIRequest());
+        saveAuthToken(authToken, req.getRequest());
         return authToken;
     }
 
@@ -1705,28 +1655,27 @@ public abstract class CMSServlet extends HttpServlet {
 
                 logger.debug("CMSServlet: no authMgrName");
                 return null;
+            }
+            // save the "Subject DN" of this certificate in case it
+            // must be audited as an authentication failure
+            if (clientCert == null) {
+                logger.debug("CMSServlet: no client certificate found");
             } else {
-                // save the "Subject DN" of this certificate in case it
-                // must be audited as an authentication failure
-                if (clientCert == null) {
-                    logger.debug("CMSServlet: no client certificate found");
-                } else {
-                    String certUID = clientCert.getSubjectDN().getName();
-                    logger.debug("CMSServlet: certUID=" + certUID);
+                String certUID = clientCert.getSubjectDN().getName();
+                logger.debug("CMSServlet: certUID=" + certUID);
 
-                    if (certUID != null) {
-                        certUID = certUID.trim();
+                if (certUID != null) {
+                    certUID = certUID.trim();
 
-                        if (!(certUID.equals(""))) {
-                            // reset the "auditUID"
-                            auditUID = certUID;
-                        }
+                    if (!(certUID.equals(""))) {
+                        // reset the "auditUID"
+                        auditUID = certUID;
                     }
                 }
-
-                // reset the "auditAuthMgrID"
-                auditAuthMgrID = authMgrName;
             }
+
+            // reset the "auditAuthMgrID"
+            auditAuthMgrID = authMgrName;
             IAuthToken authToken = CMSGateway.checkAuthManager(httpReq,
                     httpArgs,
                     clientCert,
@@ -1980,28 +1929,19 @@ public abstract class CMSServlet extends HttpServlet {
      */
     protected String auditSubjectID() {
 
-        logger.debug("CMSServlet: in auditSubjectID");
-        String subjectID = null;
-
-        // Initialize subjectID
         SessionContext auditContext = SessionContext.getExistingContext();
 
-        logger.debug("CMSServlet: auditSubjectID auditContext " + auditContext);
-        if (auditContext != null) {
-            subjectID = (String)
-                    auditContext.get(SessionContext.USER_ID);
-
-            logger.debug("CMSServlet auditSubjectID: subjectID: " + subjectID);
-            if (subjectID != null) {
-                subjectID = subjectID.trim();
-            } else {
-                subjectID = ILogger.NONROLEUSER;
-            }
-        } else {
-            subjectID = ILogger.UNIDENTIFIED;
+        if (auditContext == null) {
+            return ILogger.UNIDENTIFIED;
         }
 
-        return subjectID;
+        String subjectID = (String) auditContext.get(SessionContext.USER_ID);
+
+        if (subjectID == null) {
+            return ILogger.NONROLEUSER;
+        }
+
+        return subjectID.trim();
     }
 
     /**
@@ -2022,7 +1962,7 @@ public abstract class CMSServlet extends HttpServlet {
         // Initialize groupID
         SessionContext auditContext = SessionContext.getExistingContext();
 
-        logger.debug("CMSServlet: auditGroupID auditContext " + auditContext);
+        // logger.debug("CMSServlet: auditGroupID auditContext " + auditContext);
         if (auditContext != null) {
             groupID = (String)
                     auditContext.get(SessionContext.GROUP_ID);
@@ -2070,7 +2010,7 @@ public abstract class CMSServlet extends HttpServlet {
         while (groups.hasMoreElements()) {
             Group group = groups.nextElement();
 
-            if (group.isMember(SubjectID) == true) {
+            if (group.isMember(SubjectID)) {
                 if (membersString.length() != 0) {
                     membersString.append(", ");
                 }
@@ -2143,7 +2083,6 @@ public abstract class CMSServlet extends HttpServlet {
             httpResp.setContentLength(cb.length);
             os.write(cb);
             os.flush();
-            return;
         } catch (Exception ee) {
             logger.warn(CMS.getLogMessage("CMSGW_ERR_BAD_SERV_OUT_STREAM", "", ee.toString()), ee);
         }
