@@ -72,9 +72,6 @@ public class LDAPConfigurator {
 
         String database = config.getDatabase();
         params.put("database", database);
-
-        String dbuser = config.getDBUser("uid=pkidbuser,ou=people," + baseDN);
-        params.put("dbuser", dbuser);
     }
 
     public LDAPConfigurator(LDAPConnection connection, LDAPConfig config, String instanceID) throws Exception {
@@ -125,7 +122,7 @@ public class LDAPConfigurator {
         File tmpFile = File.createTempFile("pki-" + subsystem + "-reindex-", ".ldif");
 
         try {
-            customizeFile(file, tmpFile);
+            customizeFile(file, tmpFile, params);
 
             LDIF ldif = new LDIF(tmpFile.getAbsolutePath());
             LDIFRecord record = ldif.nextRecord();
@@ -141,9 +138,24 @@ public class LDAPConfigurator {
         }
     }
 
-    public void setupDatabaseManager() throws Exception {
-        logger.info("Setting up database manager");
-        importLDIF("/usr/share/pki/server/conf/manager.ldif", true);
+    public void grantDatabaseAccess(String dn) throws Exception {
+
+        logger.info("Granting database access to " + dn);
+
+        Map<String, String> params = new HashMap<>();
+        params.put("dbuser", dn);
+
+        importLDIF("/usr/share/pki/server/conf/db-access-grant.ldif", true, params);
+    }
+
+    public void revokeDatbaseAccess(String dn) throws Exception {
+
+        logger.info("Revoking database access from " + dn);
+
+        Map<String, String> params = new HashMap<>();
+        params.put("dbuser", dn);
+
+        importLDIF("/usr/share/pki/server/conf/db-access-revoke.ldif", true, params);
     }
 
     public List<LDAPEntry> findVLVs() throws Exception {
@@ -382,7 +394,7 @@ public class LDAPConfigurator {
         connection.add(entry);
     }
 
-    public void customizeFile(File file, File tmpFile) throws Exception {
+    public void customizeFile(File file, File tmpFile, Map<String, String> params) throws Exception {
 
         logger.info("Creating " + tmpFile);
 
@@ -428,16 +440,30 @@ public class LDAPConfigurator {
     }
 
     public Collection<LDIFRecord> importLDIF(String filename, boolean ignoreErrors) throws Exception {
+        return importLDIF(filename, ignoreErrors, null);
+    }
+
+    public Collection<LDIFRecord> importLDIF(String filename, boolean ignoreErrors, Map<String, String> inputParams) throws Exception {
 
         logger.info("Importing " + filename);
 
+        Map<String, String> params = new HashMap<>(this.params);
+
+        if (inputParams != null) {
+            params.putAll(inputParams);
+        }
+
+        for (String name : params.keySet()) {
+            logger.debug("- " + name + ": " + params.get(name));
+        }
+
         File file = new File(filename);
         File tmpFile = File.createTempFile("pki-import-", ".ldif");
 
         Collection<LDIFRecord> records = new ArrayList<>();
 
         try {
-            customizeFile(file, tmpFile);
+            customizeFile(file, tmpFile, params);
 
             LDIF ldif = new LDIF(tmpFile.getAbsolutePath());
 
@@ -525,6 +551,9 @@ public class LDAPConfigurator {
                 if (e.getLDAPResultCode() == LDAPException.NO_SUCH_OBJECT && ignoreErrors) {
                     logger.info(message);
 
+                } else if (e.getLDAPResultCode() == LDAPException.NO_SUCH_ATTRIBUTE && ignoreErrors) {
+                    logger.info(message);
+
                 } else if (e.getLDAPResultCode() == LDAPException.ATTRIBUTE_OR_VALUE_EXISTS && ignoreErrors) {
                     logger.info(message);
 
@@ -661,26 +690,35 @@ public class LDAPConfigurator {
 
         try {
             connection.add(entry);
+            // replication manager added -> done
+            return;
 
         } catch (LDAPException e) {
-            if (e.getLDAPResultCode() == LDAPException.ENTRY_ALREADY_EXISTS) {
-                logger.warn("Entry already exists: " + dn);
-
-                try {
-                    logger.info("Deleting " + dn);
-                    connection.delete(dn);
-
-                    logger.info("Re-adding " + dn);
-                    connection.add(entry);
-
-                } catch (LDAPException ee) {
-                    logger.warn("Unable to recreate " + dn + ": " + ee.getMessage());
-                }
-
-            } else {
+            if (e.getLDAPResultCode() != LDAPException.ENTRY_ALREADY_EXISTS) {
                 logger.error("Unable to add " + dn + ": " + e.getMessage(), e);
                 throw e;
             }
+            logger.warn("Replication manager already exists: " + dn);
+        }
+
+        logger.warn("Deleting existing replication manager: " + dn);
+
+        try {
+            connection.delete(dn);
+
+        } catch (LDAPException e) {
+            logger.error("Unable to delete " + dn + ": " + e.getMessage());
+            throw e;
+        }
+
+        logger.warn("Adding new replication manager: " + dn);
+
+        try {
+            connection.add(entry);
+
+        } catch (LDAPException e) {
+            logger.error("Unable to add " + dn + ": " + e.getMessage());
+            throw e;
         }
     }
 
@@ -780,9 +818,9 @@ public class LDAPConfigurator {
         String bindDN = "cn=" + LDAPUtil.escapeRDNValue(bindUser) + ",ou=csusers,cn=config";
 
         logger.info("Adding " + replicaDN);
-        logger.info("- nsDS5ReplicaRoot: " + baseDN);
-        logger.info("- nsDS5ReplicaBindDN: " + bindDN);
-        logger.info("- nsDS5ReplicaId: " + id);
+        logger.debug("- nsDS5ReplicaRoot: " + baseDN);
+        logger.debug("- nsDS5ReplicaBindDN: " + bindDN);
+        logger.debug("- nsDS5ReplicaId: " + id);
 
         LDAPAttributeSet attrs = new LDAPAttributeSet();
         attrs.add(new LDAPAttribute("objectclass", "top"));
@@ -799,28 +837,41 @@ public class LDAPConfigurator {
 
         try {
             connection.add(entry);
+            // replica object added -> done
+            return true;
 
         } catch (LDAPException e) {
-
             if (e.getLDAPResultCode() != LDAPException.ENTRY_ALREADY_EXISTS) {
+                logger.error("Unable to add " + replicaDN + ": " + e.getMessage(), e);
                 throw e;
             }
-
-            // BZ 470918: We can't just add the new dn.
-            // We need to do a replace until the bug is fixed.
-            logger.warn("Entry already exists, adding bind DN");
-
-            entry = connection.read(replicaDN);
-            LDAPAttribute attr = entry.getAttribute("nsDS5ReplicaBindDN");
-            attr.addValue(bindDN);
-
-            LDAPModification mod = new LDAPModification(LDAPModification.REPLACE, attr);
-            connection.modify(replicaDN, mod);
-
-            return false;
+            logger.warn("Replica object already exists: " + replicaDN);
         }
 
-        return true;
+        logger.info("Adding replica bind DN");
+
+        // BZ 470918: We can't just add the new dn.
+        // We need to do a replace until the bug is fixed.
+
+        entry = connection.read(replicaDN);
+        LDAPAttribute attr = entry.getAttribute("nsDS5ReplicaBindDN");
+        attr.addValue(bindDN);
+
+        LDAPModification mod = new LDAPModification(LDAPModification.REPLACE, attr);
+
+        try {
+            connection.modify(replicaDN, mod);
+            // replica bind DN added -> done
+
+        } catch (LDAPException e) {
+            if (e.getLDAPResultCode() != LDAPException.ATTRIBUTE_OR_VALUE_EXISTS) {
+                logger.error("Unable to add " + bindDN + ": " + e.getMessage(), e);
+                throw e;
+            }
+            logger.warn("Replica bind DN already exists: " + bindDN);
+        }
+
+        return false;
     }
 
     public void createReplicationAgreement(
@@ -837,12 +888,12 @@ public class LDAPConfigurator {
         String bindDN = "cn=" + LDAPUtil.escapeRDNValue(bindUser) + ",ou=csusers,cn=config";
 
         logger.info("Adding " + dn);
-        logger.info("- description: " + name);
-        logger.info("- nsDS5ReplicaRoot: " + baseDN);
-        logger.info("- nsDS5ReplicaHost: " + replicaHostname);
-        logger.info("- nsDS5ReplicaPort: " + replicaPort);
-        logger.info("- nsDS5ReplicaBindDN: " + bindDN);
-        logger.info("- nsDS5ReplicaTransportInfo: " + replicationSecurity);
+        logger.debug("- description: " + name);
+        logger.debug("- nsDS5ReplicaRoot: " + baseDN);
+        logger.debug("- nsDS5ReplicaHost: " + replicaHostname);
+        logger.debug("- nsDS5ReplicaPort: " + replicaPort);
+        logger.debug("- nsDS5ReplicaBindDN: " + bindDN);
+        logger.debug("- nsDS5ReplicaTransportInfo: " + replicationSecurity);
 
         LDAPAttributeSet attrs = new LDAPAttributeSet();
         attrs.add(new LDAPAttribute("objectclass", "top"));
@@ -864,29 +915,33 @@ public class LDAPConfigurator {
 
         try {
             connection.add(entry);
+            // replication agreement added -> done
+            return;
 
         } catch (LDAPException e) {
-            if (e.getLDAPResultCode() == LDAPException.ENTRY_ALREADY_EXISTS) {
-                logger.warn("Entry already exists: " + dn);
-
-                try {
-                    connection.delete(dn);
-                } catch (LDAPException ee) {
-                    logger.error("Unable to delete " + dn + ": " + ee.getMessage(), ee);
-                    throw ee;
-                }
-
-                try {
-                    connection.add(entry);
-                } catch (LDAPException ee) {
-                    logger.error("Unable to add " + dn + ": " + ee.getMessage(), ee);
-                    throw ee;
-                }
-
-            } else {
+            if (e.getLDAPResultCode() != LDAPException.ENTRY_ALREADY_EXISTS) {
                 logger.error("Unable to add " + dn + ": " + e.getMessage(), e);
                 throw e;
             }
+            logger.warn("Replication agreement already exists: " + dn);
+        }
+
+        logger.warn("Removing existing replication agreement: " + dn);
+
+        try {
+            connection.delete(dn);
+        } catch (LDAPException e) {
+            logger.error("Unable to delete " + dn + ": " + e.getMessage(), e);
+            throw e;
+        }
+
+        logger.warn("Adding new replication agreement: " + dn);
+
+        try {
+            connection.add(entry);
+        } catch (LDAPException e) {
+            logger.error("Unable to add " + dn + ": " + e.getMessage(), e);
+            throw e;
         }
     }
 
@@ -1013,7 +1068,7 @@ public class LDAPConfigurator {
         }
 
         String status = attrs.nextElement();
-        logger.info("- nsds5replicalastinitstatus: " + status);
+        logger.debug("- nsds5replicalastinitstatus: " + status);
 
         return status;
     }
