@@ -35,8 +35,6 @@ import com.netscape.certsrv.authentication.IAuthToken;
 import com.netscape.certsrv.authorization.EAuthzAccessDenied;
 import com.netscape.certsrv.authorization.EAuthzException;
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.common.ICMSRequest;
-import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestVirtualList;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.cms.servlet.base.CMSServlet;
@@ -47,7 +45,8 @@ import com.netscape.cms.servlet.common.ECMSGWException;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.base.ArgBlock;
-import com.netscape.cmscore.request.ARequestQueue;
+import com.netscape.cmscore.request.Request;
+import com.netscape.cmscore.request.RequestQueue;
 import com.netscape.cmscore.request.RequestRepository;
 
 /**
@@ -84,7 +83,7 @@ public class QueryReq extends CMSServlet {
 
     // variables
     protected IReqParser mParser;
-    protected ARequestQueue mQueue;
+    protected RequestQueue mQueue;
     protected String mFormPath;
     protected int mMaxReturns = 2000;
 
@@ -123,8 +122,8 @@ public class QueryReq extends CMSServlet {
 
         // override success and error templates to null -
         // handle templates locally.
-        mTemplates.remove(ICMSRequest.SUCCESS);
-        mTemplates.remove(ICMSRequest.ERROR);
+        mTemplates.remove(CMSRequest.SUCCESS);
+        mTemplates.remove(CMSRequest.ERROR);
 
         if (mOutputTemplatePath != null)
             mFormPath = mOutputTemplatePath;
@@ -135,30 +134,30 @@ public class QueryReq extends CMSServlet {
 
         if (p == null)
             return filter;
-        if (p.equals(IRequest.ENROLLMENT_REQUEST)) {
-            filter = "(requestType=" + IRequest.ENROLLMENT_REQUEST + ")";
-        } else if (p.equals(IRequest.RENEWAL_REQUEST)) {
-            filter = "(requestType=" + IRequest.RENEWAL_REQUEST + ")";
-        } else if (p.equals(IRequest.REVOCATION_REQUEST)) {
-            filter = "(requestType=" + IRequest.REVOCATION_REQUEST + ")";
-        } else if (p.equals(IRequest.UNREVOCATION_REQUEST)) {
-            filter = "(requestType=" + IRequest.UNREVOCATION_REQUEST + ")";
-        } else if (p.equals(IRequest.KEYARCHIVAL_REQUEST)) {
-            filter = "(requestType=" + IRequest.KEYARCHIVAL_REQUEST + ")";
-        } else if (p.equals(IRequest.KEYRECOVERY_REQUEST)) {
-            filter = "(requestType=" + IRequest.KEYRECOVERY_REQUEST + ")";
-        } else if (p.equals(IRequest.GETCACHAIN_REQUEST)) {
-            filter = "(requestType=" + IRequest.GETCACHAIN_REQUEST + ")";
-        } else if (p.equals(IRequest.GETREVOCATIONINFO_REQUEST)) {
-            filter = "(requestType=" + IRequest.GETREVOCATIONINFO_REQUEST + ")";
-        } else if (p.equals(IRequest.GETCRL_REQUEST)) {
-            filter = "(requestType=" + IRequest.GETCRL_REQUEST + ")";
-        } else if (p.equals(IRequest.GETCERTS_REQUEST)) {
-            filter = "(requestType=" + IRequest.GETCERTS_REQUEST + ")";
-        } else if (p.equals(IRequest.NETKEY_KEYGEN_REQUEST)) {
-            filter = "(requestType=" + IRequest.NETKEY_KEYGEN_REQUEST + ")";
-        } else if (p.equals(IRequest.NETKEY_KEYRECOVERY_REQUEST)) {
-            filter = "(requestType=" + IRequest.NETKEY_KEYRECOVERY_REQUEST + ")";
+        if (p.equals(Request.ENROLLMENT_REQUEST)) {
+            filter = "(requestType=" + Request.ENROLLMENT_REQUEST + ")";
+        } else if (p.equals(Request.RENEWAL_REQUEST)) {
+            filter = "(requestType=" + Request.RENEWAL_REQUEST + ")";
+        } else if (p.equals(Request.REVOCATION_REQUEST)) {
+            filter = "(requestType=" + Request.REVOCATION_REQUEST + ")";
+        } else if (p.equals(Request.UNREVOCATION_REQUEST)) {
+            filter = "(requestType=" + Request.UNREVOCATION_REQUEST + ")";
+        } else if (p.equals(Request.KEYARCHIVAL_REQUEST)) {
+            filter = "(requestType=" + Request.KEYARCHIVAL_REQUEST + ")";
+        } else if (p.equals(Request.KEYRECOVERY_REQUEST)) {
+            filter = "(requestType=" + Request.KEYRECOVERY_REQUEST + ")";
+        } else if (p.equals(Request.GETCACHAIN_REQUEST)) {
+            filter = "(requestType=" + Request.GETCACHAIN_REQUEST + ")";
+        } else if (p.equals(Request.GETREVOCATIONINFO_REQUEST)) {
+            filter = "(requestType=" + Request.GETREVOCATIONINFO_REQUEST + ")";
+        } else if (p.equals(Request.GETCRL_REQUEST)) {
+            filter = "(requestType=" + Request.GETCRL_REQUEST + ")";
+        } else if (p.equals(Request.GETCERTS_REQUEST)) {
+            filter = "(requestType=" + Request.GETCERTS_REQUEST + ")";
+        } else if (p.equals(Request.NETKEY_KEYGEN_REQUEST)) {
+            filter = "(requestType=" + Request.NETKEY_KEYGEN_REQUEST + ")";
+        } else if (p.equals(Request.NETKEY_KEYRECOVERY_REQUEST)) {
+            filter = "(requestType=" + Request.NETKEY_KEYRECOVERY_REQUEST + ")";
         } else if (p.equals(IN_SHOW_ALL)) {
             filter = "(requestType=*)";
         }
@@ -256,7 +255,7 @@ public class QueryReq extends CMSServlet {
         }
 
         if (authzToken == null) {
-            cmsReq.setStatus(ICMSRequest.UNAUTHORIZED);
+            cmsReq.setStatus(CMSRequest.UNAUTHORIZED);
             return;
         }
 
@@ -265,7 +264,7 @@ public class QueryReq extends CMSServlet {
 
         } catch (EAuthzException e) {
             logger.warn(CMS.getLogMessage("ADMIN_SRVLT_AUTH_FAILURE", e.toString()), e);
-            cmsReq.setStatus(ICMSRequest.UNAUTHORIZED);
+            cmsReq.setStatus(CMSRequest.UNAUTHORIZED);
             return;
         }
 
@@ -358,7 +357,7 @@ public class QueryReq extends CMSServlet {
             throw new ECMSGWException(CMS.getUserMessage("CMS_GW_DISPLAY_TEMPLATE_ERROR"), e);
         }
 
-        cmsReq.setStatus(ICMSRequest.SUCCESS);
+        cmsReq.setStatus(CMSRequest.SUCCESS);
     }
 
     /**
@@ -448,18 +447,18 @@ public class QueryReq extends CMSServlet {
             header.addIntegerValue(OUT_TOTALCOUNT, totalCount);
             header.addIntegerValue(OUT_CURRENTCOUNT, list.getSize());
 
-            Vector<IRequest> v = fetchRecords(list, maxCount);
+            Vector<Request> v = fetchRecords(list, maxCount);
             v = normalizeOrder(v);
             trim(v, id);
 
             int currentCount = 0;
             BigInteger curNum = BigInteger.ZERO;
             BigInteger firstNum = BigInteger.ONE.negate();
-            Enumeration<IRequest> requests = v.elements();
+            Enumeration<Request> requests = v.elements();
 
             logger.info("QueryReq: Requests:");
             while (requests.hasMoreElements()) {
-                IRequest request = null;
+                Request request = null;
                 try {
                     request = requests.nextElement();
                 } catch (Exception e) {
@@ -508,7 +507,7 @@ public class QueryReq extends CMSServlet {
      * @param v The vector to trim
      * @param marker the marker to look for.
      */
-    private void trim(Vector<IRequest> v, RequestId marker) {
+    private void trim(Vector<Request> v, RequestId marker) {
         int i = v.size() - 1;
 
         if (i == 0) {
@@ -529,15 +528,15 @@ public class QueryReq extends CMSServlet {
      * @param list
      * @return
      */
-    private Vector<IRequest> fetchRecords(IRequestVirtualList list, int maxCount) {
+    private Vector<Request> fetchRecords(IRequestVirtualList list, int maxCount) {
 
-        Vector<IRequest> v = new Vector<>();
+        Vector<Request> v = new Vector<>();
         int count = list.getSize();
         logger.info("QueryReq: Fetching " + count + " request(s)");
 
         int c = 0;
         for (int i = 0; i < count; i++) {
-            IRequest request = list.getElementAt(i);
+            Request request = list.getElementAt(i);
             if (request != null) {
                 v.add(request);
                 c++;
@@ -556,7 +555,7 @@ public class QueryReq extends CMSServlet {
      * @param list
      * @return
      */
-    private Vector<IRequest> normalizeOrder(Vector<IRequest> list) {
+    private Vector<Request> normalizeOrder(Vector<Request> list) {
 
         BigInteger firstrequestnum = new BigInteger(list.elementAt(0)
                 .getRequestId().toString());
@@ -566,10 +565,10 @@ public class QueryReq extends CMSServlet {
         if (firstrequestnum.compareTo(lastrequestnum) > 0) {
             reverse = true; // if the order is backwards, place items at the beginning
         }
-        Vector<IRequest> v = new Vector<>();
+        Vector<Request> v = new Vector<>();
         int count = list.size();
         for (int i = 0; i < count; i++) {
-            IRequest request = list.elementAt(i);
+            Request request = list.elementAt(i);
             if (request != null) {
                 if (reverse)
                     v.add(0, request);
