@@ -17,34 +17,23 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.cmstools;
 
+import java.io.BufferedReader;
 import java.io.FileOutputStream;
+import java.io.FileReader;
 import java.io.FileWriter;
-import java.io.IOException;
 import java.io.PrintStream;
 import java.security.KeyPair;
-import java.security.NoSuchAlgorithmException;
-import java.security.PublicKey;
-import java.security.interfaces.RSAPublicKey;
 
 import org.dogtag.util.cert.CertUtil;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.InitializationValues;
-import org.mozilla.jss.asn1.BMPString;
-import org.mozilla.jss.asn1.OBJECT_IDENTIFIER;
-import org.mozilla.jss.asn1.PrintableString;
-import org.mozilla.jss.asn1.TeletexString;
-import org.mozilla.jss.asn1.UTF8String;
-import org.mozilla.jss.asn1.UniversalString;
 import org.mozilla.jss.crypto.CryptoToken;
+import org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage;
 import org.mozilla.jss.crypto.PrivateKey;
 import org.mozilla.jss.netscape.security.pkcs.PKCS10;
 import org.mozilla.jss.netscape.security.x509.Extensions;
 import org.mozilla.jss.netscape.security.x509.KeyIdentifier;
 import org.mozilla.jss.netscape.security.x509.SubjectKeyIdentifierExtension;
-import org.mozilla.jss.netscape.security.x509.X500Name;
-import org.mozilla.jss.netscape.security.x509.X509Key;
-import org.mozilla.jss.pkix.primitive.AVA;
-import org.mozilla.jss.pkix.primitive.Name;
 import org.mozilla.jss.util.Password;
 
 import com.netscape.cmsutil.crypto.CryptoUtil;
@@ -68,7 +57,7 @@ public class PKCS10Client {
 
     private static void printUsage() {
         System.out.println(
-                "Usage: PKCS10Client -d <location of certdb> -h <token name> -p <token password> -a <algorithm: 'rsa' or 'ec'> -l <rsa key length> -c <ec curve name> -o <output file which saves the base64 PKCS10> -n <subjectDN>\n");
+                "\nUsage: PKCS10Client -d <location of certdb> -h <token name> -P <token password file> -a <algorithm: 'rsa' or 'ec'> -l <rsa key length> -c <ec curve name> -o <output file which saves the base64 PKCS10> -n <subjectDN>\n");
         System.out.println(
                 "    Optionally, for ECC key generation per definition in JSS pkcs11.PK11KeyPairGenerator:\n");
         System.out.println(
@@ -83,16 +72,19 @@ public class PKCS10Client {
                 "    Also optional for ECC key generation:\n");
         System.out.println(
                 "    -x <true for SSL cert that does ECDH ECDSA; false otherwise; default false>\n");
-        System.out.println(
-                "    -v Verbose mode");
         System.out.println(
                 "   available ECC curve names (if provided by the crypto module): nistp256 (secp256r1),nistp384 (secp384r1),nistp521 (secp521r1),nistk163 (sect163k1),sect163r1,nistb163 (sect163r2),sect193r1,sect193r2,nistk233 (sect233k1),nistb233 (sect233r1),sect239k1,nistk283 (sect283k1),nistb283 (sect283r1),nistk409 (sect409k1),nistb409 (sect409r1),nistk571 (sect571k1),nistb571 (sect571r1),secp160k1,secp160r1,secp160r2,secp192k1,nistp192 (secp192r1, prime192v1),secp224k1,nistp224 (secp224r1),secp256k1,prime192v2,prime192v3,prime239v1,prime239v2,prime239v3,c2pnb163v1,c2pnb163v2,c2pnb163v3,c2pnb176v1,c2tnb191v1,c2tnb191v2,c2tnb191v3,c2pnb208w1,c2tnb239v1,c2tnb239v2,c2tnb239v3,c2pnb272w1,c2pnb304w1,c2tnb359w1,c2pnb368w1,c2tnb431r1,secp112r1,secp112r2,secp128r1,secp128r2,sect113r1,sect113r2,sect131r1,sect131r2\n");
+        System.out.println(
+                "    -v Verbose mode\n");
+        System.out.println(
+                "    -w geneate RSA keypair with keyOpFlags for doing wrap/unwrap\n");
         System.out.println(
                 "In addition: -y <true for adding SubjectKeyIdentifier extensionfor CMC SharedSecret requests; false otherwise; default false> To be used with 'request.useSharedSecret=true' when running CMCRequest.\n");
     }
 
     public static void main(String args[]) throws Exception {
         String dbdir = null, ofilename = null, kid_ofilename = null, password = null, subjectName = null, tokenName = null;
+        String passwordFile = null;
 
         String alg = "rsa";
         String ecc_curve = "nistp256";
@@ -102,6 +94,7 @@ public class PKCS10Client {
         int ec_sensitive = -1; /* -1, 0, or 1 */
         int ec_extractable = -1; /* -1, 0, or 1 */
         boolean ec_ssl_ecdh = false;
+        boolean rsa_keygen_wrap_unwrap_ops = false;
         int rsa_keylen = 2048;
 
         boolean use_shared_secret = false;
@@ -116,6 +109,8 @@ public class PKCS10Client {
 
             if (name.equals("-p")) {
                 password = args[i+1];
+	    } else if (name.equals("-P")) {
+                passwordFile = args[i+1];
             } else if (name.equals("-d")) {
                 dbdir = args[i+1];
             } else if (name.equals("-a")) {
@@ -130,6 +125,9 @@ public class PKCS10Client {
                     ec_ssl_ecdh = true;
                 else
                     ec_ssl_ecdh = false;
+            } else if (name.equals("-w")) {
+                rsa_keygen_wrap_unwrap_ops = true;
+                i--;
             } else if (name.equals("-t")) {
                 String temp = args[i+1];
                 if (temp.equals("true"))
@@ -142,6 +140,7 @@ public class PKCS10Client {
                     enable_encoding = true;
                 else
                     enable_encoding = false;
+                System.out.println("PKCS10Client: enable_encoding =" + enable_encoding);
             } else if (name.equals("-s")) {
                 String ec_sensitive_s = args[i+1];
                 ec_sensitive = Integer.parseInt(ec_sensitive_s);
@@ -181,6 +180,7 @@ public class PKCS10Client {
                     use_shared_secret = false;
             } else if (name.equals("-v")) {
                 verbose = true;
+                i--;
             } else {
                 System.out.println("Unrecognized argument(" + i + "): "
                     + name);
@@ -195,6 +195,12 @@ public class PKCS10Client {
             System.exit(1);
         }
 
+        if (password != null && passwordFile != null) {
+            System.out.println("PKCS10Client: '-p' and '-P' cannot be both specified.");
+            printUsage();
+            System.exit(1);
+        }
+
         if (dbdir == null)
             dbdir = ".";
 
@@ -220,7 +226,25 @@ public class PKCS10Client {
                 System.out.println("PKCS10Client: Debug: thread token set.");
             }
 
-            if (password != null) {
+            if (passwordFile != null) {
+                String line;
+                try (BufferedReader in = new BufferedReader(new FileReader(passwordFile))) {
+                    line = in.readLine();
+                    if (line == null) {
+                        line = "";
+                    }
+                }
+                Password pass = new Password(line.toCharArray());
+
+                try {
+                    token.login(pass);
+                    if (verbose) {
+                        System.out.println("PKCS10Client: token "+ tokenName + " logged in...");
+                    }
+                } finally {
+                    pass.clear();
+                }
+            } else if (password != null) {
                 Password pass = new Password(password.toCharArray());
 
                 try {
@@ -236,24 +260,34 @@ public class PKCS10Client {
             KeyPair pair = null;
 
             if (alg.equals("rsa")) {
-                pair = CryptoUtil.generateRSAKeyPair(token, rsa_keylen);
+
+                if (verbose) {
+                    System.out.println("PKCS10Client: rsa_keygen_wrap_unwrap_ops: " + rsa_keygen_wrap_unwrap_ops);
+                }
+
+                Usage[] usages = rsa_keygen_wrap_unwrap_ops ? CryptoUtil.RSA_KEYPAIR_USAGES : null;
+                Usage[] usagesMask = rsa_keygen_wrap_unwrap_ops ? CryptoUtil.RSA_KEYPAIR_USAGES_MASK : null;
+
+                pair = CryptoUtil.generateRSAKeyPair(
+                        token,
+                        rsa_keylen,
+                        usages,
+                        usagesMask);
 
             }  else if (alg.equals("ec")) {
-                // used with SSL server cert that does ECDH ECDSA
-                org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage usages_mask_ECDH[] = {
-                    org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage.SIGN,
-                    org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage.SIGN_RECOVER
-                };
 
-                // used for other certs including SSL server cert that does ECDHE ECDSA
-                org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage usages_mask[] = {
-                  org.mozilla.jss.crypto.KeyPairGeneratorSpi.Usage.DERIVE
-                };
+                Usage[] usages = null;
+                Usage[] usagesMask = ec_ssl_ecdh ? CryptoUtil.ECDH_USAGES_MASK : CryptoUtil.ECDHE_USAGES_MASK;
+
+                pair = CryptoUtil.generateECCKeyPair(
+                        token,
+                        ecc_curve,
+                        ec_temporary,
+                        ec_sensitive,
+                        ec_extractable,
+                        usages,
+                        usagesMask);
 
-                pair = CryptoUtil.generateECCKeyPair(token, ecc_curve,
-                       null,
-                       usages_mask, ec_temporary /*temporary*/,
-                       ec_sensitive /*sensitive*/, ec_extractable /*extractable*/);
                 if (pair == null) {
                     System.out.println("PKCS10Client: pair null.");
                     System.exit(1);
@@ -307,26 +341,11 @@ public class PKCS10Client {
                 extns.add(extn);
             }
 
-            String algorithm = "SHA256withRSA";
-            PublicKey publicKey = pair.getPublic();
-            X509Key key = CryptoUtil.createX509Key(publicKey);
-
-            if (publicKey instanceof RSAPublicKey) {
-                algorithm = "SHA256withRSA";
-            } else if (CryptoUtil.isECCKey(key)) {
-                algorithm = "SHA256withEC";
-            } else {
-                throw new NoSuchAlgorithmException("Unsupported algorithm: " + publicKey.getAlgorithm());
-            }
-
             PKCS10 certReq = CryptoUtil.createCertificationRequest(
-                    subjectName, key, pair.getPrivate(), algorithm, extns);
-
-            if (certReq == null) {
-                System.out.println("PKCS10Client: Unable to create certificate request");
-                System.exit(1);
-                return;
-            }
+                    subjectName,
+                    enable_encoding,
+                    pair,
+                    extns);
 
             if (verbose) {
                 System.out.println("PKCS10Client: Certificate request created");
@@ -334,7 +353,6 @@ public class PKCS10Client {
 
             // print out keyid to be used in cmc popLinkWitnessV2
             PrivateKey privateKey = (PrivateKey) pair.getPrivate();
-            @SuppressWarnings("deprecation")
             byte id[] = privateKey.getUniqueID();
             String kid = CryptoUtil.encodeKeyID(id);
             if(verbose) {
@@ -343,7 +361,7 @@ public class PKCS10Client {
             }
 
             String pem = CertUtil.toPEM(certReq);
-            System.out.print(pem);
+            // System.out.print(pem);
 
             try (FileOutputStream fos = new FileOutputStream(ofilename);
                     PrintStream ps = new PrintStream(fos)) {
@@ -364,145 +382,4 @@ public class PKCS10Client {
         }
     }
 
-    static boolean isEncoded (String elementValue) {
-        boolean encoded = false;
-
-        if (elementValue != null && ((elementValue.startsWith("UTF8String:")) ||
-                                     (elementValue.startsWith("PrintableString:")) ||
-                                     (elementValue.startsWith("BMPString:")) ||
-                                     (elementValue.startsWith("TeletexString:")) ||
-                                     (elementValue.startsWith("UniversalString:")))) {
-            encoded = true;
-        }
-        return encoded;
-    }
-
-    static Name addNameElement (Name name, OBJECT_IDENTIFIER oid, int n, String elementValue) {
-        try {
-            String encodingType = (n > 0)? elementValue.substring(0, n): null;
-            String nameValue = (n > 0)? elementValue.substring(n+1): null;
-            if (encodingType != null && encodingType.length() > 0 &&
-                nameValue != null && nameValue.length() > 0) {
-                if (encodingType.equals("UTF8String")) {
-                    name.addElement( new AVA(oid, new UTF8String(nameValue)));
-                } else if (encodingType.equals("PrintableString")) {
-                    name.addElement( new AVA(oid, new PrintableString(nameValue)));
-                } else if (encodingType.equals("BMPString")) {
-                    name.addElement( new AVA(oid, new BMPString(nameValue)));
-                } else if (encodingType.equals("TeletexString")) {
-                    name.addElement( new AVA(oid, new TeletexString(nameValue)));
-                } else if (encodingType.equals("UniversalString")) {
-                    name.addElement( new AVA(oid, new UniversalString(nameValue)));
-                }
-            }
-        }  catch (Exception e)  {
-            System.out.println("PKCS10Client: Error adding name element: " + elementValue + " Error: "  + e.toString());
-        }
-        return name;
-    }
-
-    static Name getJssName(boolean enable_encoding, String dn) {
-
-        X500Name x5Name = null;
-
-        try {
-            x5Name = new X500Name(dn);
-        } catch (IOException e) {
-
-            System.out.println("PKCS10Client: Illegal Subject Name:  " + dn + " Error: " + e.toString());
-            System.out.println("PKCS10Client: Filling in default Subject Name......");
-            return null;
-        }
-
-        Name ret = new Name();
-        org.mozilla.jss.netscape.security.x509.RDN[] names = null;
-        names = x5Name.getNames();
-        int nameLen = x5Name.getNamesLength();
-
-        org.mozilla.jss.netscape.security.x509.RDN cur = null;
-
-        for (int i = 0; i < nameLen; i++) {
-            cur = names[i];
-            String rdnStr = cur.toString();
-            String[] split = rdnStr.split("=");
-
-            if (split.length != 2)
-                continue;
-            int n = split[1].indexOf(':');
-
-            try {
-                if (split[0].equals("UID")) {
-                    if (enable_encoding && isEncoded(split[1])) {
-                        ret = addNameElement(ret, new OBJECT_IDENTIFIER("0.9.2342.19200300.100.1.1"),
-                                             n, split[1]);
-                    } else {
-                        ret.addElement(new AVA(new OBJECT_IDENTIFIER("0.9.2342.19200300.100.1.1"),
-                                               new PrintableString(split[1])));
-                    }
-                    //                 System.out.println("UID found : " + split[1]);
-                }
-
-                if (split[0].equals("C")) {
-                    ret.addCountryName(split[1]);
-                    //                   System.out.println("C found : " + split[1]);
-                    continue;
-                }
-
-                if (split[0].equals("CN")) {
-                    if (enable_encoding && isEncoded(split[1])) {
-                        ret = addNameElement (ret, Name.commonName, n, split[1]);
-                    } else {
-                        ret.addCommonName(split[1]);
-                    }
-                    //                  System.out.println("CN found : " + split[1]);
-                    continue;
-                }
-
-                if (split[0].equals("L")) {
-                    if (enable_encoding && isEncoded(split[1])) {
-                        ret = addNameElement (ret, Name.localityName, n, split[1]);
-                    } else {
-                        ret.addLocalityName(split[1]);
-                    }
-                    //                 System.out.println("L found : " + split[1]);
-                    continue;
-                }
-
-                if (split[0].equals("O")) {
-                    if (enable_encoding && isEncoded(split[1])) {
-                        ret = addNameElement (ret, Name.organizationName, n, split[1]);
-                    } else {
-                        ret.addOrganizationName(split[1]);
-                    }
-                    //                System.out.println("O found : " + split[1]);
-                    continue;
-                }
-
-                if (split[0].equals("ST")) {
-                    if (enable_encoding && isEncoded(split[1])) {
-                        ret = addNameElement (ret, Name.stateOrProvinceName, n, split[1]);
-                    } else {
-                        ret.addStateOrProvinceName(split[1]);
-                    }
-                    //               System.out.println("ST found : " + split[1]);
-                    continue;
-                }
-
-                if (split[0].equals("OU")) {
-                    if (enable_encoding && isEncoded(split[1])) {
-                        ret = addNameElement (ret, Name.organizationalUnitName, n, split[1]);
-                    } else {
-                        ret.addOrganizationalUnitName(split[1]);
-                    }
-                    //              System.out.println("OU found : " + split[1]);
-                    continue;
-                }
-            } catch (Exception e) {
-                System.out.println("PKCS10Client: Error constructing RDN: " + rdnStr + " Error: " + e.toString());
-                continue;
-            }
-        }
-
-        return ret;
-    }
 }
