@@ -52,18 +52,10 @@ public class KRAKeyRetrieveCLI extends CommandCLI {
         option.setArgName("Passphrase");
         options.addOption(option);
 
-        option = new Option(null, "input-format", true, "Input format (json only - provided for backwards compatibility)");
-        option.setArgName("format");
-        options.addOption(option);
-
         option = new Option(null, "input", true, "Location of the request template file.");
         option.setArgName("Input file path");
         options.addOption(option);
 
-        option = new Option(null, "output-format", true, "Output format (json only - provided for backwards compatibility)");
-        option.setArgName("format");
-        options.addOption(option);
-
         option = new Option(null, "output", true, "Location to store the retrieved key information");
         option.setArgName("File path to store key information");
         options.addOption(option);
@@ -101,10 +93,8 @@ public class KRAKeyRetrieveCLI extends CommandCLI {
             String passphrase = cmd.getOptionValue("passphrase");
             String requestId = cmd.getOptionValue("requestID");
             String requestFile = cmd.getOptionValue("input");
-            String inputFormat = cmd.getOptionValue("input-format", "json");
             String outputFilePath = cmd.getOptionValue("output");
             String outputDataFile = cmd.getOptionValue("output-data");
-            String outputFormat = cmd.getOptionValue("output-format", "json");
             String transportNickname = cmd.getOptionValue("transport");
 
             KeyClient keyClient = keyCLI.getKeyClient(transportNickname);
@@ -114,12 +104,6 @@ public class KRAKeyRetrieveCLI extends CommandCLI {
                 String input = new String(Files.readAllBytes(path), StandardCharsets.UTF_8);
 
                 KeyRecoveryRequest req;
-                if ("json".equalsIgnoreCase(inputFormat)) {
-                    req = JSONSerializer.fromJSON(input, KeyRecoveryRequest.class);
-                    logger.info("Request: " + req.toJSON());
-                } else {
-                    throw new Exception("Unsupported format: " + inputFormat);
-                }
                 req = JSONSerializer.fromJSON(input, KeyRecoveryRequest.class);
                 logger.info("Request: " + req.toJSON());
 
@@ -208,15 +192,11 @@ public class KRAKeyRetrieveCLI extends CommandCLI {
             } else if (outputFilePath != null) {
 
                 try (FileWriter out = new FileWriter(outputFilePath)) {
-                    if ("json".equalsIgnoreCase(outputFormat)) {
-                        out.write(keyData.toJSON());
-                    } else {
-                        throw new Exception("Unsupported format: " + outputFormat);
-                    }
+                    out.write(keyData.toJSON());
                 }
-            } else if ("json".equalsIgnoreCase(outputFormat)) {
-                System.out.println(keyData.toJSON());
+
             } else {
+                System.out.println(keyData.toJSON());
                 MainCLI.printMessage("Retrieve Key Information");
 
                 printKeyInfo(key);
@@ -234,7 +214,7 @@ public class KRAKeyRetrieveCLI extends CommandCLI {
 
     public void printKeyInfo(Key key) {
         if (key.getRequestId() != null)
-            System.out.println("  Recovery Request ID: " + key.getRequestId());
+            System.out.println("  Recovery Request ID: " + key.getRequestId().toHexString());
         if (key.getAlgorithm() != null)
             System.out.println("  Key Algorithm: " + key.getAlgorithm());
         if (key.getSize() != null)
