@@ -1,7 +1,9 @@
 #!/bin/bash -ex
 
+CERT_ID=$(cat /tmp/cert_id)
+
 # revoke the cert
-pki -n caadmin ca-cert-hold `cat /tmp/cert_id` --force
+pki -u caadmin -w Secret.123 ca-cert-hold $CERT_ID --force
 
 set +e
 
@@ -11,4 +13,4 @@ pki -n caagent ca-cert-request-find || echo $? > /tmp/actual
 set -e
 
 echo 255 > /tmp/expected
-diff /tmp/actual /tmp/expected
+diff /tmp/expected /tmp/actual
